	SUBROUTINE CPB_GOBP ( icat, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_GOBP								*
C*									*
C* This subroutine computes the observed probability (relative		*
C* frequency) for category ICAT.					*
C*									*
C* The data record consists of the following:				*
C*									*
C* DATA Field                  Contents					*
C*     1       Number of verification events (N)			*
C*     2       Category 1 mean forecast probability * obs probability   *
C*     3       Category 1 mean of squares of all forecast probabilities	*
C*     4       Fraction of N observed in category 1			*
C*     5       Category 2 mean forecast probability * obs probability   *
C*     6       Category 2 mean of squares of all forecast probabilities	*
C*									*
C* There may be additional categories, in which case the fraction of N	*
C* observed is included for category 2 and all additional categories,	*
C* except the last.  This last fraction is computed as a residual.	*
C*									*
C* This average forecast probability given the event was observed in	*
C* category ICAT is given by:						*
C*									*
C*           PROB (O) = Fraction					*
C*									*
C*									*
C* CPB_GOBP ( ICAT, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE,		*
C*	      RMISS, PRBS, NPRBS, TRCDAT, TRCMIN, TRCMAX, IRET )	*
C*									*
C* Input parameters:							*
C*	ICAT		INTEGER		Category number			*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = Computation not possible	*
C*					 -3 = invalid GBS category	*
C
C**									*
C* Log:									*
C* K. Brill/HPC		 6/02						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		rnttl, fr
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	ncat = ndpth / 3
	IF ( ncat .lt. 2 ) THEN
	    iret = -1
	    RETURN
	END IF
	IF ( icat .gt. ncat ) THEN
	    iret = -3
	    RETURN
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	indx = ( icat - 1 ) * 3 + 2
	IF ( indx + 2 .gt. ndpth ) THEN
	    indxp2 = 0
	ELSE
	    indxp2 = indx + 2
	END IF
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    rnttl  = dtrace (itrc,1,ip)
	    IF ( indxp2 .ne. 0 ) THEN
	        fr = dtrace (itrc,indxp2,ip)
	    ELSE
		fr = dtrace (itrc,1,ip)
		i1 = 4
		i2 = indx - 1
		DO i = i1, i2, 3
		    fr = fr - dtrace (itrc,i,ip)
		END DO
	    END IF
	    IF ( ok .and. rnttl .gt. 0.0 ) THEN
		trcdat (ip) = fr / rnttl
C*
		IF ( trcdat (ip) .lt. trcmin ) trcmin = trcdat (ip)
		IF ( trcdat (ip) .gt. trcmax ) trcmax = trcdat (ip)
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
