	SUBROUTINE CPB_PANL ( indx, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_PANL								*
C*									*
C* This subroutine computes the probability of the analysis being lower,*
C* within, higher, or outside the range of the ensemble for a trace	*
C* of RHET records.							*
C* 
C*									*
C* CPB_PANL ( INDX, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, ICAT,	*
C*	      TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Calculation selection #:	*
C*					1 = Prob analysis lower than ens*
C*					2 = Prob analysis within the ens*
C*					3 = Prob analysis hgher than ens*
C*					4 = Prob analysis outside ens   *
C*					5 = Statistically consistent	*
C*					    prob analysis outside ens	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-99 = invalid indx		*
C**									*
C* Log:									*
C* K. Brill/HPC		03/04						*
C* K. Brill/HPC		04/04	Added INDX=5 option			*
C* K. Brill/HPC		 5/04	Change TLGEA stats to RHET stats	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, tn, rnmp1
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	IF ( indx .gt. 5 .or. indx .lt. 1 ) THEN
	    iret = -99
	    RETURN
	END IF
	IF ( indx .eq. 5 ) THEN
	    trcmin = 1.0E31
	    trcmax = -1.0E31
	ELSE
	    trcmin = 0.0
	    trcmax = 1.0
	END IF
	DO ip = 1, npts
	    tn = -1.0
	    f = 0.0
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
		tn = dtrace (itrc,1,ip)
		IF ( indx .eq. 1 ) THEN
		    f = dtrace (itrc,2,ip)
		ELSE IF ( indx .eq. 2 ) THEN
		    DO k = 3, ndpth
			f = f + dtrace (itrc,k,ip)
		    END DO
		ELSE IF ( indx .eq. 3 .or. indx .ge. 4 ) THEN
		    DO k = 2, ndpth
			f = f + dtrace (itrc,k,ip)
		    END DO
		    IF ( indx .eq. 3 ) THEN
			f = tn - f
		    ELSE
			f = tn - f + dtrace (itrc,2,ip)
		    END IF
		END IF
	    END IF
	    IF ( tn .gt. 0.0 ) THEN
		trcdat (ip) = f / tn
		IF ( trcdat (ip) .gt. 1.0 ) trcdat (ip) = 1.0
		IF ( trcdat (ip) .lt. 0.0 ) trcdat (ip) = 0.0
		IF ( indx .eq. 5 ) THEN
		    rnmp1 = DFLOAT ( ndpth )
		    trcdat (ip) = trcdat (ip) - 2.0 / rnmp1
		    IF ( trcdat (ip) .gt. trcmax ) trcmax = trcdat (ip)
		    IF ( trcdat (ip) .lt. trcmin ) trcmin = trcdat (ip)
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
