	SUBROUTINE CPB_PASK ( mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, icat, trcdat, trcmin, trcmax,
     +			      iret )
C************************************************************************
C* CPB_PASK								*
C*									*
C* This subroutine computes the Postagreement from PBS values.		*
C*									*
C* A value that exceeds the threshold is counted as a hit if it is	*
C* within the category selected by ICAT or any higher category.  If	*
C* ICAT <= 0, all categories except the no risk category are used.	*
C* ICAT <= 0 produces the same result as ICAT = 1.			*
C*									*
C* Only values within category ICAT and higher categories are counted	*
C* as forecasts.  All values exceeding the threshold are counted as	*
C* observations.							*
C*									*
C* CPB_PASK ( MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, ICAT,		*
C*	      TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	ICAT		INTEGER		Detection category cutoff	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		12/00						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, td
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	mcat = icat
	IF ( mcat .le. 0 ) mcat = 1
	IF ( mcat .gt. (ndpth/2-1) ) mcat = ndpth/2 - 1
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
		f = 0.0
		nsplt = ndpth / 2
		DO m = mcat+1, nsplt
	    	    f = f + dtrace (itrc,m,ip)
		END DO
		h = 0.0
		DO m = ndpth, nsplt+1+mcat, -1
		    h = h + dtrace (itrc,m,ip)
		END DO
	    END IF
	    IF ( ok .and. f .ne. 0.0 ) THEN
		td =  h / f
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
