	SUBROUTINE CS_BMRK ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_BMRK								*
C*									*
C* This subroutine computes the average of the CPR benchmarks (PA and   *
C* CMR), which defines the optimal point halfway between them.		*
C*									*
C* CS_BMRK ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20100223						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, tn
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn .gt. 0.0 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. 0.0 ) THEN
		alfa = o / tn
		P = h / o
		B = f / o
		dn = 2. * B * ( 1. - alfa * B )
		IF ( dn .ne. 0.0 ) THEN
		    td = ( P - 2. * alfa * P * B + alfa * B ) / dn
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
