	SUBROUTINE CS_BNOP ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     iop, ipos1, ipos2,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_BNOP								*
C*									*
C* This subroutine computes a binary arithmetic operation with the	*
C* first operand being the value in DTRACE (ITRC,IPOS1,*) and the	*
C* second the value in DTRACE (ITRC,IPOS2,*).				*
C*									*
C* An invalid IOP value results in an output trace of missing values.	*
C*									*
C* CS_BNOP ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS, IOP, IPOS1, IPOS2,	*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	IOP		INTEGER		Operation code:			*
C*					  1 = addition			*
C*					  2 = subtraction		*
C*					  3 = multipication		*
C*					  4 = division			*
C*	IPOS1		INTEGER		Position of first operand	*
C*	IPOS2		INTEGER		Position of second operand	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		07/00						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		c, f, o, td
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,ipos1,ip)
	    o  = dtrace (itrc,ipos2,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +		 c  .ne. 0.0 .and.
     +		 iop .ge. 1 .and. iop .le. 4 ) THEN
		f = f / c
		o = o / c
		IF ( iop .eq. 1 ) THEN
		    td = f + o
		ELSE IF ( iop .eq. 2 ) THEN
		    td = f - o
		ELSE IF ( iop .eq. 3 ) THEN
		    td = f * o
		ELSE IF ( iop .eq. 4 ) THEN
		    td = f / o
		ELSE
		    td = rmiss
		END IF
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
