	SUBROUTINE CS_CPFR ( kmp, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_CPFR								*
C*									*
C* This subroutine computes the conditional probability of forecast	*
C* value greater than observed value given one of several conditions 	*
C* that forecast and/or observed values exceed a given threshold.  It	*
C* can compute the frequency bias (forecasts exceeding the threshold	*
C* divided by the observations exceeding the threshold).		*
C*									*
C* CS_CPFR ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	KMP		INTEGER		Computational identifier:	*
C*					1 = P(F>O|O>threshold)		*
C*					2 = P(F>O|F>threshold)		*
C*					3 = BIAS=P(F>Th)/P(O>Th)	*
C*               			4 = P(F>O|both O & F > Th)	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20100915						*
C* K. Brill/HPC	     20100930	Add KMP & calculations 2 & 3		*
C* K. Brill/HPC      20101001	Add KMP = 4 calculation			*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		h, o, td, hh, ff, hhh, fff
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    hh  = dtrace (itrc,5,ip)
	    ff  = dtrace (itrc,6,ip)
	    hhh  = dtrace (itrc,7,ip)
	    fff  = dtrace (itrc,8,ip)
	    IF ( kmp .eq. 1 .and. h .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 ) THEN
		IF ( o .ne. 0.0 ) THEN
		    td = h / o
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE IF ( kmp .eq. 2 .and. hh .gt. -1.E30 .and.
     +		      ff .gt. -1.E30 ) THEN
		IF ( ff .ne. 0.0 ) THEN
		    td = hh / ff
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE IF ( kmp .eq. 3 .and. o .gt. -1.E30 .and.
     +		 ff  .gt. -1.E30 ) THEN
		IF ( o .ne. 0.0 ) THEN
		    td = ff / o
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE IF ( kmp .eq. 4 .and. hhh .gt. -1.E30 .and.
     +		      fff .gt. -1.E30 ) THEN
		IF ( fff .ne. 0.0 ) THEN
		    td = hhh / fff
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
