	SUBROUTINE CS_DIRE ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_DIRE								*
C*									*
C* This subroutine computes the average observed to forecast location	*
C* vector direction for TRK error stats.				*
C*									*
C*									*
C* CS_DIRE ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20061227						*
C************************************************************************
	PARAMETER       ( PI = 3.14159265  )
	PARAMETER       ( RTD = 180. / PI  )
C*
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		c, xp, yp
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,1,ip)
	    xp  = dtrace (itrc,7,ip)
	    yp  = dtrace (itrc,8,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 xp .gt. -1.E30 .and.
     +		 yp .gt. -1.E30 .and.
     +		 c  .ne. 0.0 ) THEN
		xp = xp / c
		yp = yp / c
		IF ( xp .eq. 0.0 .and. yp .eq. 0.0 ) THEN
		    td = 0.0
		ELSE
		    td = ATAN2 ( xp, yp ) * RTD
		    IF ( td .le. 0 ) td = td + 360.0
	        END IF
		IF ( td .ge. 0.0 ) THEN
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
