	SUBROUTINE CS_EDSK ( indx, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_EDSK								*
C*									*
C* This subroutine computes the Extreme Dependency Score (EDS) from FHO *
C* values.  It will also compute the Symmetric EDS (SEDS), the Extemal	*
C* Dependence Index (EDI), and the Symmetric EDI (SEDI).		*
C*									*
C* CS_EDSK ( INDX, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Computation indenting integer:	*
C*					1 = EDS				*
C*					2 = SEDS			*
C*					3 = EDI				*
C*					4 = SEDI			*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = INDX out of bounds	*
C**									*
C* Log:									*
C* K. Brill/HPC      20061228						*
C* K. Brill/HPC      20110805	Added INDX & computation of SEDS, EDI,	*
C*				and SEDI				*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, td, dn, hr, fr
C*-----------------------------------------------------------------------
	iret = 0
C*
	IF ( indx .lt. 1 .or. indx .gt. 4 ) THEN
	    iret = -1
	    RETURN
	END IF
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    dn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( indx .eq. 1 .and. dn .gt. 0.0 .and.
     +		 h  .gt. 0.0 .and.
     +		 o  .gt. 0.0 ) THEN
		td = 2. * DLOG ( o/dn ) / DLOG ( h/dn )
		td = td - 1.0
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE IF ( indx .eq. 2 .and. dn .gt. 0.0 .and.
     +		 f .gt. 0.0 .and. h .gt. 0.0 .and.
     +		 o  .gt. 0.0 ) THEN
		td = DLOG ( (f*o)/(dn*dn) ) / DLOG ( h/dn )
		td = td - 1.0
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE IF ( indx .eq. 3 .and. dn .gt. 0.0 .and.
     +		 f .gt. 0.0 .and. h .gt. 0.0 .and.
     +		 o  .gt. 0.0 .and. f .ne. h .and.
     +           o .ne. dn ) THEN
		hr = h / o
		fr = ( f - h ) / ( dn - o )
		td = DLOG ( fr / hr ) / DLOG ( fr * hr )
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE IF ( indx .eq. 4 .and. dn .gt. 0.0 .and.
     +		 f .gt. 0.0 .and. h .gt. 0.0 .and.
     +		 o  .gt. 0.0 .and. f .ne. h .and.
     +           o .ne. dn .and. (f-h) .ne. (dn-o) .and.
     +           h .ne. o ) THEN
		hr = h / o
		fr = ( f - h ) / ( dn - o )
		td = DLOG ( fr / hr ) + DLOG ( (1.-hr) / (1.-fr) )
		td = td / DLOG ( fr * hr * (1.-fr) * ( 1.-hr ) )
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
