	SUBROUTINE CS_ETSK ( indx, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_ETSK								*
C*									*
C* This subroutine computes the Equitable Threat score, the Heidke	*
C* skill score, or the Pierce-Hanssen-Kuipers discriminant skill score	*
C* from	 FHO values.							*
C*									*
C* CS_ETSK ( INDX, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Calculation selection #:	*
C*					0 = Equitable Threat Score	*
C*					1 = Heidke Skill Score		*
C*					2 = P-H-K Skill Score		*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C* K. Brill/HPC		10/02	Added Heidke and P-H-K skill scores	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		tn, f, h, o, td, dn
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 ) THEN
		IF ( indx .eq. 0 .and. tn .ne. 0.0 ) THEN
C
C*		    Compute equitable threat score.
C
		    td = f * o / tn
		    dn = f + o - h - td
		    IF ( dn .ne. 0.0 ) THEN
			td = ( h - td ) / dn
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 1 ) THEN
C
C*		    Compute Heidke skill score.
C
		    dn = tn * ( o + f ) - 2. * o * f
		    IF ( dn .ne. 0.0 ) THEN
			td = 2.0 * ( tn * h - f * o )
			td = td / dn
		    ELSE
			td = rmiss
		    END IF
		ELSE IF ( indx .eq. 2 .and. o*(tn-o) .ne. 0. ) THEN
C
C*		    Compute the P-H-K skill score.
C
		    td = ( tn * h - f * o ) / ( o * ( tn - o ) )
		ELSE
		    td = rmiss
		END IF
		IF ( td .ne. rmiss ) THEN
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
