	SUBROUTINE CS_FASK ( indx, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_FASK								*
C*									*
C* This subroutine computes the False Alarm Ratio, False Alarm Rate,	*
C* or the Conditional Miss Rate from FHO values.			*
C*									*
C* CS_FASK ( INDX, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	INDX		INTEGER		Calculation selection #:	*
C*					0 = False Alarm Ratio		*
C*					1 = False Alarm Rate		*
C*					2 = Conditional Miss Rate	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C* K. Brill/HPC		10/02	Add False Alarm Rate & Cond. Miss Rate	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, tn, td
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn  = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn  .gt. -1.E30 .and.
     +	         f  .gt. -1.E30 .and.
     +	         h  .gt. -1.E30 .and.
     +	         o  .gt. -1.E30 ) THEN
		IF ( indx .eq. 0 .and. f .ne. 0.0 ) THEN
C
C*		    Compute false alarm ratio.
C
		    td = 1. - ( h / f )
		ELSE IF ( indx .eq. 1 .and. (tn-o) .gt. 0. ) THEN
C
C*		    Compute false alarm rate.
C
		    td = ( f - h ) / ( tn - o )
		ELSE IF ( indx .eq. 2 .and. (tn-f) .gt. 0. ) THEN
C
C*		    Compute conditional miss rate.
C
		    td = ( o - h ) / ( tn -f )
		ELSE
		    td = rmiss
		END IF
		IF ( td .ne. rmiss ) THEN
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
