	SUBROUTINE CV_BIAS ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CV_BIAS								*
C*									*
C* This subroutine computes the speed BIAS for forcast and obs data.	*
C*									*
C* CV_BIAS ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		c, fv2, ov2, td
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,1,ip)
	    fv2  = dtrace (itrc,7,ip)
	    ov2  = dtrace (itrc,8,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 fv2  .gt. -1.E30 .and.
     +		 ov2  .gt. -1.E30 .and.
     +		 c    .gt. 0.0 ) THEN
		fv2 = SQRT ( fv2 / c )
		ov2 = SQRT ( ov2 / c )
		td =  fv2 - ov2
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
