	SUBROUTINE CV_CORR ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CV_CORR								*
C*									*
C* This subroutine computes the Correlation of forecast and obs vectors.*
C*									*
C*									*
C* CV_CORR ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		uf, vf, uo, vo, fo, f2, o2, c, td, s2, so, sf
	REAL*8		as, dn
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c   = dtrace (itrc,1,ip)
	    uf  = dtrace (itrc,2,ip)
	    vf  = dtrace (itrc,3,ip)
	    uo  = dtrace (itrc,4,ip)
	    vo  = dtrace (itrc,5,ip)
	    fo  = dtrace (itrc,6,ip)
	    f2  = dtrace (itrc,7,ip)
	    o2  = dtrace (itrc,8,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 uf .gt. -1.E30 .and.
     +		 vf .gt. -1.E30 .and.
     +		 uo .gt. -1.E30 .and.
     +		 vo .gt. -1.E30 .and.
     +		 fo .gt. -1.E30 .and.
     +		 f2 .gt. -1.E30 .and.
     +		 o2 .gt. -1.E30 .and.
     +		 c  .ne. 0.0 ) THEN
		uf = uf  / c
		vf = vf  / c
		uo = uo  / c
		vo = vo  / c
		fo = fo / c
		f2 = f2 / c
		o2 = o2 / c
		s2 = fo - uf * uo - vf * vo
		as = f2 - uf * uf - vf * vf
		IF ( as .ge. 0.0 ) THEN
		    sf = SQRT ( as )
		ELSE
		    sf = 0.0
		END IF
		as = o2 - uo * uo - vo * vo
		IF ( as .ge. 0.0 ) THEN
		    so = SQRT ( as )
		ELSE
		    so = 0.0
		END IF
		dn = sf * so
		IF ( dn .ne. 0.0 ) THEN
		    td = s2 / dn
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
