	SUBROUTINE CV_COVA ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CV_COVA								*
C*									*
C* This subroutine computes the Covariance of forecast and obs vectors.	*
C*									*
C*									*
C* CV_COVA ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		uf, vf, uo, vo, fo, c, td
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c   = dtrace (itrc,1,ip)
	    uf  = dtrace (itrc,2,ip)
	    vf  = dtrace (itrc,3,ip)
	    uo  = dtrace (itrc,4,ip)
	    vo  = dtrace (itrc,5,ip)
	    fo  = dtrace (itrc,6,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 uf .gt. -1.E30 .and.
     +		 vf .gt. -1.E30 .and.
     +		 uo .gt. -1.E30 .and.
     +		 vo .gt. -1.E30 .and.
     +		 fo .gt. -1.E30 .and.
     +		 c  .ne. 0.0 ) THEN
		uf = uf  / c
		vf = vf  / c
		uo = uo  / c
		vo = vo  / c
		fo = fo / c
		td = fo - uf * uo - vf * vo
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
