	SUBROUTINE CV_ESCI ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     nmem, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CV_ESCI								*
C*									*
C* This subroutine computes the Ensemble Statistical Consistency Index. *
C*									*
C*                      Mean Squared Error of Ensemble Mean Forecast    *
C*        ESCI = ----------------------------------------------------	*
C*                        Variance of Ensemble About Ensemble Mean	*
C*									*
C* The mean squared error is usually weighted by (n/n+1), when n is the *
C* number of ensemble members.  This is done here.  The variance is the *
C* sum of the squared deviations from the ensemble mean divided by n-1. *
C*									*
C* CV_ESCI ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS, NMEM,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	NMEM		INTEGER		Number of ensemble members	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		05/04						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		fo, f2, o2, c, td, as, rnmem
C*-----------------------------------------------------------------------
	iret = 0
	rnmem = DFLOAT ( nmem )
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,1,ip)
	    fo  = dtrace (itrc,6,ip)
	    f2  = dtrace (itrc,7,ip)
	    o2  = dtrace (itrc,8,ip)
	    evar = dtrace (itrc,9,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 fo .gt. -1.E30 .and.
     +		 f2 .gt. -1.E30 .and.
     +		 o2 .gt. -1.E30 .and.
     +		 evar .gt. -1.E30 .and.
     +		 c  .ne. 0.0 ) THEN
		fo = fo / c
		f2 = f2 / c
		o2 = o2 / c
		as = f2 + o2 - 2. * fo
		evar = evar / c
		IF ( evar .gt. 0.0 ) THEN
		    as = as * ( rnmem / ( rnmem + 1 ) )
		    td = as / evar
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
