	SUBROUTINE TI_ADDM  ( idtarr, min, jdtarr, iret )
C************************************************************************
C* TI_ADDM								*
C*									*
C* This subroutine adds a specified number of minutes to the time in	*
C* an integer array.  The input and output arrays may be the same array.*
C*									*
C* TI_ADDM  ( IDTARR, MIN, JDTARR, IRET )				*
C*									*
C* Input parameters:							*
C*	IDTARR (5)	INTEGER		Time array (YYYY,MM,DD,HH,MM)	*
C*	MIN		INTEGER		Number of minutes to add	*
C*									*
C* Output parameters:							*
C*	JDTARR (5)	INTEGER		Time array (YYYY,MM,DD,HH,MM)	*
C* 	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -7 = invalid year		*
C*					 -8 = invalid month		*
C*					 -9 = invalid day		*
C**									*
C* Log:									*
C* J. Whistler/AWC	 8/95	Based on TI_ADDD			*
C* K. Tyle/GSC		11/95	Fixed leap-year and day/month-change	*
C* K. Brill/EMC		 2/98	Removed INCLUDE GEMPRM.PRM		*
C************************************************************************
	INTEGER		idtarr (*), jdtarr (*)
C*
	INTEGER		month ( 13 )
	LOGICAL 	LEAP
C
C*      Function LEAP determines whether this is a leap year.
C
        LEAP ( iyear ) =  ( ( MOD ( iyear, 4 ) .eq. 0 )  .and.
     +                    ( ( MOD ( iyear, 100 ) .ne. 0 )  .or.
     +                      ( MOD ( iyear, 400 ) .eq. 0 ) ) )
C
	DATA		month / 31, 28, 31, 30, 31, 30, 31, 31, 30, 31,
     +				30, 31, 29 /
C------------------------------------------------------------------------
	iret = 0
C
C*	Get year, month, day, hour, and minute.
C
	iyear  = idtarr (1)
	imonth = idtarr (2)
	iday   = idtarr (3)
	ihour  = idtarr (4)
	imin   = idtarr (5)
C
C*	Check for leap year.  If leap year, set February to be month 13.
C
	jmonth = imonth
	IF ( LEAP ( iyear ) .and. jmonth .eq. 2 ) jmonth = 13
C
C*	Check for valid year.
C
	IF  ( ( iyear .lt. 0 ) .or. ( ( iyear .gt. 99 ) .and.
     +        ( iyear .lt. 1000 ) ) )  THEN
	    iret = -7
	    RETURN
	END IF
C
C*	Check for valid month.
C
	IF  ( ( imonth .lt. 1 ) .or. ( imonth .gt. 12 ) )  THEN
	    iret = - 8
	    RETURN
	END IF
C
C*	Check for valid day.
C
	IF  ( ( iday .lt. 1 ) .or. ( iday .gt. month (jmonth) ) )  THEN
	    iret  = -9
	    RETURN
	END IF
C
C*	Check for last minute of hour.
C
	imin = imin + min
	IF ( imin .gt. 59 ) THEN
	    iadd =  imin / 60 
	    IF ( mod ( imin, 60) .eq. 0 ) THEN
		imin = 0
	    ELSE
		imin = imin - ( iadd * 60 ) 
	    END IF
C
C*	    Check for last hour of day.
C
	    ihour = ihour + iadd
	    IF ( ihour .gt. 23 ) THEN
		iaddh = ihour / 24 
		ihour = ihour - ( iaddh * 24 )
		DO k = 1, iaddh
C
C*	            Check for last day of month.
C
		    IF  ( iday .eq. month ( jmonth ) )  THEN
	                imonth = imonth + 1
C
C*			Check for last month of year.
C
	                IF  ( imonth .eq. 13 )  THEN
		            iyear  = iyear + 1
		            imonth = 1
	                END IF
C
C*			Check for leap year.
C
	 	        jmonth = imonth
		        IF ( LEAP ( iyear ) .and. jmonth .eq. 2 )
     +			    jmonth = 13
C
C*	                Adjust day.
C
	                iday = 1
	            ELSE
	    	        iday = iday + 1
	            END IF
		END DO
	    END IF
	END IF
C
C*	Put time in output array.
C
	jdtarr (1) = iyear
	jdtarr (2) = imonth
	jdtarr (3) = iday
	jdtarr (4) = ihour
	jdtarr (5) = imin
C*
	RETURN
	END
