	SUBROUTINE PLT_ADLN  ( line, iret )
C************************************************************************
C* PLT_ADLN								*
C*									*
C* This subroutine converts the input for the ADLINE variable into a	*
C* list of colors, line types, and line widths for the reference lines  *
C* in the attribute diagram.  They are specified in clockwise order of	*
C* their appearance in the diagram:  vertical sample climatological	*
C* frequency line, perfect reliability line, skill/no-skill line, and   *
C* horizontal sample climatological frequency line.			*
C* If the number of specifications is less than the number expected (4),*
C* the input sequence will be repeated to fill the internal arrays.	*
C*									*
C* The ADLINE control file input must be of the form:			*
C*									*
C*      col1;col2;.../typ1;typ2.../wid1;wid2...                         *
C*									*
C* In general, lines are turned off by specifying color = 0.		*
C* 0 for line type results in 2; while, width will use a default value  *
C* of 1.								*
C*									*
C* PLT_ADLN  ( LINE, IRET )						*
C*									*
C* Input parameters:							*
C*	LINE 		CHAR*		LINE input			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC      20070122   Created from PLT_ILIN			*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*) 	line
C*
	CHARACTER	group (3)*60
C------------------------------------------------------------------------
	iret = 0
	nexp = 4
C
C*	Break list into three groups.
C
	CALL ST_CLST  ( line, '/', '1', 3, group, ng, ier )
C
C*      Decode color, type, width and label parts
C
	CALL ST_ILST ( group (1), ';', 0, nexp, iadlnc, nclr, ier )
        CALL ST_ILST ( group (2), ';', 0, nexp, iadlnt, ntyp, ier )
        CALL ST_ILST ( group (3), ';', 0, nexp, iadlnw, nwid, ier )
C
C*	Set defaults for no entry.
C
	IF  ( nclr .eq. 0 )  THEN
	    nclr       = 1
	    iadlnc  (1) = 1
	END IF
	IF  ( ntyp .eq. 0 )  THEN
	    ntyp       = 1
	    iadlnt  (1) = 2
	END IF
	IF  ( nwid .eq. 0 )  THEN
	    nwid       = 1
	    iadlnw (1) = 1
	END IF
C
C*	Set the repeated width patterns to fill buffer.
C
	IF  ( nwid .lt. nexp )  THEN
	    DO  i = nwid + 1, nexp
		j = MOD ( i-1, nwid ) + 1 
		iadlnw (i) = iadlnw ( j )
	    END DO
	END IF
C
C*      Repeat dash type pattern to fill buffer if necessary.
C
	IF  ( ntyp .lt. nexp )  THEN
	    DO  i = ntyp + 1, nexp
		iadlnt  (i) = iadlnt  ( MOD ( i-1, ntyp ) + 1 )
	    END DO
        END IF
C
C*      Repeat color pattern to fill buffer if necessary.
C
	IF  ( nclr .lt. nexp )  THEN
	    DO  i = nclr + 1, nexp
		iadlnc  (i) = iadlnc  ( MOD ( i-1, nclr ) + 1 )
	    END DO
        END IF
C*
	RETURN
	END
