	SUBROUTINE PLT_GDEV ( iret )
C************************************************************************
C* PLT_GDEV								*
C*									*
C* This subroutine sets the graphics device in GEMPLT.  If an 		*
C* error is returned from GEMPLT, an error message is written.		*
C*									*
C* The subroutine also sets the view region.				*
C*									*
C* PLT_GDEV ( IRET )							*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*				 	 -2 = invalid device specified	*
C*					-10 = cannot set view region	*
C**									*
C* Log:									*
C* M. desJardins/GSFC	 2/85						*
C* K. Brill/EMC		12/97	Copied GG_SDEV				*
C* K. Brill/EMC		 1/99	Added TX for text dumps			*
C* K. Brill/HPC		 9/00	CALL GSTANM				*
C* K. Brill/HPC		 3/03	CALL PLT_GSCR				*
C* K. Brill/HPC          6/08   GEPLOT and GCLEAR after PLT_GSCR	*
C* K. Brill/HPC      20120420   Open file for box-whisker (bxw) text	*
C* K. Brill/HPC      20120423   Use "fvs" as default file names		*
C* K. Brill/WPC      20130320   RETURN if device is not valid		*
C* K. Brill/WPC      20130530   Open text file for append if CLEAR=NO;  *
C*				increase file name sizes		*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER	carr (4)*128, ddev*80, filnam*128, ctype*1
	CHARACTER	filbxw*128
	CHARACTER	cerr*8, errstr*32
	REAL		xyarr (2)
	DATA		RMISSD / -9999. /
C-----------------------------------------------------------------------
	iret = 0
C
C*	Parse device string into components and translate into numbers.
C
	CALL ST_CLST ( devstr, '|', ' ', 4, carr, num, ier ) 
C
	CALL ST_LCUC ( carr (1), ddev, ier )
C
C*	Check for blank file/window name. Set a default based
C*	on the device type.
C
	filnam = carr (2)
	IF  ( filnam .eq. ' ' )  THEN
	    IF  ( ddev .eq. 'XW'  )  THEN
		filnam = 'fvs'
	      ELSE IF  ( ddev .eq. 'PS'  )  THEN
		filnam = 'ps.plt'
	      ELSE IF  ( ddev .eq. 'NC'  )  THEN
		filnam = 'Nmeta'
	      ELSE IF  ( ddev .eq. 'GF'  )  THEN
		filnam = 'fvs.gif'
	      ELSE IF  ( ddev .eq. 'PSC' )  THEN
		filnam = 'psc.plt'
	      ELSE IF  ( ddev .eq. 'PS1' )  THEN
		filnam = 'ps1.plt'
	      ELSE IF  ( ddev .eq. 'PSP' )  THEN
		filnam = 'psp.plt'
	      ELSE IF  ( ddev .eq. 'TX' ) THEN
		filnam = 'txt.dmp'
	    END IF
	END IF
	CALL ST_LSTR ( filnam, lnth, ier )
	filbxw = filnam (1:lnth) // '_bxw'
	IF ( ddev .eq. 'TX' .and. lclear ) THEN
C
C*	    Open new files.
C
	    luntxt = 51
	    OPEN ( UNIT = 51, FILE = filnam, IOSTAT =ios )
	    IF ( ios .ne. 0 ) THEN
		iret = -22	
		RETURN
	    END IF
	    lunbxw = 52
	    OPEN ( UNIT = 52, FILE = filbxw, IOSTAT =ios )
	    IF ( ios .ne. 0 ) THEN
		iret = -41	
		RETURN
	    END IF
	    RETURN
	ELSE IF ( ddev .eq. 'TX' ) THEN
C
C*	    Try to open old files and position file pointers
C*	    for appending.
C
	    luntxt = 51
	    OPEN ( UNIT = 51, FILE = filnam, STATUS = "OLD",
     +		   IOSTAT =iosx )
	    IF ( iosx .ne. 0 ) THEN
C
C*		If not an OLD file, OPEN as a new file.
C
	        OPEN ( UNIT = 51, FILE = filnam, IOSTAT =ios )
	        IF ( ios .ne. 0 ) THEN
		    iret = -22	
		    RETURN
	        END IF
	    END IF
            DO WHILE ( iosx .eq. 0 )
                READ (51,'(A1)', IOSTAT=iosx) ctype
            END DO
C*
	    lunbxw = 52
	    OPEN ( UNIT = 52, FILE = filbxw, STATUS = "OLD",
     +		   IOSTAT =iosx )
	    IF ( iosx .ne. 0 ) THEN
C
C*		If not an OLD file, OPEN as a new file.
C
	        OPEN ( UNIT = 52, FILE = filbxw, IOSTAT =ios )
	        IF ( ios .ne. 0 ) THEN
		    iret = -41	
		    RETURN
	        END IF
	    END IF
            DO WHILE ( iosx .eq. 0 )
                READ (52,'(A1)', IOSTAT=iosx) ctype
            END DO
	    RETURN
	END IF
C
	CALL ST_RLST ( carr(3), ';', RMISSD, 2, xyarr, num, ier )
	IF  ( ddev .eq. 'PSP' )  THEN
	    xsize = 8.5
	    ysize = 11.0
	  ELSE IF  ( ( ddev .eq. 'PSC' ) .or.
     +		     ( ddev .eq. 'PS1' ) )  THEN
	    xsize = 11.0
	    ysize = 8.5
	  ELSE
	    xsize = xyarr (1)
	    ysize = xyarr (2)
	    IF ( xsize .lt. 0 ) THEN
		xsize = 700
	    END IF
	    IF ( ysize .lt. 0 ) THEN
		ysize = 700
	    END IF
	END IF
C
	IF  ( ddev .eq. 'PSC' )  THEN
	    ctype = 'C'
	  ELSE IF  ( ddev .eq. 'PS1' )  THEN
	    ctype = 'M'
	  ELSE IF  ( ddev .eq. 'PSP' )  THEN
	    ctype = 'G'
	  ELSE
	    CALL ST_LCUC ( carr(4), ctype, ier )
	END IF
	itype = 1
	IF  ( ctype .eq. 'M'   )  THEN
	    itype = 0
	  ELSE IF  ( ctype .eq. 'C'   )  THEN
	    itype = 2
	END IF
C
C*	Reset PSC, PS1 and PSP to PS.
C
	IF  ( ( ddev .eq. 'PSC' ) .or.
     +	      ( ddev .eq. 'PS1' ) .or.
     +	      ( ddev .eq. 'PSP' ) )  ddev = 'PS'
C
C*	Set device in GEMPLT.
C
	iunit = 1
	CALL GSDEVA ( ddev, iunit, filnam, itype, xsize, ysize, ier )
	IF ( ier .ne. 0 ) THEN
	    CALL ST_INCH ( ier, cerr, iero )
	    errstr = 'RETURN CODE FROM GPLT = ' // cerr
	    iret = -2
	    CALL PLT_ERRO ( iret, errstr, iero )
	    CALL PLT_ERRO ( iret, 'Invalid device', iero )
	    RETURN
	END IF
C
C*	Parse and set user defined colors.
C
	IF ( colors .ne. ' ' ) THEN
	    CALL PLT_GSCR ( colors, ier )
	    CALL GEPLOT ( ier )
	END IF
C
C*	Clear device.
C
	CALL GSTANM ( ier )
	IF ( lclear ) CALL GCLEAR ( ier )
C
C*	Set view region.
C
	CALL GSVIEW  ( view (1), view (2), view (3), view (4), ier )
	IF  ( ier .ne. 0 )  THEN
	    iret = -10
	    errstr = ' Cannot set view region'
	    CALL PLT_ERRO ( iret, errstr, iero )
	END IF
C*
	RETURN
	END
