	SUBROUTINE PLT_GREF  ( iret )
C************************************************************************
C* PLT_GREF								*
C*									*
C* This subroutine draws the user-defined reference line.		*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	REFLIN = x1,y1;x2,y2;...;xN,yN/color/type/width			*
C*									*
C* PLT_GREF  ( IRET )							*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-14 = GEMPLT error		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/03						*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	REAL		x (2), y (2)
	LOGICAL		ok
C*
C------------------------------------------------------------------------
	iret = 0
	IF ( nulpts .eq. 0 ) RETURN
C
C*	Find graph bounds.
C
	CALL GQBND ( 'M', x (1), y (1), x (2), y (2), ierrg )
C*
	IF ( ierrg .ne. 0 ) THEN
	    iret = -14
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Check for points out of bounds.
C
	IF ( x (1) .lt. 0 ) THEN
	    x (1) = 1.01 * x (1)
	ELSE
	    x (1) = 0.99 * x (1)
	END IF
	IF ( x (2) .gt. 0 ) THEN
	    x (2) = 1.01 * x (2)
	ELSE
	    x (2) = 0.99 * x (2)
	END IF
	IF ( y (1) .lt. 0 ) THEN
	    y (1) = 1.01 * y (1)
	ELSE
	    y (1) = 0.99 * y (1)
	END IF
	IF ( y (2) .gt. 0 ) THEN
	    y (2) = 1.01 * y (2)
	ELSE
	    y (2) = 0.99 * y (2)
	END IF
	ok = .true.
	i = 0
	DO WHILE ( ok .and. i .lt. nulpts )
	    i = i + 1
	    ok = ( rulxvl (i) .ge. x (1) .and. rulxvl (i) .le. x (2) )
	    ok = ok .and.
     +           ( rulyvl (i) .ge. y (1) .and. rulyvl (i) .le. y (2) )
	END DO
C*
	IF ( .not. ok ) THEN
	    ierrg = +13
	    WRITE (6,*) ' Valid coordinate bounds are (', x(1), ', ',
     +	                y(1), ') to (', x(2), ', ', y(2), ').'
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Set line attributes.
C
	CALL GSLINE ( iuldsh, 0, iulwth, 0, ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Save current color number.
C
	CALL GQCOLR ( iclrsv, ier )
C
C*	Set the color.
C
	CALL GSCOLR ( iulclr, ier )
C
C*	Draw the reference line.
C
	CALL GLINE ( 'M', nulpts, rulxvl, rulyvl, ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	END IF
C
C*	Restore original color number.
C
	CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
