	SUBROUTINE PLT_GSCT ( mp, mt, trc, xpts, npts, iret )
C************************************************************************
C* PLT_GSCT								*
C*									*
C* This subroutine draws a scatter plot given two traces.		*
C*									*
C* PLT_GSCT  ( MP, MT, TRC, XPTS, NPTS, IRET )				*
C*									*
C* Marker number one is used to denote points on the scatter plot.	*
C*									*
C* The elements of the LINE common data structure determine if the	*
C* perfect regression line and the least squares linear regression	*
C* lines are drawn.  The user input for LINE has the following result:	*
C*									*
C*	0;0/...		Draw no regression lines			*
C*  1/... or 1;0/...    Draw only the perfect regression line		*
C*	0;1/...		Draw only the linear regression line		*
C*	1;1/...		Draw both lines					*
C*									*
C* The default settings will result in both lines being drawn.		*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points	*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 6/98	Check for missing values; display means *
C* K. Brill/EMC		 4/99	Reverse coordinate changes		*
C* K. Brill/HPC		01/00	Add HARDWR to PLT_GTXT call		*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C*
	REAL		trc (mp,mt), xpts (mp,mt)
	INTEGER		npts (*)
C*
	REAL		xdrw (2), ydrw (2)
	CHARACTER	ctxt*16, crho*12
	LOGICAL		ERMISS, CHECK, equal, hardwr
C*
	CHECK (x,y) = ( ABS ( x - y ) .lt. .00001)
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*------------------------------------------------------------------------
	iret = 0
	IF ( revers ) THEN
	    WRITE (6,*) ' Reversed coordinate scatter plot not allowed.'
	    RETURN
	END IF
C
C*	Initialize sums for linear regression.
C
	isum = 0
	sx = 0.0
	sx2 = 0.0
	sy = 0.0
	sy2 = 0.0
	sxy = 0.0
C*
	it1 = 1
	it2 = 2
	ip1 = 0
	ip2 = 0 
	np1 = 1
	np2 = 1
	itmax = MAX ( npts (1), npts (2) )
	iter = 0
	DO WHILE ( iter .lt. itmax )
	    iter = iter + 1
C
C*	    Establish which trace begins first.  Run the first one up to
C*	    a common starting point.  Repeat thru traces until done.
C
	    IF ( .not. CHECK ( xpts (np1,1), xpts (np2,2) ) ) THEN
		IF ( xpts (np1,1) .lt. xpts (np2,2) ) THEN
		    it1 = 1
		    it2 = 2
		    ip1 = np1
		    ip2 = np2
		ELSE
		    it1 = 2
		    it2 = 1
		    ip1 = np2
		    ip2 = np1
		END IF
		icnt = 0
		equal = .false.
		DO WHILE ( .not. equal .and. ip1 .lt. npts (it1) )
		    ip1 = ip1 + 1
		    icnt = icnt + 1
		    equal = CHECK ( xpts (ip1,it1), xpts (ip2,it2) )
		    IF ( xpts (ip1,it1) .gt. xpts (ip2,it2) ) THEN
C
C*			Switch traces.
C
			IF ( it1 .eq. 1 ) np1 = np1 + icnt
			IF ( it1 .eq. 2 ) np2 = np2 + icnt
			IF ( np1 .gt. npts (1) ) np1 = npts (1)
			IF ( np2 .gt. npts (2) ) np2 = npts (2)
			itsv = it1
			it1 = it2
			it2 = itsv
			ipsv = ip1
			ip1 = ip2
			ip2 = ipsv
			icnt = 0
		    END IF
		END DO
		IF ( it1 .eq. 1 ) np1 = np1 + icnt
		IF ( it1 .eq. 2 ) np2 = np2 + icnt
		IF ( np1 .gt. npts (1) ) np1 = npts (1)
		IF ( np2 .gt. npts (2) ) np2 = npts (2)
	    ELSE
		equal = .true.
		ip1 = np1
		ip2 = np2
		it1 = 1
		it2 = 2
	    END IF
	    is1 = ip1
	    is2 = ip2
	    icnt = 0
	    DO WHILE ( equal .and. ( ip1 .lt. npts (it1) .and.
     +		        	   ip2 .lt. npts (it2) ) )
C
C*		Find range through a stretch of equal points.
C
		ip1 = ip1 + 1
		ip2 = ip2 + 1
		icnt = icnt + 1
		equal = CHECK ( xpts (ip1,it1), xpts (ip2,it2) )
	    END DO
C
C*		Plot those points.
C
	    ie1 = ip1 - 1
	    ie2 = ip2 - 1
	    np = ie1 - is1 + 1
	    IF ( it1 .eq. 1 .and. np .gt. 0 ) THEN
		CALL PLT_GMRK  ( 1, 'M', np, trc (is1,it1),
     +				 trc (is2,it2), iret )
		DO iq = 1, np
		    ix = is1 + iq - 1
		    iy = is2 + iq - 1
		    IF ( .not. ERMISS ( trc (ix,it1) ) .and.
     +			 .not. ERMISS ( trc (iy,it2) ) ) THEN
			isum = isum + 1
			sx = sx + trc (ix,it1)
			sx2 = sx2 + trc (ix,it1) * trc (ix,it1)
			sy = sy + trc (iy,it2)
			sy2 = sy2 + trc (iy,it2) * trc (iy,it2)
			sxy = sxy + trc (ix,it1) * trc (iy,it2)
		    END IF
		END DO
	    ELSE IF ( np .gt. 0 ) THEN
		CALL PLT_GMRK  ( 1, 'M', np, trc (is2,it2),
     +				 trc (is1,it1), iret )
		DO iq = 1, np
		    ix = is2 + iq - 1
		    iy = is1 + iq - 1
		    IF ( .not. ERMISS ( trc (ix,it2) ) .and.
     +			 .not. ERMISS ( trc (iy,it1) ) ) THEN
			isum = isum + 1
			sx = sx + trc (ix,it2)
			sx2 = sx2 + trc (ix,it2) * trc (ix,it2)
			sy = sy + trc (iy,it1)
			sy2 = sy2 + trc (iy,it1) * trc (iy,it1)
			sxy = sxy + trc (ix,it2) * trc (iy,it1)
		    END IF
		END DO
	    END IF
C
C*	    Increment trace counters.
C
	    np1 = np1 + icnt
	    np2 = np2 + icnt
	    IF ( np1 .gt. npts (1) ) np1 = npts (1)
	    IF ( np2 .gt. npts (2) ) np2 = npts (2)
	END DO
C
C*	Plot last point, if ok.
C
	IF ( CHECK ( xpts (np1,1), xpts (np2,2) ) ) THEN
	    CALL PLT_GMRK  ( 1, 'M', 1, trc (np1,1),
     +			     trc (np2,2), iret )
	    IF ( .not. ERMISS ( trc (np1,1) ) .and.
     +		 .not. ERMISS ( trc (np2,2) ) ) THEN
		isum = isum + 1
		sx = sx + trc (np1,1)
		sx2 = sx2 + trc (np1,1) * trc (np1,1)
		sy = sy + trc (np2,2)
		sy2 = sy2 + trc (np2,2) * trc (np2,2)
		sxy = sxy + trc (np1,1) * trc (np2,2)
	    END IF
	END IF
C*
	IF ( ilcolr (1) .eq. 0 .and. ilcolr (2) .eq. 0 ) THEN
	    RETURN
	ELSE
	    CALL GQBND ( 'M', x1, y1, x2, y2, ierrg )
	    IF ( ierrg .ne. 0 ) THEN
		CALL PLT_PERR ( ierrg, iret )
		RETURN
	    END IF
	END IF
C*
	IF ( ilcolr (1) .ne. 0 ) THEN
C
C*	    Plot perfect regression line.
C
	    xdrw (1) = x1
	    xdrw (2) = x2
	    ydrw (1) = y1
	    ydrw (2) = x2 + ( y1 - x1 )
	    CALL PLT_GLIN ( 1, 'M', 2, xdrw, ydrw, ier )
	END IF
C*
	IF ( ilcolr (2) .ne. 0 .and. isum .ne. 0 ) THEN
C
C*	    Plot least squares regression line.
C
	    rn = FLOAT (isum)
	    rmnx = sx / rn
	    rmny = sy / rn
C*
	    dd = SQRT ( ( rn * sx2 - sx * sx ) *
     +			( rn * sy2 - sy * sy ) )
	    IF ( dd .ne. 0 ) THEN
	    	rho = ( rn * sxy - sx * sy ) / dd
	    ELSE
		rho = 1.0
	    END IF
C*
	    dd = ( rn * sx2 - sx * sx )
C*
	    IF ( dd .ne. 0 ) THEN
	    	alpha = ( rn * sxy - sx * sy ) / dd
		beta = ( sy - alpha * sx ) / rn
		xdrw (1) = x1
		xdrw (2) = x2
		ydrw (1) = alpha * x1 + beta
		ydrw (2) = alpha * x2 + beta
		WRITE (6,111) ' Regression line slope = ', alpha
		WRITE (6,111) ' Regression line intercept = ', beta
111		FORMAT (A,1PE13.5)
	    ELSE
		xntrcp = sx / rn
		xdrw (1) = xntrcp
		xdrw (2) = xntrcp
		ydrw (1) = y1
		ydrw (2) = y2
		WRITE (6,*) ' Regression line slope is infinite.'
	    END IF
C*
	    CALL PLT_GLIN ( 2, 'M', 2, xdrw, ydrw, ier )
C
C*	    Display the correlation coefficient and means.
C
	    WRITE (crho,'(F8.4)') rho
	    ctxt = 'CORR = ' // crho
	    CALL PLT_GTXT ( tcslab, hardwr, ier )
	    CALL GTRANS ( 'M', 'V', 1, x1, y2, xv, yv, ier )
	    CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 7, ierrg )
	    WRITE (crho, '(1PE10.3)') rmnx
	    ctxt = 'XAV = ' // crho
	    CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 4, ierrg )
	    WRITE (crho, '(1PE10.3)') rmny
	    ctxt = 'YAV = ' // crho
	    CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 1, ierrg )
	    IF ( ierrg .ne. 0 ) THEN
		CALL PLT_PERR ( ierrg, iret )
		RETURN
	    END IF
	END IF
C*
	RETURN
	END
