	SUBROUTINE PLT_IBTX  ( uinpt, iret )
C************************************************************************
C* PLT_IBTX								*
C*									*
C* This subroutine processes control information for box-whisker	*
C* annotation text box.							*
C* 									*
C* The control file entry is formatted as follows:			*
C*									*
C*      B_TEXT = color/[#]x;y/size;font;width;HWSW/flag			*
C*									*
C* The color number determines the color to use for all the elements	*
C* comprising the box-whisker annotation text display.  The x;y		*
C* coordinates give the position of the lower-left corner of the	*
C* annotation box as fractions left-to-right and bottom-to-top,		*
C* respectively, of the viewable plotting domain unless preceded by 	*
C* "#", in which case x and y are given in graph coordinates.  The	*
C* size;font;width;HWSW are inputs controlling the text used.  The flag *
C* has a yes or no input, where yes causes the text to be enclosed by a *
C* box.									*
C*									*
C* This subroutine sets the variables in the BXWBTX common block.	*
C*									*
C* PLT_IBTX  ( UINPT, IRET )						*
C*									*
C* Input parameters:							*
C*	UINPT		CHAR*		B_TEXT input			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC      20120607	Created					*
C* K. Brill/HPC      20120618   Completed first version			*
C* K. Brill/HPC      20120622   Changes to build IN_TEXT input string	*
C* K. Brill/HPC      20120626   Set corner point to missing if not given*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1 )
C*
	CHARACTER*(*)	uinpt
C*
	CHARACTER	group (4)*60, cfont (4)*32, cstr*60
	REAL		xy (2)
C*
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
C
C*	Break list into four groups.
C
	CALL ST_CLST  ( uinpt, '/', ' ', 4, group, ng, ier )
C
C*	Get the color number.
C
	IF ( group (1) .eq. ' ' ) THEN
	    itxclr = 0
	ELSE
	    CALL ST_NUMB ( group (1), itxclr, ier )
	    IF ( ier .ne. 0 .or. itxclr .lt. 0 ) THEN
	        itxclr = 0
	        bxbflg = .false.
	        RETURN
	    END IF
	END IF
C
C*	Get the box position:
C
	ipos = INDEX ( group (2), '#' )
	cstr = group (2) (ipos+1:)
        CALL ST_RLST ( cstr, ';', RMISSD, 2, xy, np, ier )
	IF ( np .eq. 2 .and. .not. ERMISS (xy(1)) .and.
     +	     .not. ERMISS (xy(2)). and. ier .eq. 0 ) THEN
	    xlltbx = xy(1)
	    ylltbx = xy(2)
	    lgctbx = ipos .gt. 0
	ELSE
	    xlltbx = RMISSD
	    ylltbx = RMISSD
	END IF
C
C*	Assign the text attributes string in the form of input
C*	for IN_TEXT.
C
C*      B_TEXT = color/[#]x;y/ size;font;width;HWSW /flag
C*                             --------------------
C
	CALL ST_CLST  ( group (3), ';', ' ', 4, cfont, nf, ier )
	tcsbxw = ' '
	ierrs = 0
	CALL ST_CRNM ( cfont (1), vvv, ierr )
	IF ( cfont (1) .ne. ' ' ) ierrs = ierrs + ierr
	IF ( cfont (1) .eq. ' ' .or. ierr .ne. 0 ) THEN
	    tcsbxw = '1'
	    lng = 1
	ELSE
	    CALL ST_LSTR ( cfont (1), lng, ier )
	    tcsbxw = cfont (1) (1:lng)
	END IF
	DO i = 2, 3
	    CALL ST_CRNM ( cfont (i), vvv, ierr )
	    IF ( cfont (i) .ne. ' ' ) ierrs = ierrs + ierr
	    IF ( cfont (i) .eq. ' ' .or. ierr .ne. 0 ) THEN
		tcsbxw = tcsbxw (1:lng) // '/1'
		lng = lng + 2
	    ELSE
	        CALL ST_LSTR ( cfont (i), ln, ier )
		tcsbxw = tcsbxw (1:lng) // '/' // cfont (i) (1:ln)
		lng = lng + 1 + ln
	    END IF
	END DO
	CALL ST_CRNM ( cfont (4), vvv, ierr )
	IF ( ierr .eq. 0 ) THEN
	    ierr = -1
	ELSE
	    ierr = 0
	END IF
	IF ( cfont (4) .ne. ' ' ) ierrs = ierrs + ierr
	IF ( cfont (4) .eq. ' ' .or. ierr .ne. 0 ) THEN
	    tcsbxw = tcsbxw (1:lng) // '/SW'
	    lng = lng + 3
	ELSE
	    CALL ST_LSTR ( cfont (4), ln, ier )
	    tcsbxw = tcsbxw (1:lng) // '/' // cfont (4) (1:ln)
	    lng = lng + 1 + ln
	END IF
	IF ( ierrs .ne. 0 ) THEN
	    WRITE (6,*) ' '
	    WRITE (6,*) ' Input for B_TEXT is erroneous.  Defaults ',
     +			' used as appropriate.'
	    WRITE (6,*) ' '
	END IF
C
C*	Assign the flag for the annotation box:
C
	cstr = " "
	bxbflg = .true.
        CALL ST_LCUC ( group(4), cstr, ier )
        IF ( INDEX ( cstr, 'N' ) .ne. 0 .or.
     +       INDEX ( cstr, 'F' ) .ne. 0 ) bxbflg = .false.
C
C*	Append border/rotation/justification specifications to the
C*	text specification for IN_TEXT.
C
	IF ( bxbflg ) THEN
	    tcsbxw = tcsbxw (1:lng) // '/211/0/L'
	ELSE
	    tcsbxw = tcsbxw (1:lng) // '/111/0/L'
	END IF
C*
	RETURN
	END
