	SUBROUTINE PLT_IBXW  ( cbxw, nbxt, iret )
C************************************************************************
C* PLT_IBXW								*
C*									*
C* This subroutine converts the input for the BXWSKR variable into a	*
C* list of colors, line widths, the two-sided significance level for	*
C* computing the box half-length, the yes/no flag to draw the whiskers,	*
C* and the yes/no flag to shift the objects half a box width to the	*
C* right.								*
C*									*
C* If the number of specifications is less than the number expected,	*
C* the input sequence will be repeated to fill the internal arrays.	*
C*									*
C* The LINE control file input must be of the form:			*
C*									*
C*          col1;col2;.../wid1;wid2/alpha/wskflg/bxshft			*
C*									*
C* In general, lines are turned off by specifying color = 0.  Zero (0)	*
C* for line width will default to the value of 1.  Other defaults are	*
C* as follows:								*
C*									*
C*		alpha = .05						*
C*		wskflg = no						*
C*		bxshft = no						*
C*									*
C* If wskflg = no, no whiskers are drawn, only error bars.		*
C*									*
C* PLT_IBXW  ( LINE, NBXT, IRET )					*
C*									*
C* Input parameters:							*
C*	LINE 		CHAR*		LINE input			*
C*	NBXT		INTEGER         Number expected			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/12	Created from IN_LINE			*
C* K. Brill/HPC      20120330	Added wskflg				*
C* K. Brill/HPC      20120402	Set bxwfnd back to false for 0		*
C* K. Brill/HPC      20120416   Set bxshft				*
C* K. Brill/HPC      20130314   Detect box-whisker error # 9		*
C* K. Brill/IMSG     20150521   Change wskflg default from yes to no    *
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*) 	cbxw
C*
	CHARACTER	group (5)*60, cflag*60
	INTEGER		ibxsv (MAXLIN)
	LOGICAL		lt0
C------------------------------------------------------------------------
	iret = 0
	nexp = nbxt
C
C*	If the input is blank, RETURN.
C
	IF ( cbxw .eq. ' ' ) THEN
	    bxwfnd = .false.
	    RETURN
	END IF
C
C*	Prepare to detect box-whisker error # 9 by saving
C*      the box color flags in case some have been set to -1.
C
	DO i = 1, MAXLIN
	    ibxsv (i) = ibxclr (i)
	END DO
C*
	IF ( nexp .le. 0 ) nexp = 1
C
C*	Break list into three groups.
C
	CALL ST_CLST  ( cbxw, '/', '1', 5, group, ng, ier )
C
C*      Decode color, type, width and label parts
C
	CALL ST_ILST ( group (1), ';', 0, MAXLIN, ibxclr, nclr, ier )
        CALL ST_ILST ( group (2), ';', 0, MAXLIN, ibxlwd, nwid, ier )
C
C*	Set defaults for no entry.
C
	IF  ( nclr .eq. 0 )  THEN
	    nclr       = 1
	    ibxclr  (1) = 1
	END IF
	IF  ( nwid .eq. 0 )  THEN
	    nwid       = 1
	    ibxlwd (1) = 1
	END IF
C
C*	Set the repeated width patterns to fill buffer.
C
	IF  ( nwid .lt. nexp )  THEN
	    DO  i = nwid + 1, nexp
		j = MOD ( i-1, nwid ) + 1 
		ibxlwd (i) = ibxlwd ( j )
	    END DO
	END IF
C
C*      Repeat color pattern to fill buffer if necessary.
C
	IF  ( nclr .lt. nexp )  THEN
	    DO  i = nclr + 1, nexp
		ibxclr  (i) = ibxclr  ( MOD ( i-1, nclr ) + 1 )
	    END DO
        END IF
C
C*	Detect box-whisker error number 9.
C
	ii = 0
	lt0 = .false.
	DO WHILE ( .not. lt0 .and. ii .lt. MAXLIN )
	    ii = ii + 1
	    lt0 = ibxsv (ii) .lt. 0 .and. ibxclr (ii) .ne. 0
	END DO
	IF ( lt0 ) THEN
	    nbxerr = nbxerr + 1
	    IF ( nbxerr .le. MAXERR ) THEN
		ibxerr (nbxerr) = 9
	    END IF
	END IF
C
C*	Set the flag for box-whisker objects:
C
	bxwflg = .false.
C
C*	Check for all zero color numbers:
C
	i = 0
	DO WHILE ( .not. bxwflg .and. i .lt. nexp )
	    i = i + 1
	    bxwflg = ibxclr (i) .gt. 0
	END DO
	IF ( .not. bxwflg ) THEN
	    bxwfnd = .false.
	    RETURN
	END IF
C
C*	Get the significance test level probability.
C
	CALL ST_CRNM ( group(3), val, ier )
	IF ( ier .eq. 0 .and. val .gt. 0 .and. val .lt. 1.0 ) THEN
	    bxplvl = val
	    IF ( val .le. 0. .or. val .ge. 1. ) THEN
	        bxplvl = .05
	        WRITE (6,*)
	        WRITE (6,*)
     +          ' Invalid entry--using default test level = .05 for',
     +		' resampling.'
	        WRITE (6,*)
	    END IF
	ELSE
	    bxplvl = .05
	    WRITE (6,*)
	    WRITE (6,*)
     +      ' Using default test level = .05 for resampling.'
	    WRITE (6,*)
	END IF
C
C*	Set the whisker drawing flag.
C
	wskflg = .true.
	CALL ST_LCUC ( group(4), cflag, ier )
	IF ( INDEX ( cflag, 'N' ) .ne. 0 .or.
     +	     INDEX ( cflag, 'F' ) .ne. 0 ) wskflg = .false.
C
C*	Set the flag to shift the box-whisker objects half a box to the
C*      right.
C
	bxshft = .false.
	CALL ST_LCUC ( group(5), cflag, ier )
	IF ( INDEX ( cflag, 'Y' ) .ne. 0 .or.
     +	     INDEX ( cflag, 'T' ) .ne. 0 ) bxshft = .true.
C*
	RETURN
	END
