	SUBROUTINE PLT_IMRK  ( marker, numtrc, iret )
C************************************************************************
C* PLT_IMRK								*
C*									*
C* This subroutine decodes control information for trace markers.	*
C* 									*
C* The control file entry is formatted as follows:			*
C*									*
C*	MARKER = Marker colors/types/sizes/widths			*
C*									*
C* The marker size is a real number which is a multiplier for the	*
C* base marker size.  If the size is 0.0, the current size will be 	*
C* used.  If the marker color is 0, no marker will be drawn.  If	*
C* the marker color is blank, color number 1 will be used.  If 		*
C* the marker number is missing or 0, the current marker number		*
C* will be used.  The marker color, type, size and width are set in	*
C* in the internal data structure.					*
C*									*
C* The pattern of colors, types, size, or widths will be repeated to	*
C* to make NUMTRC entries if the number provided is less than NUMTRC.	*
C*									*
C* PLT_IMRK  ( MARKER, NUMTRC, IRET )					*
C*									*
C* Input parameters:							*
C*	MARKER		CHAR*		Marker input			*
C*	NUMTRC		INTEGER		Number of markers needed	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98	Created from IN_LINE			*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*)	marker
C*
	CHARACTER	group (4)*60
C------------------------------------------------------------------------
	iret = 0
	nexp = numtrc
C
C*	Break list into four groups.
C
	CALL ST_CLST  ( marker, '/', '1', 4, group, ng, ier )
C
C*      Decode color, type, width and label parts
C
	CALL ST_ILST ( group (1), ';', 0, nexp, imcolr, nclr, ier )
        CALL ST_ILST ( group (2), ';', 0, nexp, imtype, ntyp, ier)
        CALL ST_RLST ( group (3), ';', 0, nexp, rmsize, nsiz, ier)
        CALL ST_ILST ( group (4), ';', 0, nexp, imwdth, nwid, ier)
C
C*	Set defaults for no entry.
C
	IF  ( nclr .eq. 0 )  THEN
	    nclr       = 1
	    imcolr (1) = 0
	END IF
	IF  ( ntyp .eq. 0 )  THEN
	    ntyp       = 1
	    imtype (1) = 1
	END IF
	IF  ( nsiz .eq. 0 )  THEN
	    nsiz       = 1
	    rmsize (1) = 1.0
	END IF
	IF  ( nwid .eq. 0 )  THEN
	    nwid       = 1
	    imwdth (1) = 1
	END IF
C
C*      Repeat pattern to fill buffer if necessary.
C
	IF  ( nclr .lt. nexp )  THEN
	    DO  i = nclr + 1, nexp
		imcolr  (i) = imcolr  ( MOD ( i-1, nclr ) + 1 )
	    END DO
        END IF
	IF  ( ntyp .lt. nexp )  THEN
	    DO  i = ntyp + 1, nexp
		imtype  (i) = imtype  ( MOD ( i-1, ntyp ) + 1 )
	    END DO
        END IF
	IF  ( nsiz .lt. nexp )  THEN
	    DO  i = nsiz + 1, nexp
		rmsize  (i) = rmsize  ( MOD ( i-1, nsiz ) + 1 )
	    END DO
        END IF
	IF  ( nwid .lt. nexp )  THEN
	    DO  i = nwid + 1, nexp
		imwdth  (i) = imwdth  ( MOD ( i-1, nwid ) + 1 )
	    END DO
        END IF
C*
	RETURN
	END
