	SUBROUTINE PLT_IREF ( string, iret )
C************************************************************************
C* PLT_IREF								*
C*									*
C* This subroutine sets the user input for a user-defined reference	*
C* line.								*
C*									*
C* The reference line input is given in the following form:		*
C*									*
C*      REFLIN = X1,Y1;X2,Y2;...;Xn,Yn/ICOLOR/ITYPE/IWIDTH		*
C*									*
C* where X,Y is a point on the line, ICOLOR is the line color, ITYPE	*
C* is the dashing pattern, and IWIDTH is the line width.  The number,	*
C* n, of points cannot exceed MAXUDX.  The color, dashing pattern, and	*
C* width default to 1.							*
C*									*
C* PLT_IREF  ( IRET )							*
C*									*
C* Input parameters:							*
C*	STRING		CHAR*		User input for REFLIN		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 5/03						*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*)	string
C*
	CHARACTER*24	cpair (MAXUDX)
	REAL		xy (2)
	INTEGER		ivals (3)
	LOGICAL		done
C*-----------------------------------------------------------------------
	iret = 0
	IF ( string .eq. ' ' ) THEN
	    iret = +13
	    nulpts = 0
	    RETURN
	END IF
C
C*	Find first slash separating coordinates from line info.
C
	CALL ST_LSTR ( string, lng, ier )
	islsh = INDEX ( string, '/' )
	IF ( islsh .eq. 0 ) THEN
	    iulclr = 1
	    iuldsh = 1
	    iulwth = 1
	    done = .true.
	    islsh = lng + 1
	ELSE
	    done = .false.
	END IF
C
C*	Extract coordinate points.
C
	CALL ST_CLST ( string (1:islsh-1), ';', '0', MAXUDX, cpair,
     +		       nulpts, ier )
	IF ( ier .lt. 0 .or. nulpts .le. 1 ) THEN
	    iret = +13
	    nulpts = 0
	    RETURN
	END IF
	DO i = 1, nulpts
	    CALL ST_RLST ( cpair (i), ',', 0, 2, xy, nn, ier )
	    IF ( nn .ne. 2 .or. ier .ne. 0 ) THEN
		iret = +13
		nulpts = 0
		RETURN
	    END IF
	    rulxvl (i) = xy (1)
	    rulyvl (i) = xy (2)
	END DO
C
C*	Extract line color, type, and width.
C
	IF ( .not. done ) THEN
	    CALL ST_ILST ( string (islsh+1:), '/', 1, 3, ivals, nn,
     +			   ier )
	    IF ( ier .ne. 0 ) THEN
		iret = +13
		nulpts = 0
		RETURN
	    END IF
	    IF ( nn .gt. 0 ) THEN
		iulclr = ivals (1)
		iuldsh = ivals (2)
		iulwth = ivals (3)
	    ELSE
		iulclr = 1
		iuldsh = 1
		iulwth = 1
	    END IF
	END IF
C*
	RETURN
	END
