	SUBROUTINE PLT_IRWT  ( line, iret )
C************************************************************************
C* PLT_IRWT								*
C*									*
C* This subroutine converts the input for the RWTLIN variable into a	*
C* list of colors, line types, line widths and line values.		*
C*									*
C* The LINE control file input must be of the form:			*
C*									*
C*      col1;col2;.../typ1;typ2.../wid1;wid2.../val1;val2...		*
C*									*
C* In general, lines are turned off by specifying color = 0.		*
C* 0 for line type or width will use a default value of 1.  If values	*
C* are absent, a single zero witness line will be drawn.		*
C*									*
C* PLT_IRWT  ( LINE, IRET )						*
C*									*
C* Input parameters:							*
C*	LINE 		CHAR*		LINE input			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/GSC		 3/01						*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*) 	line
C*
	CHARACTER	group (4)*60
C------------------------------------------------------------------------
	iret = 0
	IF ( line .eq. ' ' ) RETURN
	nexp = MAXLIN
C
C*	Break list into four groups.
C
	CALL ST_CLST  ( line, '/', ' ', 4, group, ng, ier )
C
C*      Decode color, type, width and label parts
C
	CALL ST_ILST ( group (1), ';', 0, nexp, ircolr, nclr, ier )
        CALL ST_ILST ( group (2), ';', 0, nexp, irdash, ntyp, ier)
        CALL ST_ILST ( group (3), ';', 0, nexp, irwdth, nwid, ier)
        CALL ST_RLST ( group (4), ';', 0, nexp, rrvals, nlab, ier)
C
C*	Set defaults for no entry.
C
	nrline = MAX ( nclr, ntyp, nwid, nlab )
	IF  ( nclr .eq. 0 )  THEN
	    nclr       = 1
	    ircolr  (1) = 1
	END IF
	IF  ( ntyp .eq. 0 )  THEN
	    ntyp       = 1
	    irdash  (1) = 1
	END IF
	IF  ( nwid .eq. 0 )  THEN
	    nwid       = 1
	    irwdth (1) = 1
	END IF
	IF  ( nlab .eq. 0 )  THEN
	    nlab       = 1
	    rrvals (1) = 0.
	END IF
C
C*	Set the repeated width patterns to fill buffer.
C
	IF  ( nwid .lt. nexp )  THEN
	    DO  i = nwid + 1, nexp
		j = MOD ( i-1, nwid ) + 1 
		irwdth (i) = irwdth ( j )
	    END DO
	END IF
C
C*      Repeat dash type pattern to fill buffer if necessary.
C
	IF  ( ntyp .lt. nexp )  THEN
	    DO  i = ntyp + 1, nexp
		irdash  (i) = irdash  ( MOD ( i-1, ntyp ) + 1 )
	    END DO
        END IF
C
C*      Repeat color pattern to fill buffer if necessary.
C
	IF  ( nclr .lt. nexp )  THEN
	    DO  i = nclr + 1, nexp
		ircolr  (i) = ircolr  ( MOD ( i-1, nclr ) + 1 )
	    END DO
        END IF
C*
	RETURN
	END
