	SUBROUTINE TI_ITOC  ( idtarr, dattim, iret )
C************************************************************************
C* TI_ITOC								*
C*									*
C* This subroutine converts an integer time array into a standard	*
C* GEMPAK time.  The integers are checked for validity.			*
C*									*
C* TI_ITOC  ( IDTARR, DATTIM, IRET )					*
C*									*
C* Input parameters:							*
C*	IDTARR (5)	INTEGER		Time array (YYYY,MM,DD,HH,MM)	*
C*									*
C* Output parameters:							*
C*	DATTIM		CHAR*		GEMPAK time			*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -7 = invalid year		*
C*					 -8 = invalid month		*
C*					 -9 = invalid day		*
C*					-10 = invalid hour		*
C*					-11 = invalid minute		*
C**									*
C* Log:									*
C* M. desJardins/GSFC	11/87	GEMPAK 4				*
C* K. Brill/EMC		 2/98	Modified for YYYYMMDDHHNN		*
C************************************************************************
	CHARACTER*(*)	dattim
	INTEGER		idtarr (*)
C*
	CHARACTER	date*8, time*4
C*
	INTEGER		jday (13)
	DATA		jday / 31,28,31,30,31,30,31,31,30,31,30,31,29 /
C------------------------------------------------------------------------
	iret   = 0
	dattim = ' '
C
C*	Put array values into variables.
C
	iyear  = idtarr (1)
	imonth = idtarr (2)
	iday   = idtarr (3)
	ihour  = idtarr (4)
	iminut = idtarr (5)
C
C*	Check for leap year.  In leap year, set month to be month 13.
C
	jmonth = imonth
	IF  ( ( jmonth .eq. 2 ) .and. ( MOD (iyear,4) .eq. 0 .and.
     +      ( MOD (iyear,100) .ne. 0 .or. MOD (iyear,400) .eq. 0 ) )
     +	    )  THEN
	    jmonth = 13
	END IF
C
C*	Check that each of these values is valid.
C
	IF  ( iyear .lt. 0 )  iret = -7
	IF  ( ( imonth .lt. 1 ) .or. ( imonth .gt. 12 ) ) iret = -8
	IF  ( ( iday   .lt. 1 ) .or. ( iday   .gt. jday (jmonth) ) ) 
     +							  iret = -9
	IF  ( ( ihour  .lt. 0 ) .or. ( ihour  .gt. 24 ) ) iret = -10
	IF  ( ( iminut .lt. 0 ) .or. ( iminut .gt. 60 ) ) iret = -11
	IF  ( iret .ne. 0 )  RETURN
C
C*	Get the date and time.
C
	idate = iyear * 10000 + imonth * 100 + iday
	itime = ihour * 100   + iminut
C
C*	Convert date and time to character strings.
C
	WRITE  ( date, 50, IOSTAT=ier )  idate
 50	FORMAT ( I8.8 )
	WRITE  ( time, 60, IOSTAT=ierr)  itime
 60	FORMAT ( I4.4 )
C
C*	Check for errors and concatenate date and time.
C
	IF  ( ( ier .ne. 0 ) .or. ( ierr .ne. 0 ) )  THEN
	    iret = -1
	  ELSE
	    dattim = date // time
	END IF
C*
	RETURN
	END
