	SUBROUTINE TI_MDIF  ( idtar1, idtar2, nmin, iret )
C************************************************************************
C* TI_MDIF								*
C*									*
C* This subroutine computes the time difference in minutes between 	*
C* two integer times.  The time difference is time1 - time2 and		*
C* may be computed for a maximum of one year.				*
C*									*
C* TI_MDIF  ( IDTAR1, IDTAR2, NMIN, IRET )				*
C*									*
C* Input parameters:							*
C*	IDTAR1 (5)	INTEGER		Time array 1 (YYYY,MM,DD,HH,MM)	*
C*	IDTAR2 (5)	INTEGER		Time array 2 (YYYY,MM,DD,HH,MM)	*
C*									*
C* Output parameters:							*
C*	NMIN		INTEGER		Difference in minutes		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*				  	+99 = invalid time range	*
C**									*
C* Log:									*
C* M. Goodman/RDS	12/85						*
C* M. desJardins/GSFC	11/87	GEMPAK 4				*
C* S. Jacobs/NCEP	 3/96	Fixed leap year calc involving Feb 29	*
C* K. Brill		10/98	+99 return code for VSDB PLT		*
C************************************************************************
	INTEGER		idtar1 (5), idtar2 (5)
C*
	INTEGER		jdtar1 (5), jdtar2 (5)
	INTEGER 	month (12)
	LOGICAL		LEAP
C*
	EQUIVALENCE	( jdtar1 (1), iyr1 ), ( jdtar2 (1), iyr2 ),
     +			( jdtar1 (2), imm1 ), ( jdtar2 (2), imm2 ),
     +			( jdtar1 (3), idd1 ), ( jdtar2 (3), idd2 ),
     +			( jdtar1 (4), ihh1 ), ( jdtar2 (4), ihh2 ),
     +			( jdtar1 (5), imin1), ( jdtar2 (5), imin2 )
C*
	LEAP (iyear) =	( ( MOD ( iyear, 4 ) .eq. 0 ) .and.
     +			  ( ( MOD ( iyear, 100 ) .ne. 0 ) .or.
     +			    ( MOD ( iyear, 400 ) .eq. 0 ) ) )
C*
	DATA		month / 31, 28, 31, 30, 31, 30, 31, 31, 30, 31,
     +				30, 31 / 
C------------------------------------------------------------------------
	iret = 0
	nmin = 0
C
C*	Move times into arrays which are equivalenced to variable names.
C
	DO  i = 1, 5
	    jdtar1 (i) = idtar1 (i)
	    jdtar2 (i) = idtar2 (i)
	END DO
C
C*	Compute julian days, checking for leap years.
C
	jdays1 = 0
	DO  i = 1, imm1-1
	    jdays1 = jdays1 + month (i)
	    IF  ( ( i .eq. 2 ) .and. LEAP (iyr1) )  jdays1 = jdays1 + 1
	END DO
	jdays1 = jdays1 + idd1
C
	jdays2 = 0
	DO  i = 1, imm2-1
	    jdays2 = jdays2 + month (i)
	    IF  ( ( i .eq. 2 ) .and. LEAP (iyr2) )  jdays2 = jdays2 + 1
	END DO
	jdays2 = jdays2 + idd2
C
	jyr = iyr2 - iyr1 
C
C*	Special case of exactly 1 year.
C
	IF ((ABS (jyr) .eq. 1) .and. (imm1 .eq. imm2) .and.
     +      (idd1 .eq. idd2) .and. (ihh1 .eq. ihh2) .and.
     +      (imin1 .eq. imin2)) THEN
	    IF ((leap1 .eq. 0) .or. (leap2 .eq. 0)) THEN
	        idif = 1440
	      ELSE
	        idif = 0
	    END IF
	    IF (iyr1 .gt. iyr2) THEN
	        nmin = 525600 + idif
	      ELSE
	        nmin = -525600 - idif
	    END IF
	    RETURN
	END IF
C
C*      Check for a time range greater than one year.
C
	IF (( jyr .gt.  1 ) .or.  ( jyr    .lt. -1 )     .or.
     +	    ( jyr .eq.  1 ) .and. ( jdays2 .gt. jdays1 ) .or.
     +	    ( jyr .eq. -1 ) .and. ( jdays1 .gt. jdays2 )) THEN
	    iret = 99
	    RETURN
	END IF
C
C*	Convert hours and minutes to total minutes.
C
	nmin1 = ihh1 * 60 + imin1
	nmin2 = ihh2 * 60 + imin2

	IF (( jdays2 .lt. jdays1 ) .and. ( iyr1 .lt. iyr2 )) THEN
	    nday = jdays2 - jdays1 + 365
	  ELSE IF (( jdays2 .gt. jdays1 ) .and. ( iyr2 .lt. iyr1 )) THEN
	    nday = jdays2 - jdays1 - 365
	  ELSE
	    nday = jdays2 - jdays1
	END IF
C	    
	IF (( nmin2 .lt. nmin1 ) .and. ( nday .gt. 0 )) THEN
	    nday = nday - 1
	    nmin = nmin2 - nmin1 + 1440
	  ELSE 
	    nmin = nmin2 - nmin1
	END IF
C
C*	Compute difference in minutes.
C
	nmin = nday * 1440 + nmin
C
C*	Change sign since it is incorrect.
C
	nmin = -nmin
C*
	RETURN
	END
