        SUBROUTINE PLT_MTAX ( cplbl, xplbl, nplbl, nxlbl, ntics,
     +			      cxlbl, cxpos, xtics, iret )
C************************************************************************
C* PLT_MTAX								*
C*									*
C* This subroutine creates the labels for a time axis.			*
C*									*
C* For monthly time labels, the day positions are marked by a tic mark,	*
C* and NTICS > 0.  For yearly time labels, the month positions are	*
C* marked by a tic mark, and NTICS > 0.  Otherwise, NTICS = 0.		*
C*									*
C* PLT_MTAX  ( CPLBL, XPLBL, NPLBL, NXLBL, NTICS,			*
C*	       CXLBL, CXPOS, XTICS, IRET )				*
C*									*
C* Input parameters:							*
C*	CPLBL (NPLBL)	CHAR*		Character axis labels		*
C*	XPLBL (NPLBL)	REAL		x positions of labels		*
C*	NPLBL		INTEGER		Number of labels		*
C*									*
C* Input and output parameter:						*
C*	NXLBL		INTEGER		Input:  maximum # of labels	*
C*					Output:  actual # of labels	*
C*	NTICS		INTEGER		Input:  maximum # of tic marks	*
C*					Output:  actual # of tic marks	*
C*									*
C* Output parameters:							*
C*	CXLBL (NXLBL)	CHAR*		Axis labels to plot		*
C*	CXPOS (NXLBL)	REAL		Label positions on axis		*
C*	XTICS (NTICS)	REAL		Tic mark positions on axis	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 +9 = start day not found	*
C**									*
C* Log:									*
C* K. Brill/EMC		10/98						*
C* K. Brill/EMC		 1/99	Do NPLBL = 1 case and RETURN		*
C* K. Brill/EMC		12/00	Fix labels for yr, mon, day, hour change*
C* K. Brill/HPC      20071002   Fix seg fault bug for single pt trace   *
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	REAL		xplbl (*), cxpos (*), xtics (*)
	CHARACTER*(*)	cplbl (*), cxlbl (*)
C*
	INTEGER		jdtm (5)
	CHARACTER*2	lmo, lda, lhr, lmn, yr, mo, da, hr, mn
	CHARACTER*4	lyr
	CHARACTER*20	cdate
	LOGICAL		yrsame, mosame, hrsame, found
C*------------------------------------------------------------------------
	iret = 0
	IF ( nplbl .eq. 1 ) THEN
	    cxlbl (1) = cplbl (1)
	    cxpos (1) = xplbl (1)
	    nxlbl = 1
	    ntics = 1
	    xtics (1) = xplbl (1)
	    RETURN
	END IF
	maxlb = nxlbl
	maxtc = ntics
	ntics = 0
	nxlbl = 0
C
C*	Labels are based on days.
C
	IF ( unttax .eq. 'D' ) THEN
	    IF ( nxaxvl .ne. 0 ) THEN
C
C*		Use existing CPLBL points to set date-times at
C*		user specified intervals (days).
C
		ilbl = 0
		i = 0
		DO WHILE ( i .lt. nxaxvl .and.
     +			   ilbl .lt. maxlb )
		    i = i + 1
		    xv = xaxval (i)
C
C*		    Find closest label less than XV.
C
		    j = 0
		    found = .false.
		    DO WHILE ( .not. found .and. j .lt. nplbl )
			    j = j +1
			    found = ( xplbl (j) .gt. xv )
		    END DO
		    j = j - 1
		    IF ( j .gt. 0 ) THEN
			ilbl = ilbl + 1
			cxpos (ilbl) = xv
			lyr = cplbl (j) (1:4)
			CALL ST_NUMB ( lyr, jdtm (1), ier )
			lmo = cplbl (j) (5:6)
			CALL ST_NUMB ( lmo, jdtm (2), ier )
			lda = cplbl (j) (7:8)
			CALL ST_NUMB ( lda, jdtm (3), ier )
			lhr = cplbl (j) (9:10)
			CALL ST_NUMB ( lhr, jdtm (4), ier )
			lmn = cplbl (j) (11:12)
			CALL ST_NUMB ( lmn, jdtm (5), ier )
			mndf = NINT ( ( xv - xplbl (j) ) * 1440. )
			CALL TI_ADDM  ( jdtm, mndf, jdtm, iret )
			CALL TI_ITOC  ( jdtm, cxlbl (ilbl), iret )
		    END IF
		END DO
		nxlbl = ilbl
	    ELSE
C
C*		Use the CPLBL labels.
C
		i = 0
		j = 0
		DO WHILE ( i .lt. nplbl .and. j .lt. maxlb )
		    i = i + 1
		    j = j + 1
		    cxlbl (j) = cplbl (i)
		    cxpos (j) = xplbl (i)
		END DO
		nxlbl = j
	    END IF
C
C*	    Prune characters from time type labels.
C
	    lyr = cxlbl (1) (3:4)
	    lmo = cxlbl (1) (5:6)
	    lda = cxlbl (1) (7:8)
	    lhr = cxlbl (1) (9:10)
	    lmn = cxlbl (1) (11:12)
	    IF ( lmn .ne. '00' ) THEN
		cxlbl (1) =
     +			lyr (1:2) // lmo // lda // '/' // lhr // lmn
	    ELSE
		cxlbl (1) = lyr (1:2) // lmo // lda // '/' // lhr
	    END IF
	    kyr = 1
    	    kmo = 1
	    kda = 1
	    khr = 1
	    DO i = 2, nxlbl
		yr = cxlbl (i) (3:4)
		mo = cxlbl (i) (5:6)
		da = cxlbl (i) (7:8)
		hr = cxlbl (i) (9:10)
		mn = cxlbl (i) (11:12)
		indx = 1
		cxlbl (i) = ' '
		IF ( lyr (1:2) .ne. yr ) THEN
			    cxlbl (i) (indx:indx+1) = yr
			    indx = indx + 2
			    yrsame = .false.
			    lyr = yr
			    kyr = 1
		ELSE IF ( kyr .lt. ilbfrx ) THEN
			    cxlbl (i) (indx:indx+1) = yr
			    indx = indx + 2
			    kyr = kyr + 1
			    yrsame = .true.
		ELSE
			    yrsame = .true.
		END IF
		IF ( lmo .ne. mo .or. .not. yrsame ) THEN
			    cxlbl (i) (indx:indx+1) = mo
			    indx = indx + 2
			    mosame = .false.
			    lmo = mo
			    kmo = 1
		ELSE IF ( kmo .lt. ilbfrx ) THEN
			    cxlbl (i) (indx:indx+1) = mo
			    indx = indx + 2
			    kmo = kmo + 1
			    mosame = .true.
		ELSE
			    mosame = .true.
		END IF
		IF ( lda .ne. da .or. .not. mosame ) THEN
			    cxlbl (i) (indx:indx+1) = da
			    indx = indx + 2
			    lda = da
			    kda = 1
		ELSE IF ( kda .lt. ilbfrx ) THEN
			    cxlbl (i) (indx:indx+1) = da
			    indx = indx + 2
			    kda = kda + 1
		END IF
		cxlbl (i) (indx:indx) = '/'
		indx = indx + 1
		IF ( lhr .ne. hr ) THEN
			    cxlbl (i) (indx:indx+1) = hr
			    indx = indx + 2
			    hrsame = .false.
			    lhr = hr
			    khr = 1
		ELSE IF ( khr .lt. ilbfrx ) THEN
			    cxlbl (i) (indx:indx+1) = hr
			    indx = indx + 2
			    khr = khr + 1
			    hrsame = .true.
		ELSE
			    hrsame = .true.
		END IF
		IF ( lmn .ne. mn ) THEN
		    IF ( hrsame ) THEN
			cxlbl (i) (indx:indx+1) = hr
			indx = indx + 2
		    END IF
		    cxlbl (i) (indx:indx+1) = mn
		    indx = indx + 2
		    lmn = mn
		END IF
	    END DO
	ELSE
C
C*	    Find first label after starting time.
C
	    xtx = xplbl (1)
	    itx = 1
	    DO WHILE ( xtx .lt. xaxbeg .and. itx .lt. nplbl )
		itx = itx + 1
		xtx = xplbl (itx)
	    END DO
C
C*	    Do monthly or yearly labels with tic marks for days
C*	    or months, respectively.
C
	    lyr = cplbl (itx) (1:4)
	    CALL ST_NUMB ( lyr, jdtm (1), ier )
	    lmo = cplbl (itx) (5:6)
	    CALL ST_NUMB ( lmo, jdtm (2), ier )
	    lda = cplbl (itx) (7:8)
	    CALL ST_NUMB ( lda, jdtm (3), ier )
	    lhr = cplbl (itx) (9:10)
	    CALL ST_NUMB ( lhr, jdtm (4), ier )
	    lmn = cplbl (itx) (11:12)
	    CALL ST_NUMB ( lmn, jdtm (5), ier )
	    IF ( jdtm (5) .gt. 0 .or. jdtm (4) .gt. 0 ) THEN
C
C*		Compute fraction of day to add to xplbl (itx)
C*		to get to the next day.
C
		mndf = 1440 - jdtm(5) - 60 * jdtm(4)
		dayfr = FLOAT (mndf) / 1440.
		tday = xplbl (itx) + dayfr
		CALL TI_ADDM  ( jdtm, mndf, jdtm, iret )
		CALL TI_ITOC  ( jdtm, cdate, iret )
		IF ( jdtm (4) .ne. 0 .or. jdtm (5) .ne. 0 ) THEN
		    iret = +9
		    CALL PLT_ERRO ( iret, ' Continuing anyway...',
     +				    ier )
		END IF
	    ELSE
		tday = xplbl (itx)
		CALL TI_ITOC  ( jdtm, cdate, iret )
	    END IF
	    mndf = 1440
	    icntm = 0
	    icnty = 0
	    imon = jdtm (2)
	    iday = jdtm (3)
	    DO WHILE ( tday .le. xaxend .and.
     +		       nxlbl .lt. maxlb )
		IF ( ntics .lt. maxtc .and. unttax .eq. 'M' ) THEN
		    IF ( itmbtw .gt. 0 ) THEN
			itest = MOD ( iday, itmbtw )
		    ELSE
			itest = 999
		    END IF
		    IF ( itest .eq. 0 ) THEN
			ntics = ntics + 1
			xtics (ntics) = tday
		    END IF
		END IF
		IF ( jdtm (3) .eq. 1 ) THEN
		    imon = jdtm (2)
		    iday = 1
		    ido = MOD ( icntm, inctax )
		    icntm = icntm + 1
		    IF ( unttax .eq. 'M' .and. ido .eq. 0 ) THEN
			nxlbl = nxlbl + 1
			cxlbl (nxlbl) = cdate (3:6)
			cxpos (nxlbl) = tday
		    END IF
		    IF ( ntics .lt. maxtc .and. unttax .eq. 'Y' ) THEN
			IF ( itmbtw .gt. 0 ) THEN
			    itest = MOD ( imon, itmbtw )
			ELSE
			    itest = 999
			END IF
			IF ( itest .eq. 0 ) THEN
			    ntics = ntics + 1
			    xtics (ntics) = tday
			END IF
		    END IF
		    IF ( jdtm (2) .eq. 1 ) THEN
			imon = 1
			ido = MOD ( icnty, inctax )
			icnty = icnty + 1
			IF ( unttax .eq. 'Y' .and. ido .eq. 0 ) THEN
			    nxlbl = nxlbl + 1
			    cxlbl (nxlbl) = cdate (1:4)
			    cxpos (nxlbl) = tday
			END IF
		    END IF
		END IF
C
C*		Increment to the next day.
C
		tday = tday + 1.00
		iday = iday + 1
		CALL TI_ADDM  ( jdtm, mndf, jdtm, iret )
		CALL TI_ITOC  ( jdtm, cdate, iret )
	    END DO
	END IF
C*
	RETURN
	END
