	SUBROUTINE PLT_NCDF ( rv, rm, rs, prb, iret )
C************************************************************************
C* PLT_NCDF								*
C*									*
C* This subroutine computes the normal cumulative distribution function *
C* given a particular value, the mean, and standard deviation:          *
C*                                                                      *
C* PLT_NCDF (V, M, S) = { INTEGRAL [-inf -> Z] EXP ( -u**2 / 2 ) } /    *
C*                              SQRT ( 2 * PI )                         *
C*                                                                      *
C*     where u = (z - M) / S and Z = (V - M) / S                        *
C*                                                                      *
C* This gives the probability of v <= V.  For the probability of        *
C* v >= V, subtract this result from one.  For the probability of v     *
C* between two values, take the absolute value of the difference of     *
C* this result for each of the two values.                              *
C*                                                                      *
C* The standard normal distribution is described and tabulated in Meyer *
C* (1970).  The numerical integration algorithm is the Simpson Composite*
C* Algorithm described in Burden et. al (1978).                         *
C*                                                                      *
C* References:                                                          *
C*                                                                      *
C* Burden, R. L., J. D. Faires, and A. C. Reynolds, 1978:  NUMERICAL    *
C*     ANALYSIS.  Prindle, Weber & Schmidt, ISBN 0-87150-243-7, 579 pp. *
C*                                                                      *
C* Meyer, P. L., 1970:  INTRODUCTORY PROBABILITY AND STATISTICAL        *
C*     APPLICATIONS.  Addison-Wesley Pub. Co., ISBN 0-201-04710-1,      *
C*     367 pp.                                                          *
C*                                                                      *

C* This subroutine prints out statistical significance analysis results *
C* for two traces.							*
C*									*
C* PLT_NCDF  ( RV, RM, RS, PRB, IRET )					*
C*									*
C* Input parameters:							*
C*	RV		REAL		Value whose cumulative prob is  *
C*					sought				*
C*	RM		REAL		Mean of normal distribution	*
C*	RS		REAL		Sigma of normal distribution	*
C*									*
C* Output parameters:							*
C*	PRB		REAL		Probability of v <= RV		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20061117   					*
C************************************************************************
C*
	PARAMETER	( PI = 3.1415927 )
C*
C*-----------------------------------------------------------------------
	iret = 0
        hstep = .05
        cnorm = 1. / ( 3. * SQRT ( 2.0 * PI ) )
C*
        zstop = ( rv - rm ) / rs
        azstp = ABS ( zstop )
        IF ( azstp .lt. 0.0001 ) THEN
            prb = .500
        ELSE IF ( zstop .gt. 7. ) THEN
            prb = 1.0
        ELSE IF ( zstop .lt. -7. ) THEN
            prb = 0.0
        ELSE
            IF ( zstop .lt. 0.0 ) THEN
                sign = -1.0
            ELSE
                sign = 1.0
            END IF
            m = INT ( azstp / ( 2. * hstep ) )
            IF ( m .lt. 4 ) m = 4
            h = azstp / ( 2. * FLOAT (m) )
C
C*          Perform Simpson's Composite Algorithm to integrate.
C
            x = 0.
            sum = 1.
            kend = 2 * m
            DO k = 1, kend
                x = x + h
                IF ( k .eq. kend ) THEN
                    sum = sum + EXP ( - x * x / 2. )
                ELSE IF ( MOD ( k, 2 ) .ne. 0 ) THEN
                    sum = sum + 4. * EXP ( - x * x / 2. )
                ELSE
                    sum = sum + 2. * EXP ( - x * x / 2. )
                END IF
            END DO
            sum = ( sum * h ) * cnorm
            prb = .5 + sign * sum
	END IF
C*
	RETURN
	END
