	SUBROUTINE PLT_SMTH ( ain, np, ismwnd, ismort, aout, amn, amx,
     +			      iret )
C************************************************************************
C* PLT_SMTH								*
C*									*
C* This subroutine smooths the array AIN using running averages.	*
C*									*
C* AIN and AOUT must not be the same array.				*
C*									*
C* ISMWND gives the number of points in the running average window.	*
C* ISMWND points are averaged to give the value at each trace point,	*
C* except near the endpoints of the array.				*
C*									*
C* PLT_SMTH  ( AIN, NP, ISMWND, ISMORT, AOUT, AMN, AMX, IRET )		*
C*									*
C* Input parameters:							*
C*	AIN (NP)	REAL		Array to be smoothed		*
C*	NP		INTEGER		Number of points		*
C*	ISMWND		INTEGER		Running average window		*
C*	ISMORT		INTEGER		Running avg window alignment	*
C*					  < 0 - window ends on points	*
C*					  = 0 - window centered on pts	*
C*					  > 0 - window starts on pts	*
C* Output parameters:							*
C*	AOUT (NP)	REAL		Array of smoothed values	*
C*	AMN		REAL		Minimum of smoothed array	*
C*	AMX		REAL		Maximum of smoothed array	*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill		 1/99						*
C************************************************************************
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	REAL		ain (*), aout (*)
C*
	LOGICAL ERMISS
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	IF ( ismort .lt. 0 ) THEN
	    nbk = ismwnd - 1
	    nfd = 0
	ELSE IF ( ismort .eq. 0 ) THEN
	    nfd = ismwnd / 2   
	    nbk = nfd
	    IF ( nfd + nbk + 1 .gt. ismwnd ) nbk = nbk - 1
	ELSE
	    nfd = ismwnd - 1
	    nbk = 0
	END IF
	amn = 1.1E31
	amx = -1.1E31
	DO i = 1, np
	    nstrt = i - nbk
	    nstop = i + nfd
	    icnt = 0
	    avg = 0.0
	    DO j = nstrt, nstop, 1
		IF ( j .gt. 0 .and. j .le. np .and.
     +		     .not. ERMISS ( ain (j) ) ) THEN
		    avg = avg + ain (j)
		    icnt = icnt + 1
		END IF
	    END DO
	    IF ( icnt .gt. 0 .and.
     +		 .not. ERMISS ( ain (i) ) ) THEN
		aout (i) = avg / FLOAT (icnt)
	        IF ( aout (i) .gt. amx ) amx = aout (i)
		IF ( aout (i) .lt. amn ) amn = aout (i)
	    ELSE
		aout (i) = RMISSD
	    END IF
	END DO
C*
	RETURN
	END
