	SUBROUTINE PLT_STAT ( mp, mt, ntrc, trc, npts, iret )
C************************************************************************
C* PLT_STAT								*
C*									*
C* This subroutine prints out statistics for each input trace.		*
C*									*
C* PLT_STAT  ( MP, MT, NTRC, TRC, NPTS, IRET )				*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces to plot	*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		10/98						*
C* K. Brill/HPC		01/00	Format X to 1X for LINUX		*
C* K. Brill/HPC      20080131   Write to output text file on unit 71	*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	PARAMETER	( RMISSD = -9999.  )
	PARAMETER	( RDIFFD =  0.1    )
C*
	CHARACTER*40	pad
	REAL		trc (mp,mt)
	INTEGER		npts (*)
	LOGICAL		ERMISS
	DOUBLE PRECISION
     +			xsum, x2sum, x3sum, x4sum, rmn, rsig, rvar,
     +			curtis, skew, rnn
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
	pad = ' '
C
C*	Open output text file.
C
	OPEN ( UNIT=71, FILE='fvs_statspage.txt', IOSTAT=ios,
     +         STATUS='UNKNOWN' )
C*
	DO it = 1, ntrc
C
C*	    Statistics for all npts (it) points of trc (*,it).
C*	    Find max, min, mean, standard deviation, variance,
C*	    skewness, and kurtosis.
C
	    xmin = 1.1E31
	    xmax = -1.1E31
	    xsum = 0.
	    x2sum = 0.
	    x3sum = 0.
	    x4sum = 0.
	    rnn = 0.
	    DO i = 1, npts (it)
		IF ( .not. ERMISS ( trc (i,it) ) ) THEN
		    rnn = rnn + 1.
		    xsum = xsum + trc (i,it)
		    x2sum = x2sum + trc (i,it) * trc (i,it)
		    x3sum = x3sum + trc (i,it) * trc (i,it) *
     +				    trc (i,it)
		    x4sum = x4sum + trc (i,it) * trc (i,it) *
     +				    trc (i,it) * trc (i,it)
		    IF ( trc (i,it) .gt. xmax ) xmax = trc (i,it)
		    IF ( trc (i,it) .lt. xmin ) xmin = trc (i,it)
		END IF
	    END DO
	    IF ( rnn .le. 0 ) THEN
		WRITE (6,1004) it
		WRITE (71,1004) it
		CALL ST_LSTR ( trclbl (it), nchrs, ier )
		ixoff = 40 - nchrs / 2
		IF ( ixoff .gt. 0 ) THEN
		    WRITE (6,1002) pad (1:ixoff), 
     +				   trclbl (it) (1:nchrs)
		    WRITE (71,1002) pad (1:ixoff), 
     +				   trclbl (it) (1:nchrs)
		ELSE
		    WRITE (6,'(A)') trclbl (it) (1:nchrs)
		    WRITE (71,'(A)') trclbl (it) (1:nchrs)
		END IF
		WRITE (6,*) ' '
		WRITE (6,*) '     TRACE DATA IS ALL MISSING.'
		WRITE (6,*) ' '
		WRITE (71,*) ' '
		WRITE (71,*) '     TRACE DATA IS ALL MISSING.'
		WRITE (71,*) ' '
	    ELSE
		rmn = xsum / rnn
		rsig = DSQRT ( x2sum / rnn - rmn * rmn )
		rvar = rsig * rsig
		skew = x3sum - 3. * rmn * x2sum + 3. * rmn * rmn * xsum
     +		    - rnn * rmn * rmn * rmn
		skew = skew / ( rnn * rsig * rsig * rsig )
		curtis = x4sum - 4. * rmn * x3sum
     +		       + 6. * rmn * rmn * x2sum
     +		       - 4. * rmn * rmn * rmn * xsum
     +		       + rnn * rmn * rmn * rmn * rmn
		curtis = curtis / ( rnn * rvar * rvar )
C
C*		Construct frequency distribution.
C
		rn = rnn
		nci = 5 * NINT ( ALOG10 ( rn ) )
		IF ( nci .lt. 3 ) nci = 3
		rinc = ( xmax - xmin ) / FLOAT ( nci )
		sumf = 0.0
		xmedian = -1.
		fmax = -1.
		xleft = xmin
		DO i = 1, nci
		    xrht = xleft + rinc
C
C*		    Find count for this interval.
C
		    freq = 0.
		    rn = 0.
		    DO j = 1, npts (it)
			IF ( .not. ERMISS ( trc (j,it) ) ) THEN
			    rn = rn + 1.
			    IF ( ( trc (j,it) .ge. xleft .and.
     +			           trc (j,it) .lt. xrht ) .or.
     +			         ( trc (j,it) .ge. xleft .and.
     +			           i .eq. nci ) ) THEN
				freq = freq + 1.
			    END IF
			END IF
		    END DO
		    IF ( rn .gt. 0. ) THEN
			freq = freq / rn
			IF ( freq .gt. fmax ) THEN
			    fmax = freq
			    xmode = .5 * ( xleft + xrht )
			END IF
			sumf = sumf + freq
			IF ( sumf .ge. .5 .and. xmedian .lt. 0 ) THEN
			    xmedian = .5 * ( xleft + xrht )
			END IF
		    END IF
		    xleft = xrht
		END DO
		sku2 = ( rmn - xmode ) / rsig
C
C*		Print out results for this trace.
C
		WRITE (6,*) ' '
		WRITE (71,*) ' '
		CALL ST_LSTR ( ptitle, lng, ier )
		itend = 0
		istrt = 1
		nclft = lng
		nchrx = 72
		DO WHILE ( itend .lt. lng )
		    IF ( nclft .gt. nchrx ) THEN
			ic = itend + nchrx
			DO WHILE ( ic .gt. 1 )
			    ic = ic - 1
			    IF ( ptitle (ic:ic) .eq. ' ' ) THEN
				isplit = ic
				ic = -9
			    END IF
			END DO
			IF ( ic .eq. -9 ) THEN
			    itend = isplit
			ELSE
			    itend = lng + 1
			END IF
		    ELSE
			itend = lng + 1
		    END IF
		    nchrs = itend - istrt
		    ixoff = 40 - nchrs / 2
		    IF ( ixoff .gt. 0 .and. ixoff .lt. 40 ) THEN
			WRITE (6,1002) pad (1:ixoff),
     +					ptitle (istrt:itend-1)
			WRITE (71,1002) pad (1:ixoff),
     +					ptitle (istrt:itend-1)
		    ELSE
			WRITE (6,1002) ptitle (istrt:itend-1)
			WRITE (71,1002) ptitle (istrt:itend-1)
		    END IF
1002		    FORMAT ( A, A )
		    istrt = itend + 1
		    nclft = lng - istrt + 1
		END DO
		WRITE (6,1004) it
		WRITE (71,1004) it
1004		FORMAT ( /, 35X, 'TRACE # ', I2 )
		CALL ST_LSTR ( trclbl (it), nchrs, ier )
		ixoff = 40 - nchrs / 2
		IF ( ixoff .gt. 0 ) THEN
		    WRITE (6,1002) pad (1:ixoff), 
     +				   trclbl (it) (1:nchrs)
		    WRITE (71,1002) pad (1:ixoff), 
     +				   trclbl (it) (1:nchrs)
		ELSE
		    WRITE (6,'(A)') trclbl (it) (1:nchrs)
		    WRITE (71,'(A)') trclbl (it) (1:nchrs)
		END IF
		n = NINT ( rnn )
		WRITE (6,*) ' '
		WRITE (71,*) ' '
		WRITE (6,1006)
		WRITE (71,1006)
1006		FORMAT ( 7X,'N',9X,'MAX',10X,'MIN',8X,'MEDIAN',8X,
     +		         'MODE',6X,'SKEW (MODE)' )
		WRITE (6,1007) n, xmax, xmin, xmedian, xmode, sku2 
		WRITE (71,1007) n, xmax, xmin, xmedian, xmode, sku2 
1007		FORMAT ( 1X,I10,5(1X,1PE12.5) )
		WRITE (6,*) ' '
		WRITE (71,*) ' '
		WRITE (6,1008)
		WRITE (71,1008)
1008		FORMAT ( 7X, 'N',8X,'MEAN',8X,'STD DEV',5X,'VARIANCE',
     +			 5X,'SKEWNESS',5X,'KURTOSIS' )
		rmu = rmn
		sig = rsig
		var = rvar
		curtos = curtis
		sku = skew
		WRITE (6,1007) n, rmu, sig, var, sku, curtos
		WRITE (71,1007) n, rmu, sig, var, sku, curtos
		WRITE (6,*) ' '
		WRITE (71,*) ' '
	    END IF
	END DO
	CLOSE ( UNIT=71 )
C*
	RETURN
	END
