	SUBROUTINE PLT_STRT ( lungc, cplbl, xplbl, nplbl, xmin, xmax,
     +			      ymin, ymax, numtrc, iptype, idvtx, iret )
C************************************************************************
C* PLT_STRT								*
C*									*
C* This subroutine loads control information into a common data		*
C* structure, initializes the graphics, and starts a device driver.	*
C*									*
C* The control file is assumed to be connected to unit number LUNGC.	*
C* The information in the control file is key word tagged.  An equal	*
C* sign (=) separates the keyword from control information following	*
C* it.  Here are the keywords and their meanings (following GEMPAK):	*
C*									*
C* The value for the witness line defaults to zero.			*
C*									*
C*      ADLINE = Line c/t/w for attr diag ref lines in clockwise order  *
C*	BORDER = Background lines color/dash/width			*
C*	BXWSKR = Box-whisker color/width/plevel				*
C*	CLEAR  = Clear screen flag					*
C*	COLORS = Color number assignments				*
C*	DEVICE = Device|name|x size;y size|color type			*
C*	FACTOR = Scaling factor(s) to apply to data (lft_sf/rht_sf)	*
C*	HSTCLR = Histogram bar colors for each trace separated by ;	*
C*	L_TEXT = Text size/font/width/hw flag for axis tic-mark labels	*
C*	LABLEV = label level						*
C*	LINE   = Line colors/types/widths/labels			*
C*	MARKER = Marker colors/types/sizes/widths			*
C*	PANEL  = Panel location						*
C*	PTYPE  = l.s. ; r.s. yaxis plot types/h:w ratio/lm;bm;rm;tm	*
C*	REFLIN = Reference line: x1,y1;x2,y2;x3,y3/color/type/width	*
C*	REVERS = Yes/no flag to switch x and y axes			*
C*      RSTRCS = List of right-side axis trace #s separated by /	*
C*	RWTLIN = r.s. Line colors/types/widths/values for witness lines	*
C*	RYAXIS = Right side Ystrt/ystop/yinc/lbl;gln;tck		*
C*	SERCOR = YES/NO Serial correlation flag for significance test 1 *
C*	T_TEXT = Text size/font/width/hw flag for title|trace|axis text	*
C*	TITLE  = Title string						*
C*	TRACEn = User provided text label key for trace number n	*
C*      TWOCOL = YES/NO to display trace labels in two columns          *
C*	WITLIN = l.s. Line colors/types/widths/values for witness lines	*
C*	XAXIS  = Xstrt/xstop/xinc/lbl;gln;tck				*
C*	XLABEL = Label text for x axis/# of char size units from margin *
C*	XUDLBL = List of x axis point label strings			*
C*	YAXIS  = Left side Ystrt/ystop/yinc/lbl;gln;tck			*
C*	YLABEL = Label text for y axis/# of char size units from margin *
C*	YRLBEL = Label text for r.s. y axis/# of char units from margin *
C*									*
C*  If REVERS = Yes, only left side Y axis drawing is permitted.	*
C*									*
C*									*
C* PLT_STRT ( LUNGC, CPLBL, XPLBL, NPLBL, XMIN, XMAX, YMIN, YMAX,	*
C*	      NUMTRC, IPTYPE, IRET )					*
C*									*
C* Input parameters:							*
C*	LUNGC		INTEGER		Unit # of graphics control file *
C*	CPLBL (NPLBL)	CHAR*		Character labels (time stamps)	*
C*	XPLBL (NPLBL)	REAL		Label positions			*
C*	NPLBL		INTEGER		Number of labels		*
C*	XMIN (NUMTRC)	REAL		x axis minimum reqd by trace	*
C*	XMAX (NUMTRC)	REAL		x axis maximum reqd by trace	*
C*	YMIN (NUMTRC)	REAL		y axis minimum reqd by trace	*
C*	YMAX (NUMTRC)	REAL		y axis maximum reqd by trace	*
C*	NUMTRC		INTEGER		Number of traces to be drawn	*
C*	IPTYPE		INTEGER		Type of plot			*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs thresholds *
C*					  4 - categorical bins		*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - Attribute diagram		*
C*                                        8 - Quantile RELI diagram     *
C*									*
C* Input and Output parameter:						*
C*	IDVTX		INTEGER		Flag to force TX device		*
C*					  0 - do not force		*
C*					  1 - force TX			*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +4 = invalid keyword		*
C*				 	  0 = normal return 		*
C*					 -8 = too many traces		*
C*					 -9 = graphics device not set	*
C*					-13 = too many trace labels	*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 2/98	Added FACTOR				*
C* K. Brill/EMC		 4/98	Clean up / bug fixes			*
C* K. BRill/EMC		 5/98	Added witness line spec			*
C* K. Brill/EMC		 5/98	Added user-defined x axis labels	*
C* K. Brill/EMC		 1/99	Make buffr & split much bigger		*
C* K. Brill/EMC		 4/99	Call PLT_ITRC; add REVERS		*
C* K. Brill/EMC		10/99	-25 error for no input device		*
C* K. Brill/HPC		01/00	Text settings for each label type	*
C* K. Brill/HPC		03/01	Changes for right-side yaxis		*
C* K. Brill/HPC		 4/01	Changes to allow no left axis traces	*
C* K. Brill/HPC		 3/03	Changes for COLORS parameter		*
C* K. Brill/HPC		 5/03	Added REFLIN input			*
C* K. Brill/HPC		 9/03	Document IPTYPE=6			*
C* K. Brill/HPC		 3/04	Add HSTCLR input; process X axis input	*
C*				only at the end				*
C* K. Brill/HPC      20070125   Changes for attribute diagram		*
C* K. Brill/HPC      20070406   Do not start gplt if device is TX	*
C* K. Brill/HPC      20070619   Pass idvtx into PLT_STRT; parse SERCOR	*
C*				input					*
C* K. Brill/HPC      20081117   Set rhtdrw=.true. if RYAXIS is given	*
C* K. Brill/HPC      20120316   Start changes for box-whisker displays  *
C* K. Brill/HPC      20120322	Pass libw flag to PLT_INIT		*
C* K. Brill/HPC      20120402   Set bxwfnd to true			*
C* K. Brill/HPC      20120404   Extend default Y axis for bxwskr objcts	*
C* K. Brill/HPC      20120416   CALL PLT_IRSZ to set # of resamplings	*
C* K. Brill/HPC      20120615	CALL PLT_IBTX for B_TEXT input		*
C* K. Brill/IMSG     20160718	Handle IPTYPE == 8                      *
C* K. Brill/IMSG     20160726   Add TWOCOL input parameter              *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C*
	CHARACTER*(*)	cplbl (*)
	REAL		xmin (*), xmax (*), ymin (*), ymax (*)
	REAL		xplbl (*)
C*
	CHARACTER*256	buffr
	CHARACTER*256	split (2)
	CHARACTER*128	cxax, cxdv
	INTEGER		irsl (MXTRCS)
	REAL		value (2)
	LOGICAL		scalx, scaly, nolft, libw
	LOGICAL		devfnd, yaxfnd, yrxfnd, fstls, fstrs
C*
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*------------------------------------------------------------------------
	iret = 0
C*
	cxax = ' '
	nhis = 0
C*
	IF ( numtrc .gt. MAXLIN ) THEN
	    iret = -8
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN 
	END IF
C*
	libw = .false.
	CALL PLT_INIT ( numtrc, libw, ier )
	devfnd = .false.
	yaxfnd = .false.
	yrxfnd = .false.
	nolft = .false.
C
C*	Set default resampling trial number.
C
	CALL PLT_IRSZ ( '2000', ier )
	nsmpls = 2000
C
C*	Scan for the right-side trace number specification.
C
	ios = 0
	DO WHILE ( ios .eq. 0 )
	    READ (lungc, '(A)', IOSTAT=ios) buffr
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( buffr, '=', ' ', 2, split, num, ier )
		CALL ST_LCUC ( split (1), split (1), ier )
		IF ( INDEX ( split (1)(1:3), 'RST' ) .ne. 0 ) THEN
		    CALL ST_ILST ( split (2), '/', 0, MXTRCS, irsl,
     +				   nrsl, ier )
		    IF ( ier .eq. 0 .and. nrsl .gt. 0 ) THEN
			icnt = 0
			DO i = 1, nrsl
			    it = irsl (i)
			    IF ( it .le. numtrc .and. it .gt. 0 ) THEN
				rhttrc (it) = .true.
				icnt = icnt + 1
			    END IF
			END DO
			IF ( icnt .eq. numtrc ) THEN
			    iret = 12
			    CALL PLT_ERRO ( iret, 'WARNING', ier )
			    iret = 0
			    nolft = .true.
			END IF
			rhtdrw = ( icnt .gt. 0 )
		    ELSE
			rhtdrw = .false.
		    END IF
		END IF
	    END IF
	END DO
	REWIND lungc
C
C*	Find first left side and right side traces.
C
	fstls = .false.
	fstrs = .false.
	i = 0
	DO WHILE ( ( .not. fstls .or. .not. fstrs )
     +			.and. i .lt. numtrc )
	    i = i + 1
	    IF ( rhttrc (i) ) THEN
		ifstrs = i
		fstrs = .true.
	    ELSE
		ifstls = i
		fstls = .true.
	    END IF
	END DO
	IF ( nolft ) ifstls = 1
C
C*	Determine axis minima and maxima.
C
	dymxl = 0.0
	dymxr = 0.0
	dymnl = 0.0
	dymnr = 0.0
	scalx = .false.
	scaly = .true.
	IF ( iptype .ne. 2 .and. iptype .ne. 5 .and.
     +       iptype .ne. 7 .and. iptype .ne. 8 ) THEN
	    sxmin = 1.1E31
	    sxmax = -1.1E31
	    symin = 1.1E31
	    symax = -1.1E31
	    rsmin = 1.1E31
	    rsmax = -1.1E31
	    DO i = 1, numtrc
		IF ( xmin (i) .lt. sxmin ) sxmin = xmin (i)
		IF ( xmax (i) .gt. sxmax ) sxmax = xmax (i)
		IF ( .not. rhttrc (i) ) THEN
		    IF ( ymin (i) .lt. symin ) symin = ymin (i)
		    IF ( ymax (i) .gt. symax ) symax = ymax (i)
		    IF ( i .lt. numtrc ) THEN
		    	DO j = i + 1, numtrc
			    IF ( .not. rhttrc (j) ) THEN
			        dy = ABS ( ymax (j) - ymax (i) )
			        IF ( dy .gt. dymxl ) dymxl = dy
			        dy = ABS ( ymin (j) - ymin (i) )
			        IF ( dy .gt. dymnl ) dymnl = dy
			    END IF
		    	END DO
		    END IF
		ELSE
		    IF ( ymin (i) .lt. rsmin ) rsmin = ymin (i)
		    IF ( ymax (i) .gt. rsmax ) rsmax = ymax (i)
		    IF ( i .lt. numtrc ) THEN
		    	DO j = i + 1, numtrc
			    IF ( rhttrc (j) ) THEN
			        dy = ABS ( ymax (j) - ymax (i) )
			        IF ( dy .gt. dymxr ) dymxr = dy
			        dy = ABS ( ymin (j) - ymin (i) )
			        IF ( dy .gt. dymnr ) dymnr = dy
			    END IF
		    	END DO
		    END IF
		END IF
	    END DO
	ELSE IF ( iptype .eq. 2 ) THEN
	    scalx = .true.
	    rhtdrw = .false.
	    sxmin = MIN ( ymin (1), ymin (2) )
	    sxmax = MAX ( ymax (1), ymax (2) )
	    symin = sxmin
	    symax = sxmax
	ELSE IF ( iptype .eq. 5 ) THEN
	    scalx = .true.
	    scaly = .false.
	    rhtdrw = .false.
	    sxmin = ymin (1)
	    sxmax = ymax (1)
	    symin = 0.0
	    symax = 1.0
	ELSE IF ( iptype .eq. 7 .or. iptype .eq. 8 ) THEN
	    scalx = .false.
	    scaly = .false.
	    sxmin = 0.0
	    sxmax = 1.0
	    symin = 0.0
	    symax = 1.0
	    rsmin = 0.0
	    rsmax = 1.0
	END IF
	IF ( nolft ) THEN
	    symin = rsmin
	    symax = rsmax
	    dymxl = dymxr
	    dymnl = dymnr
	END IF
C
C*	Search for scale factor and BXWSKR; set them first.
C
	ios = 0
	DO WHILE ( ios .eq. 0 )
	    READ (lungc, '(A)', IOSTAT=ios) buffr
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( buffr, '=', ' ', 2, split, num, ier )
		CALL ST_LCUC ( split (1), split (1), ier )
		IF ( INDEX ( split (1)(1:3), 'FAC' ) .ne. 0 ) THEN
		    CALL ST_CRNM ( split (2), value, ier )
		    CALL ST_RLST ( split (2), '/', 1., 2, value,
     +				   num, ier )
		    IF ( ier .ne. 0 .or. ERMISS (value (1)) ) THEN
			sfctor = 1.0
		    ELSE
			sfctor = value (1)
			IF ( scalx ) THEN
			    sxmin = sfctor * sxmin
			    sxmax = sfctor * sxmax
			END IF
			IF ( scaly ) THEN
			    symin = sfctor * symin
			    symax = sfctor * symax
			    dymxl = sfctor * dymxl
			    dymnl = sfctor * dymnl
			END IF
		    END IF
		    IF ( num .eq. 2 .and. rhtdrw .and.
     +			 .not. ERMISS (value(2)) ) THEN
			rfctor = value (2)
			IF ( scaly ) THEN
			    rsmin = rfctor * rsmin
			    rsmax = rfctor * rsmax
			    dymxr = rfctor * dymxr
			    dymnr = rfctor * dymnr
			END IF
		    END IF
		ELSE IF ( INDEX ( split (1)(1:3), 'BXW' ) .ne. 0 ) THEN
		    nbxt = knmucc * npairs
		    bxwfnd = .true.
		    CALL PLT_IBXW ( split (2), nbxt, ierp )
		END IF
	    END IF
	END DO
C
C*	Extend Y axis if box-whisker objects are drawn.
C
	IF ( bxwflg ) THEN
	    symax = symax + 2. * dymxl
	    rsmax = rsmax + 2. * dymxr
	    symin = symin - 2. * dymnl
	    rsmin = rsmin - 2. * dymnr
	END IF
C*
	REWIND lungc
	ios = 0
	DO WHILE ( ios .eq. 0 )
	    READ (lungc, '(A)', IOSTAT=ios) buffr
	    IF ( ios .eq. 0 ) THEN
		ieq = INDEX ( buffr, '=' )
		IF ( ieq .ne. 0 ) THEN
		    split (1) = buffr ( 1:(ieq-1) )
		    CALL ST_RMBL ( split (1), split (1), lng, ier )
		    split (2) = buffr ( (ieq+1): )
		ELSE
		    split (1) = ' '
		    split (2) = ' '
		END IF
		CALL ST_LCUC ( split (1), split (1), ier )
		ierp = 0
		IF ( INDEX ( split (1)(1:3), 'BOR' ) .ne. 0 ) THEN
		    CALL PLT_IBOR ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'BXW' ) .ne. 0 ) THEN
C*		    DO NOTHING -- already done!
		ELSE IF ( INDEX ( split (1)(1:3), 'B_T' ) .ne. 0 ) THEN
		    CALL PLT_IBTX ( split (2), ier )
		ELSE IF ( INDEX ( split (1)(1:3), 'NSM' ) .ne. 0 ) THEN
		    CALL PLT_IRSZ ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'CLE' ) .ne. 0 ) THEN
		    CALL PLT_ICLR ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'COL' ) .ne. 0 ) THEN
		    colors = split (2)
		ELSE IF ( INDEX ( split (1)(1:3), 'DEV' ) .ne. 0 ) THEN
		    IF ( idvtx .eq. 0 ) devstr = split (2)
		    CALL ST_LCUC ( devstr, cxdv, ier )
		    CALL ST_RMBL ( cxdv, cxdv, lng, ier )
		    idvtx = INDEX ( cxdv, 'TX' )
		    devfnd = .true.
		ELSE IF ( INDEX ( split (1)(1:3), 'FAC' ) .ne. 0 ) THEN
C*		    DO NOTHING -- already done!
		ELSE IF ( INDEX ( split (1)(1:3), 'RST' ) .ne. 0 ) THEN
C*		    DO NOTHING -- already done!
		ELSE IF ( INDEX ( split (1)(1:3), 'HST' ) .ne. 0 ) THEN
		    CALL ST_ILST ( split (2), ';', 0, MAXLIN, ihstcl,
     +				   nhis, ier )
		ELSE IF ( INDEX ( split (1)(1:3), 'LIN' ) .ne. 0 ) THEN
		    CALL PLT_ILIN ( split (2), numtrc, ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'ADL' ) .ne. 0 ) THEN
		    CALL PLT_ADLN ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'MAR' ) .ne. 0 ) THEN
		    CALL PLT_IMRK ( split (2), numtrc, ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'PAN' ) .ne. 0 ) THEN
		    CALL PLT_IPNL ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'PTY' ) .ne. 0 ) THEN
		    CALL PLT_ITYP ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'LAB' ) .ne. 0 ) THEN
		    CALL PLT_ILLV ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'L_T' ) .ne. 0 ) THEN
		    tcslab = split (2)
		ELSE IF ( INDEX ( split (1)(1:3), 'T_T' ) .ne. 0 ) THEN
		    CALL ST_CLST ( split (2), '|', '1/1/1/SW', 3,
     +				   tcsttl, nqn, ier )
		ELSE IF ( INDEX ( split (1)(1:3), 'TIT' ) .ne. 0 ) THEN
		    ptitle = split (2)
		ELSE IF ( INDEX ( split (1), 'TRA' ) .ne. 0 ) THEN
		    CALL PLT_ITRC ( split (1), split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'WIT' ) .ne. 0 ) THEN
		    CALL PLT_IWIT ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'RWT' ) .ne. 0 ) THEN
		    CALL PLT_IRWT ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'XAX' ) .ne. 0 ) THEN
		    cxax = split (2)
		ELSE IF ( INDEX ( split (1)(1:3), 'XLA' ) .ne. 0 ) THEN
		    CALL PLT_IAXL ( 1, split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'XUD' ) .ne. 0 ) THEN
		    CALL ST_CLST ( split (2), '/', ' ', MAXUDX,
     +				  xaxudl, naxudl, ier )
		ELSE IF ( INDEX ( split (1)(1:3), 'YAX' ) .ne. 0 ) THEN
		    CALL PLT_IYAX ( split (2), symin, symax, iptype,
     +				    ierp )
		    yaxfnd = .true.
		ELSE IF ( INDEX ( split (1)(1:3), 'RYA' ) .ne. 0 ) THEN
		    CALL PLT_IYRX ( split (2), rsmin, rsmax, iptype,
     +				    ierp )
		    yrxfnd = .true.
		    rhtdrw = .true.
		ELSE IF ( INDEX ( split (1)(1:3), 'YLA' ) .ne. 0 ) THEN
		    CALL PLT_IAXL ( 2, split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'YRL' ) .ne. 0 ) THEN
		    CALL PLT_IAXL ( 3, split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'REV' ) .ne. 0 ) THEN
		    iq = INDEX ( split (2), 'Y' ) +
     +			 INDEX ( split (2), 'y' )
		    IF ( iq .ne. 0 ) THEN
			revers = .true.
			IF ( rhtdrw ) THEN
			    rhtdrw = .false.
			    CALL PLT_ERRO ( 11, ' ', ier )
			END IF
		    ELSE
			revers = .false.
		    END IF
		ELSE IF ( INDEX ( split (1)(1:3), 'TWO' ) .ne. 0 ) THEN
		    iq = INDEX ( split (2), 'Y' ) +
     +			 INDEX ( split (2), 'y' )
		    IF ( iq .ne. 0 ) THEN
			twocol = .true.
		    ELSE
			twocol = .false.
		    END IF
		ELSE IF ( INDEX ( split (1)(1:3), 'REF' ) .ne. 0 ) THEN
		    CALL PLT_IREF ( split (2), ierp )
		ELSE IF ( INDEX ( split (1)(1:3), 'SER' ) .ne. 0 ) THEN
		    iq = INDEX ( split (2), 'N' ) +
     +			 INDEX ( split (2), 'n' )
		    IF ( iq .ne. 0 ) THEN
			sercor = .false.
		    END IF
		ELSE
		    ierr = 4
		    CALL PLT_ERRO ( ierr, split (1), ier )
		END IF
		IF ( ierp .ne. 0 ) CALL PLT_ERRO ( ierp, ' ', ier )
	    END IF
	END DO
	IF ( .not. devfnd ) THEN
	    iret = -25
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Process X axis input.  Expand the axis range if histograms
C*	are requested.
C
	IF ( nhis .ne. 0 .and. nplbl .gt. 0 ) THEN
C
C*	    Figure out how many traces are to be histogrammed.
C
	    nhstgm = 0
	    DO i = 1, nhis
		IF ( ihstcl (i) .ne. 0 ) nhstgm = nhstgm + 1
	    END DO
C
C*	    Compute total number of histogram bars and spaces, leaving
C*	    two spaces between the clusters of bars internally and one
C*	    space on each end.
C
	    brsp = FLOAT ( nplbl * nhstgm + 2 * nplbl )
C
C*	    Compute the number of bars of space needed on each end.
C
	    ends = FLOAT ( nhstgm ) / 2.0 + 1.0
C
C*	    Compute the length of the bars without the ends or
C*	    bar overlaps.
C
	    xbar = brsp - 2.0 * ends
	    IF ( xbar .eq. 0.0 ) xbar = 1.0
C
C*	    Compute the length of x axis needed to include overlap
C*	    bars and ends.
C
	    xlen = ABS ( sxmax - sxmin )
	    IF ( xlen .eq. 0.0 ) xlen = 1.0
	    chng = xlen * ( brsp / xbar - 1.0 )
	    chng = chng / 2.0
	    sxmin = sxmin - chng
	    sxmax = sxmax + chng
	    barwth = ABS ( sxmax - sxmin ) / brsp
C
C*	    If this is an attribute diagram, move the histogram
C*	    color specifications beyond the given set of traces.
C
	    IF ( iptype .eq. 7 ) THEN
		DO i = 1, numtrc/2
		    j = i + numtrc/2
		    IF ( ihstcl (j) .eq. 0 ) THEN
		        ihstcl (j) = ihstcl (i)
		        ihstcl (i) = 0
		        rhttrc (j) = .true.
		 	ilcolr (j) = 0
		    END IF
		END DO
		rhtdrw = .true.
		ifstrs = numtrc/2 + 1
	    END IF
	END IF
	IF ( bxwflg .and. ( nhis .eq. 0 .or. nplbl .le. 0 ) ) THEN
C
C*	    Determine the plotting positions for the box-whisker objects
C*	    based on npairs objects (paired comparisons) at each point
C*	    along the abscissa.  DO NOT reset sxmin and sxmax if the
C*	    block of code above was executed.
C
C*	    Compute total number of box-whisker objects and spaces, leaving
C*	    two spaces between the clusters of objects internally and one
C*	    space on each end.
C
	    brsp = FLOAT ( nplbl * npairs + 2 * nplbl )
C
C*	    Compute the number of bars of space needed on each end.
C
	    ends = FLOAT ( npairs ) / 2.0 + 1.0
C
C*	    Compute the length of the bars without the ends or
C*	    bar overlaps.
C
	    xbar = brsp - 2.0 * ends
	    IF ( xbar .eq. 0.0 ) xbar = 1.0
C
C*	    Compute the length of x axis needed to include overlap
C*	    bars and ends.
C
	    xlen = ABS ( sxmax - sxmin )
	    IF ( xlen .eq. 0.0 ) xlen = 1.0
	    chng = xlen * ( brsp / xbar - 1.0 )
	    chng = chng / 2.0
	    boxspc = ABS ( sxmax - sxmin ) / brsp
	    sxmin = sxmin - chng
	    sxmax = sxmax + chng
C*
	ELSE
C*
	    boxspc=barwth
C*
	END IF
C*	    
	CALL PLT_IXAX ( cxax, cplbl, xplbl, nplbl, sxmin, sxmax,
     +			iptype, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C*
	IF ( .not. yaxfnd ) THEN
	    CALL PLT_IYAX ( ' ', symin, symax, iptype, iret )
	    IF ( iret .ne. 0 ) THEN
		CALL PLT_ERRO ( iret, ' ', ier )
		RETURN
	    END IF
	END IF
	IF ( .not. yrxfnd .and. rhtdrw ) THEN
	    CALL PLT_IYRX ( ' ', rsmin, rsmax, iptype, iret )
	    IF ( iret .ne. 0 ) THEN
		CALL PLT_ERRO ( iret, ' ', ier )
		RETURN
	    END IF
	END IF
C
C*	Initialize graphics and device.
C
	IF ( idvtx .eq. 1 ) THEN
	    CALL IN_BDTA ( iret )
C
C*	    PLT_GDEV will RETURN before calling a GEMPLT
C*          subroutine if DEVICE is TX.
C
	    IF ( iret .eq. 0 ) CALL PLT_GDEV ( iret )
	    IF ( iret .ne. 0 ) CALL PLT_ERRO ( iret, ' ', ier )
	ELSE
	    CALL PLT_GINI ( numtrc, iret )
	    IF ( iret .eq. 0 ) CALL PLT_GDEV ( iret )
	    IF ( iret .ne. 0 ) CALL PLT_ERRO ( iret, ' ', ier )
	END IF
C*
	RETURN
	END
