	SUBROUTINE PLT_TBXW ( mp, mt, ntrc, trc, npts, iret )
C************************************************************************
C* PLT_TBXW								*
C*									*
C* This subroutine prints requested box-whisker object data to a text	*
C* file by calling PLT_WBXW.						*
C*									*
C* PLT_TBXW  ( MP, MT, NTRC, TRC, NPTS, IRET )				*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces to plot	*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-38 = X point counts differ	*
C*					-39 = resampling error		*
C*					-40 = wrong # of box objects	*
C**									*
C* Log:									*
C* K. Brill/HPC      20120420	Created					*
C* K. Brill/WPC      20140825   Add smdn median differences             *
C* K. Brill/WPC      20140919   Add skew ratio of differences; add 2nd  *
C*                              dimension for sbxls to return above/    *
C*                              below median box lengths; write out     *
C*                              median skew ratio                       *
C* K. Brill/WPC      20141104   Check for missing skew ratio            *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., RDIFFD = 0.1 )
C*
	REAL		trc (mp,mt)
	INTEGER		npts (*)
C*
	REAL		sbxls (MXTRCS,2), smxs (MXTRCS), smns (MXTRCS)
        REAL            smdn (MXTRCS), skew (MXTRCS)
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
C*
	IF ( .not. bxwflg ) RETURN
C
C*	Check to see that all traces have the same number of X points.
C
	nchk = npts (1)
	DO it = 2, ntrc
	    IF ( npts (it) .ne. nchk ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 5
		iret = -38
	        RETURN
	    END IF
	END DO
C
C*	Do the resampling, X point by X point.
C
	nbxs = npairs * knmucc
	DO ip = 1, npts (1)
	    CALL RSMP_DRV ( ibxplt, ktrcnm, kntrcs,
     +			    kopcod, knmucc, ip, bxplvl, RMISSD, MXTRCS,
     +			    sbxls, smxs, smns, smdn, skew, nss, ier ) 
	    CALL RSMP_ERR ( ier, ' ', iret )
	    IF ( ier .ne. 0 ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 6
	        iret = -39
		RETURN
	    END IF
	    IF ( nss .ne. nbxs ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 7
		iret = -40
		RETURN
	    END IF
	    DO it = 1, nbxs
		sbxlen (ip,it,1) = sbxls (it,1)
		sbxlen (ip,it,2) = sbxls (it,2)
		wskrmx (ip,it) = smxs (it)
		wskrmn (ip,it) = smns (it)
                WRITE (6,*) it,
     +          ' - median of resampled differences = ', smdn (it)
                IF ( .not. ERMISS ( skew(it) ) ) THEN
                    WRITE (6,*) it,
     +              ' - skew ratio of resampled differences = ',
     +              skew (it)
                ELSE
                    WRITE (6,*) it,
     +              ' - skew ratio is undefined.'
                END IF
	    END DO
	END DO
C
C*	Print title text centered, at the top.
C
	WRITE (lunbxw,*) ' '
	WRITE (lunbxw,'(24X,A)') '************************'
	WRITE (lunbxw,'(24X,A)') 'BOX-WHISKER OBJECT DATA'
	WRITE (lunbxw,*) ' '
	CALL PLT_WRTX ( lunbxw, 72, -1, ptitle, iret )
	IF ( iret .ne. 0 ) THEN
	    iret = -42
	    RETURN
	END IF
C*
	ipr = 1
	icc = 1
	DO ibx = 1, nbxs
	    IF ( ipr .gt. npairs ) THEN
		ipr = 1
		icc = icc + 1
	    END IF
	    it = ( icc - 1 ) * kntrcs + 1
	    itp = it + ipr
C
C*	    Determine left or right coordinate system for scale factor.
C
	    IF ( rhttrc (it) ) THEN
		ysf = rfctor
	    ELSE
		ysf = sfctor
	    END IF
C
C*	    Write out header for this trace pair:
C
	    CALL PLT_WRTX ( lunbxw, 72, 4, trclbl (itp), iret )
	    IF ( iret .ne. 0 ) THEN
	        iret = -42
	        RETURN
	    END IF
	    WRITE (lunbxw,*) '            VERSUS first trace:'
	    CALL PLT_WRTX ( lunbxw, 72, 4, trclbl (it), iret )
	    IF ( iret .ne. 0 ) THEN
	        iret = -42
	        RETURN
	    END IF
C*
	    WRITE (lunbxw,1000) ' X# BENCHMRK_VAL PAIRED_VALUE',
     +	                   ' MIN_WSKR_VAL  CI_LOWERBND  CI_UPPERBND',
     +			   ' MAX_WSKR_VAL'
1000	    FORMAT(3A)
	    CALL PLT_WBXW ( npts (it), trc (1,it), trc (1, itp),
     +			    ibx, ysf, ier )
	    WRITE (lunbxw,*) ' '
	    ipr = ipr + 1
	END DO
C*
	RETURN
	END
