	SUBROUTINE PLT_TEXT ( mp, mt, ntrc, trc, xpts, npts,
     +			      cltyp, cplbl, rplbl, xplbl, nplbl,
     +                        bscr, bssk, reli, reso, uncr, cpot,
     +			      iptype, iret )
C************************************************************************
C* PLT_TEXT								*
C*									*
C* This subroutine prints trace data to a text output file.		*
C*									*
C*									*
C* PLT_TEXT  ( MP, MT, NTRC, TRC, XPTS, NPTS,				*
C* 	       CLTYP, CPLBL, PLBL, XPLBL, NPLBL, IRET )			*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces to plot	*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points	*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*	CLTYP		CHAR*1		x axis label type		*
C*					  c = character			*
C*					  r = real			*
C*					  t = character time stamps	*
C*	CPLBL (NPLBL)	CHAR*		Character axis labels		*
C*	RPLBL (NPLBL)	REAL		Real axis labels		*
C*	XPLBL (NPLBL)	REAL		x positions of labels		*
C*	NPLBL		INTEGER		Number of labels		*
C*	BSCR (NTRC)	REAL		Brier Score / CRPS per trace    *
C*	BSSK (NTRC)	REAL		BS/CRPS skill vs uncertainty    *
C*	RELI (NTRC)	REAL		Reliability component of BS/CRPS*
C*	RESO (NTRC)	REAL		Resolution component of BS/CRPS *
C*	UNCR (NTRC)	REAL		Uncertainty component of BS/CRPS*
C*	CPOT (NTRC)	REAL		Potential CRPS                  *
C*	IPTYPE		INTEGER		Plot type			*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs threshold	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - attribute diagram		*
C*					  8 - quantile reli diagram     *
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/99						*
C* K. Brill/HPC      20070305	Add substitution strings for trclbl	*
C* K. Brill/IMSG     20160720   Changes for quantile reli diagrams      *
C* K. Brill/IMSG     20170406   Use x if real labels do not match       *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., RDIFFD = 0.1 )
C*
	REAL		trc (mp,mt), xpts (mp,mt)
	INTEGER		npts (*)
	REAL		rplbl (*), xplbl (*)
	REAL		bscr (*), bssk (*), reli (*), reso (*), uncr (*)
        REAL            cpot (*)
	CHARACTER*(*)	cplbl (*), cltyp
C*
	CHARACTER*256	cbufr
	CHARACTER*128	cntstr, ostr
	CHARACTER*24	axlab
	LOGICAL		found
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
C
C*	Print title text centered, at the top.
C
	WRITE (luntxt,*) ' '
	WRITE (luntxt,'(24X,A)') '************************'
	WRITE (luntxt,*) ' '
	CALL PLT_WRTX ( luntxt, 72, -1, ptitle, iret )
	IF ( iret .ne. 0 ) RETURN
C
C*	Plot the trace data.
C
	DO it = 1, ntrc
	    WRITE (luntxt,*) ' '
	    WRITE (luntxt,*) '   -----------------------'
	    WRITE (luntxt,*) '     TRACE NUMBER = ', it
	    WRITE (luntxt,*) ' '
C
C*	    Do variable substitutions in the trace key.
C
	    IF ( iptype .eq. 7 ) THEN
C
C*		Replace attribute diagram variables with numbers.
C
		iq = INDEX ( trclbl (it), '$BSC' )
		IF ( iq .ne. 0 .and. .not. ERMISS ( bscr (it) ) )
     +		THEN
			CALL ST_RLCH ( bscr(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$BSC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		END IF
		iq = INDEX ( trclbl (it), '$BSK' )
		IF ( iq .ne. 0 .and. .not. ERMISS ( bssk (it) ) )
     +		THEN
			CALL ST_RLCH ( bssk(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$BSK',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		END IF
		iq = INDEX ( trclbl (it), '$REL' )
		IF ( iq .ne. 0 .and. .not. ERMISS ( reli (it) ) )
     +		THEN
		  	CALL ST_RLCH ( reli(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$REL',
     +				       cntstr, ipos, ostr, ir )
		        trclbl (it) = ostr
		END IF
		iq = INDEX ( trclbl (it), '$RES' )
		IF ( iq .ne. 0 .and. .not. ERMISS ( reso (it) ) )
     +		THEN
			CALL ST_RLCH ( reso(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$RES',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		END IF
		    iq = INDEX ( trclbl (it), '$UNC' )
		IF ( iq .ne. 0 .and. .not. ERMISS ( uncr (it) ) )
     +		THEN
			CALL ST_RLCH ( uncr(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$UNC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		END IF
	    END IF
C*
	    IF ( iptype .eq. 8 ) THEN
C
C*		    Replace CRPS RELI diagram variables with numbers.
C
		    iq = INDEX ( trclbl (it), '$RPS' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bscr (it) ) )
     +		    THEN
			CALL ST_RLCH ( bscr(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$RPS',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		    END IF
		    iq = INDEX ( trclbl (it), '$RSK' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bssk (it) ) )
     +		    THEN
			CALL ST_RLCH ( bssk(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$RSK',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		    END IF
		    iq = INDEX ( trclbl (it), '$REL' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reli (it) ) )
     +		    THEN
		  	CALL ST_RLCH ( reli(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$REL',
     +				       cntstr, ipos, ostr, ir )
		        trclbl (it) = ostr
		    END IF
		    iq = INDEX ( trclbl (it), '$RES' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reso (it) ) )
     +		    THEN
			CALL ST_RLCH ( reso(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$RES',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		    END IF
		    iq = INDEX ( trclbl (it), '$UNC' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( uncr (it) ) )
     +		    THEN
			CALL ST_RLCH ( uncr(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$UNC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		    END IF
		    iq = INDEX ( trclbl (it), '$POT' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( cpot (it) ) )
     +		    THEN
			CALL ST_RLCH ( cpot(it), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(it), '$POT',
     +				       cntstr, ipos, ostr, ir )
			trclbl (it) = ostr
		    END IF
            END IF
C
C*	    Plot the trace key.
C
	    CALL PLT_WRTX ( luntxt, 68, 6, trclbl (it), iret )
	    IF ( iret .ne. 0 ) RETURN
	    WRITE (luntxt,*) ' '
	    cbufr = 'X AXIS LABEL = ' // xaxlbl
	    CALL PLT_WRTX ( luntxt, 64, 8, cbufr, iret )
	    IF ( iret .ne. 0 ) RETURN
	    WRITE (luntxt,*) ' '
	    cbufr = 'Y AXIS LABEL = ' // yaxlbl
	    CALL PLT_WRTX ( luntxt, 64, 8, cbufr, iret )
	    IF ( iret .ne. 0 ) RETURN
	    WRITE (luntxt,*) ' '
C
C*	    Write the header.
C
	    WRITE (luntxt, 1001)
1001	    FORMAT ( 8X, 'X POSITION', 12X, 
     +		     'X AXIS LABEL', 11X, 'VALUE OF Y' )
C
C*	    Write the values.
C
	    DO ip = 1, npts (it)
		x = xpts (ip,it)
		y = trc (ip,it)
C
C*		Find the right label for this point.
C
		found = .false.
		ilbl = 0
		DO WHILE ( .not. found .and. ilbl .lt. nplbl )
		    ilbl = ilbl + 1
		    found = ( ABS ( x - xplbl (ilbl) ) .lt. 1.E-5 )
		END DO
		IF ( found .and. cltyp .eq. 'r' ) THEN
		    WRITE (axlab,'(1PE24.5)') rplbl (ilbl)
		ELSE IF ( found ) THEN
		    axlab = cplbl (ilbl)
		ELSE IF ( cltyp .eq. 'r' ) THEN
		    WRITE (axlab,'(1PE24.5)') x
                ELSE
		    axlab = '       MISSING          '
		END IF
		WRITE (luntxt, 1002) x, axlab, y
1002		FORMAT ( 7X, 1PE13.5, 4X, A24, 4X, E13.5 )
	    END DO
	END DO
C*
	RETURN
	END
