	SUBROUTINE PLT_XMRG ( mp, mt, xpts, npts, ntrc, xmrg, nmrg,
     +			      iret )
C************************************************************************
C* PLT_XMRG								*
C*									*
C* This subroutine merges the x axis value arrays for multiple traces   *
C* into one combined array having each unique x value occurring once.	*
C*									*
C* Values are assumed to already be ordered lowest to highest.		*
C*									*
C* PLT_XMRG  ( MP, MT, XPTS, NPTS, NTRC, XMRG, NMRG, IRET )		*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points   *
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*	NTRC		INTEGER		Number of traces		*
C*									*
C* Output parameters:							*
C*	XMRG (MP)	REAL		Merged array of x coordinates   *
C*	NMRG		INTEGER		Number of merged x values	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C************************************************************************
	INCLUDE		'plt.prm'
C*
	REAL		xpts (mp,mt), xmrg (*)
	INTEGER		npts (*)
C*
	INTEGER		indx (MXTRCS)
	LOGICAL		order
C*
	LOGICAL		SAME
	SAME ( x, y ) = ( ABS ( x - y ) .lt. .00005 )
C*------------------------------------------------------------------------
	iret = 0
C*	
	IF ( ntrc .eq. 1 ) THEN
	    DO i = 1, npts (1)
		xmrg (i) = xpts (i,1)
	    END DO
	    nmrg = npts (1)
	    RETURN
	END IF
C
C*	Find the trace with the most x values.  Check that x values
C*      are ordered.
C
	xmin = 1.1E31
	itm = 0
	mxp = 0
	order = .true.
	i = 0
	DO WHILE ( order .and. i .lt. ntrc )
	    i = i + 1
	    indx (i) = 1
	    IF ( npts (i) .gt. mxp ) THEN
		mxp = npts (i)
		itm = i
	    END IF
	    j = 0
	    nm1 = npts (i) - 1
	    DO WHILE ( order .and. j .lt. nm1 )
		j = j + 1
		order = ( xpts (j,i) .lt. xpts (j+1,i) )
		IF ( xpts (j,i) .lt. xmin ) xmin = xpts (j,i)
	    END DO
	END DO
	IF ( itm .eq. 0 .and. order ) THEN
	    iret = -35
	    RETURN
	END IF
	IF ( .not. order ) THEN
	    iret = -36
	    RETURN
	END IF
C
C*      Build the output list of merged, ordered x values.
C
	xmrg (1) = xmin
	imrg = 1
	DO WHILE ( order )
	    icnt = 0
	    xmin = 1.1E31
	    DO i = 1, ntrc
		j = indx (i)
		IF ( j .le. npts (i) ) THEN
		    IF ( SAME ( xmrg(imrg), xpts(j,i) ) ) THEN
			indx (i) = indx (i) + 1
			j = indx (i)
		    END IF
		    IF ( j .le. npts (i) ) THEN
		        IF ( xpts(j,i) .lt. xmin ) THEN
			    xmin = xpts(j,i)
		            icnt = icnt + 1
			END IF
		    END IF
		END IF
	    END DO
	    IF ( icnt .gt. 0 ) THEN
	        imrg = imrg + 1
		IF ( imrg .gt. mp ) THEN
		    iret = -37
		    RETURN
		END IF
		xmrg (imrg) = xmin
	    ELSE
		order = .false.
	    END IF
	END DO
	nmrg = imrg
C*
	RETURN
	END
