	SUBROUTINE FHONRM ( sttyp, thlds, cthld, nth, agrd, fgrd, sgrd,
     +			    kxy, inout, nlun, luns, mfrq, chedr,
     +                      tmpg, tmpa, iret )
C************************************************************************
C* FHONRM								*
C*									*
C* This subroutine computes FHO record values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* FHONRM ( STTYP, THLDS, CTHLD, NTH, AGRD, FGRD, SGRD, KXY, INOUT,	*
C* 	    NLUN, LUNS, CHEDR, IRET )					*
C*									*
C* Input parameters:							*
C*	STTYP		CHAR*		Statistic type without list	*
C*	THLDS (NTH)	REAL		Threshold value list		*
C*	CTHLD (NTH)	CHAR*		Threshold strings		*
C*	NTH		INTEGER		Number of thresholds in list	*
C*	AGRD (KXY) 	REAL		Analysis grid values		*
C*	FGRD (KXY) 	REAL		Forecast grid values		*
C*	SGRD (KXY)	REAL		Normalized box area grid	*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*      MFRQ            LOGICAL         Flag to do frequency matching   *
C*									*
C* Input and output parameter:						*
C*	CHEDR		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*      TMPG (*)        REAL            Temporary array                 *
C*      TMPA (*)        REAL            Temporary array                 *
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-26 = invalid threshold		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/03						*
C* K. Brill/HPC		 7/04	Use the normalized box area grid, SGRD	*
C* K. Brill/HPC		 5/05	Allow f=h=o=0.0	records			*
C* K. Brill/IMSG         4/15   Changes for frequency matching          *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		agrd (*), fgrd (*), sgrd (*), thlds (*)
        REAL            tmpg (*), tmpa (*)
	INTEGER		inout (*), luns (*)
        LOGICAL         mfrq
	CHARACTER*(*)	cthld (*), sttyp, chedr
	
C*
	LOGICAL		ok
	CHARACTER	cl1l2*(MXC)
	CHARACTER*32	csave
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL ST_LCUC ( chedr, chedr, ier )
	CALL ST_LSTR ( chedr, lnch, ier )
C
C*	Find end of statistic type field in header and
C*	save the trailing part in order to insert the
C*	threshold.
C
	ist = INDEX ( chedr, 'FHO' )
	iq = INDEX ( chedr (ist: ), ' ' )
	iadr = ist + iq
	csave = chedr (iadr:lnch)
	CALL ST_LSTR ( csave, lnsv, ier )
	iadr = iadr - 2
C
C*	Do frequency matching if requested:
C
	IF ( mfrq ) THEN
	    DO i = 1, kxy
		IF ( inout (i) .eq. 1 ) THEN
		    tmpg (i) = fgrd (i)
		    tmpa (i) = agrd (i)
		ELSE
		    tmpg (i) = RMISSD
		    tmpa (i) = RMISSD
		END IF
	    END DO
	    CALL SFLMFD ( kxy, tmpa, tmpg, ier )
	ELSE
	    DO i = 1, kxy
		tmpg (i) = fgrd (i)
		tmpa (i) = agrd (i)
	    END DO
	END IF
C
C*	Loop over each threshold.
C
	DO ith = 1, nth
	    IF ( ERMISS (thlds(ith)) ) THEN
		iret = -26
		CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
		RETURN
	    ELSE
		CALL ST_LSTR ( cthld (ith), lnr, ier )
		chedr = chedr (1:iadr) // cthld(ith) (1:lnr) // ' ' //
     +			csave (1:lnsv)
		CALL ST_LSTR ( chedr, lnch, ier )
	    END IF
	    rn = 0
	    rf = 0
	    rh = 0
	    ro = 0
            rh2 = 0
            rf2 = 0
	    DO i = 1, kxy
		IF ( .not. ERMISS ( tmpa (i) ) .and.
     +		     .not. ERMISS ( tmpg (i) ) .and.
     +		     inout (i) .eq. 1 ) THEN
		    rn = rn + sgrd (i)
		    ok = .false.
		    IF ( sttyp .eq. 'FHO>' ) THEN
			IF ( fgrd (i) .ge. thlds (ith) ) THEN
			    rf = rf + sgrd (i)
			    ok = .true.
			END IF
			IF ( agrd (i) .ge. thlds (ith) ) THEN
			    ro = ro + sgrd (i)
			    IF ( ok ) rh = rh + sgrd (i)
			END IF
		    ELSE
			IF ( fgrd (i) .le. thlds (ith) ) THEN
			    rf = rf + sgrd (i)
			    ok = .true.
			END IF
			IF ( agrd (i) .le. thlds (ith) ) THEN
			    ro = ro + sgrd (i)
			    IF ( ok ) rh = rh + sgrd (i)
			END IF
		    END IF
C*
		    ok = .false.
		    IF ( sttyp .eq. 'FHO>' .and. mfrq ) THEN
			IF ( tmpg (i) .ge. thlds (ith) ) THEN
			    rf2 = rf2 + sgrd (i)
			    ok = .true.
			END IF
			IF ( tmpa (i) .ge. thlds (ith) ) THEN
			    IF ( ok ) rh2 = rh2 + sgrd (i)
			END IF
		    ELSE IF ( mfrq ) THEN
			IF ( tmpg (i) .le. thlds (ith) ) THEN
			    rf2 = rf2 + sgrd (i)
			    ok = .true.
			END IF
			IF ( tmpa (i) .le. thlds (ith) ) THEN
			    IF ( ok ) rh2 = rh2 + sgrd (i)
			END IF
		    END IF
		END IF
	    END DO
C*
	    IF ( rn .gt. 0 .and. mfrq ) THEN
		f = rf / rn
		h = rh / rn
		o = ro / rn
                h2 = rh2 / rn
                f2 = rf2 / rn
		WRITE (cl1l2,1000) rn, f, h, o, h2, f2
1000		FORMAT ( F10.2, 5(1X,1PE12.5) )
		CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
		DO i = 1, nlun
		    WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
		END DO
	    ELSE IF ( rn .gt. 0 ) THEN
		f = rf / rn
		h = rh / rn
		o = ro / rn
		WRITE (cl1l2,2000) rn, f, h, o
2000		FORMAT ( F10.2, 3(1X,1PE12.5) )
		CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
		DO i = 1, nlun
		    WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
		END DO
	    ELSE
		WRITE (6,*) chedr(1:lnch), ' --------:'
		WRITE (6,*)
     +		' All points zero, missing, or not in region.'
	    END IF
	END DO
C*
	RETURN
	END
