	PROGRAM GD2OBS
C************************************************************************
C* PROGRAM GD2OBS							*
C*									*
C*    GD2OBS performs verification on gridded forecasts of scalar	*
C*    values.  These values are linearly interpolated to point		*
C*    observations.  Either FHO or SL1L2 norm VSDB statistics are	*
C*    computed and written to the OUTPUT.				*
C*									*
C**									*
C* Log:									*
C* K. Brill/HPC		10/05						*
C* K. Brill/HPC      20080304  Call GD_INIT				*
C* K. Brill/IMSG     20150423  Add frequency matching for FHO           *
C* C. Bailey/WPC     20150925  Add PBS stats                            *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	CHARACTER*(LLMXLN)
     +			gdfile, gdatim, gvcord, gfunc, glevel,
     +			sffile, sfparm, dattim
	CHARACTER*(LLMXLN)
     +			vdbfrcid, vdbfrchr, vdbanlid,
     +			vdbfrcgd, vdbstatt, vdbprmnm,
     +			vdblvlnm, regins, output
	LOGICAL		useara, mfrq
C*
	REAL		grid (4*LLMXGD), sgrd (4*LLMXGD), rdata(MMPARM)
	REAL		ogx (LLSTFL), ogy (LLSTFL), obs (LLSTFL),
     +			for (LLSTFL), scl (LLSTFL), thldg (LLSTFL)
	REAL            tmpg (LLSTFL), tmpa (LLSTFL)
	INTEGER         level (2), intdtf (3), TG_YYMD, lhdrs (9)
	CHARACTER	time (2)*20, parm*12,
     +			parms(MMPARM)*4, stid*8, prmcur(LLMXLN),
     +			pfunc*72, sdattim*20, sfp*(LLMXLN),
     +			timfnd*36, cparm(MMPARM)*4, 
     +			catprobs*(LLMXLN), thldgfnc*(LLMXLN)
	CHARACTER*64	gdfun
	CHARACTER*4	sttyp
	CHARACTER*20	vlddtm, timtmp, vdtm
	CHARACTER*24    vhdrs (9)
	LOGICAL		chrflg(MMPARM)
	LOGICAL		respnd, done, proces, contin, gottm, conth
C*	
	INCLUDE		'ERMISS.FNC'
C-----------------------------------------------------------------------
C*      Initialize user interface and GEMPLT.
C
        CALL IP_INIT  ( respnd, iperr )
        IF  ( iperr .eq. 0 )  THEN
            mode = 1
            CALL GG_INIT  ( mode, iperr )
            IF ( iperr .ne. 0 ) THEN
                ierr = -16
                CALL ER_WMSG ( 'GD2OBS', ierr, ' ', ier )
            END IF
            CALL GG_SDEV ( 'GN', ierr )
            IF ( ierr .ne. 0 ) THEN
                ierr = -1
                CALL ER_WMSG ( 'GD2OBS', ierr, ' ', ier )
                iperr = ierr
            END IF
        END IF
        IF  ( iperr .eq. 0 )  THEN
            done = .false.
          ELSE
            done = .true.
        END IF
	CALL IP_IDNT  ( 'GD2OBS', ier )
C
C*	Initialize the DG library.
C
	CALL GD_INIT ( ier )
	CALL DG_INTL ( ier )
C
C*	Main loop to read in TAE parameters and write SFC file.
C
	DO WHILE  ( .not. done )
C
C*	    Get the user input.
C
	    proces = .true.
            CALL GD2INP  ( gdfile, gdatim, gvcord, gfunc, glevel,
     +                     sffile, sfparm, dattim,
     +                     vdbfrcid, vdbfrchr, vdbanlid,
     +                     vdbfrcgd, vdbstatt, vdbprmnm, vdblvlnm,
     +                     regins, catprobs, thldgfnc, useara, mfrq, 
     +                     output, iperr )
C
C*	    Check validity of input parameters.
C
	    iret = 0
	    IF ( vdbfrcid .eq. ' ' ) THEN
		iret = -5
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdbfrchr .eq. ' ' ) THEN
		iret = -6
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdbanlid .eq. ' ' ) THEN
		iret = -7
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdbfrcgd .eq. ' ' ) THEN
		iret = -8
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdbstatt .eq. ' ' ) THEN
		iret = -9
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdbprmnm .eq. ' ' ) THEN
		iret = -10
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
	    IF ( vdblvlnm .eq. ' ' ) THEN
		iret = -11
		CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
	    END IF
C*
	    iperr = iret
	    IF  ( iperr .ne. 0 )  THEN
		done = .true.
	      ELSE
C
C*		Check for valid statistic type.
C
		CALL ST_LCUC ( vdbstatt, vdbstatt, ier )
		IF ( INDEX ( vdbstatt, 'FHO' ) .ne. 0 ) THEN
		    sttyp = 'FHO'
		ELSE IF ( INDEX ( vdbstatt, 'SL1L2' ) .ne. 0 ) THEN
		    sttyp = 'L1L2'
		ELSE IF ( INDEX ( vdbstatt, 'PBS_' ) .ne. 0 ) THEN
                    sttyp = 'PBS'
		ELSE
		    iret = -18
		    CALL ER_WMSG ( 'GD2OBS', iret, vdbstatt, ier )
		    proces = .false.
		END IF
C
C*		Open the surface file.
C
		IF  ( proces )  THEN
		    CALL SF_OPNF  ( sffile, .false., isffln, iflsrc, 
     +				    nparm, parms, iperr )
		    IF  ( iperr .ne. 0 )  proces = .false.
		END IF
C
C*		Initialize the PC library.
C
		CALL  PC_INIT  ( 0, nparm, parms, iret )
		IF ( iret .ne. 0 ) THEN
		    CALL ER_WMSG ( 'PC', iret, sfp, ier )
		    iperr = -13
		    proces = .false.
		END IF
C
C*		Check for parameter computability.
C
		CALL ST_LCUC ( sfparm, sfp, ier )
		CALL SFLPRM ( .false., sfp, parms, nparm,
     +			      .false., .false.,
     +                        prmcur, ncprm, chrflg, cparm, iret )
		IF ( iret .ne. 0 ) THEN
		    CALL ER_WMSG ( 'GD2OBS', iret, sfp, ier )
		    proces = .false.
		ELSE IF ( chrflg(1) .or. ncprm .le. 0 ) THEN
		    iret = -14
		    CALL ER_WMSG ( 'GD2OBS', iret, sfp, ier )
		    proces = .false.
		ELSE IF ( ncprm .gt. 1 ) THEN
		    iret = -15
		    CALL ER_WMSG ( 'GD2OBS', iret, sfp, ier )
		    proces = .false.
		END IF
C
C*              Process the GDFILE input.
C
		IF ( proces ) THEN
                    CALL DG_NFIL ( gdfile, ' ', iperr )
                    IF ( iperr .ne. 0 ) THEN
                        CALL ER_WMSG ( 'DG', iperr, ' ', ier )
                        proces = .false.
                    END IF
		END IF
C
C*              Process the GDATTIM input.
C
                IF ( proces ) THEN
                    CALL DG_NDTM ( gdatim, iperr )
                    IF ( iperr .ne. 0 ) THEN
                        CALL ER_WMSG ( 'DG', iperr, ' ', ier )
                        proces = .false.
                      ELSE
                        CALL DG_QTMS ( 2, .false., time, ntms,
     +                                 timfnd, iperr )
                        IF ( iperr .ne. 0 .or. ntms .gt. 1 )
     +                      proces = .false.
                    END IF
                END IF
C
C*              Get the time to process.
C
                IF ( proces ) THEN
                    CALL DG_NTIM ( .false., .false., time,
     +		                   gottm, iperr )
                    IF ( iperr .ne. 0 .or. .not. gottm ) THEN
                        CALL ER_WMSG ( 'DG', iperr, ' ', ier )
                        proces = .false.
                      ELSE
                        CALL TG_DUAL ( time, timfnd, iperr )
                    END IF
                END IF
C
C*		Compute the grid data.
C
		IF  ( proces )  THEN
		    CALL DG_GRID  ( timfnd, glevel, gvcord, gfunc,
     +			            pfunc, grid, igx, igy, time,
     +				    level, ivcord, parm, iperr )
		    IF  ( iperr .ne. 0 )  THEN
			iret = -3
		        CALL ER_WMSG  ( 'DG', iperr, pfunc, ier )
			proces = .false.
		    END IF
		END IF
C       
C*              If the user requests area summation rather than count
C*              summation, then compute the reciprocal of the product
C*              of the map scale factors.   This product is the area
C*              normalized by the area of a grid box on the map
C*              projection plane.
C           
                IF ( useara .and. proces ) THEN
                    gdfun = 'QUO(1,MUL(msfx,msfy))'
                    CALL DG_GRID ( timfnd, glevel, gvcord, gdfun,
     +                             pfunc, sgrd, igx, igy, time,
     +                             level, ivcord, parm, iret )
                    IF( iret .ne. 0 ) THEN
                        iret = -31
                        CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
                        proces = .false.
                    ELSE
                        WRITE (6,*) ' Using NORMALIZED AREA count'
                    END IF
                ELSE IF ( proces ) THEN 
                    DO ig = 1, igx * igy
                        sgrd (ig) = 1.0 
                    END DO
                    WRITE (6,*) ' Using GRID POINT count'
                END IF
C
C*              Compute the valid time from the forecast time.
C
                IF ( proces ) THEN
                    CALL TG_VALD ( time (1), vlddtm, ier )

                    IF ( ier .ne. 0 ) THEN 
			ifhr = 0
                        CALL ER_WMSG ( 'TG', ier, time (1), ierr )
                        proces = .false.
                    ELSE
                        iv = INDEX ( vlddtm, 'V' )
                        IF ( iv .ne. 0 ) THEN
                            timtmp = vlddtm (1:iv-1) // 'F000'
                            vlddtm = timtmp
                            CALL TG_CTOI ( vlddtm, intdtf, ier )
                            iymd = TG_YYMD ( intdtf (1) )
                            ihhm = intdtf (2)
                            CALL TG_CTOI ( time(1), intdtf, ier )
                            ifhr = MOD ( intdtf (3), 100000 ) / 100
                        ELSE
			    ifhr = 0
                        END IF
                    END IF
                END IF
		CALL ST_NUMB ( vdbfrchr, kvfhr, ier )
		IF ( ier .ne. 0 ) THEN
		    iret = -12
		    CALL ER_WMSG ( 'GD2OBS', iret, vdbfrchr, ier )
		    proces = .false.
		ELSE IF ( kvfhr .ne. ifhr ) THEN
		    iret = +1
		    CALL ER_WMSG ( 'GD2OBS', iret, vdbfrchr, ier )
		END IF
C
C*		Convert the grid time to a valid time for use in 
C*		the surface file.
C
		IF  ( proces )  THEN
		    IF ( dattim .eq. ' ' ) THEN
		        sdattim = vlddtm(1:11)
		    ELSE
			sdattim = dattim
		    END IF
		    CALL SF_STIM  ( isffln, sdattim, iperr )
C
C*		    If the time does not exist in the file, an error
C*		    occurs.
C
		    IF  ( iperr .ne. 0 )  THEN
		        CALL ER_WMSG  ( 'SF', iperr, sdattim, ier )
			proces = .false.
		    END IF
		END IF
C
C*		Loop over all stations.
C
		IF  ( proces )  THEN
		    iostat = 0
		    contin = .true.
		    nobs = 0
		    DO WHILE ( iostat .eq. 0 .and. contin )
		        CALL SF_SNXT  ( isffln, stid, istnm, slat,
     +				        slon, selv, ispri, iostat )
			IF  ( iostat .eq. 0 .and. contin )  THEN
C
C*			    Compute the parameter required.
C
			    CALL SFLDTA  ( isffln, stid, istnm,
     +			    		   slat, slon, selv,
     +                       		   ispri, rdata, cparm, iret )
C
C*			    Interpolate the grid data to this station.
C
			    IF ( iret .eq. 0 .and.
     +				 .not. ERMISS ( rdata(1) ) ) THEN
				nobs = nobs + 1
				ogx (nobs) = slat
				ogy (nobs) = slon
				obs (nobs) = rdata (1)
			    END IF
			    IF ( nobs .eq. LLSTFL ) THEN
				CALL ER_WMSG ( 'GD2OBS', +2, ' ', ier )
				contin = .not. contin
			    END IF
			END IF
		    END DO
		    IF ( nobs .le. 0 ) THEN
			iret = -4
			CALL ER_WMSG ( 'GD2OBS', iret, ' ', ier )
			proces = .false.
		    ELSE
			CALL GTRANS ( 'M', 'G', nobs, ogx, ogy,
     +				      ogx, ogy, ier )
C
C*			Interpolate grid values to obs points.
C
			CALL GR_INTP ( 0, ogx, ogy, nobs, igx, igy,
     +				       grid, for, ier )
C
C*			Interpolate grd box scaling values to obs points.
C
			CALL GR_INTP ( 0, ogx, ogy, nobs, igx, igy,
     +				       sgrd, scl, ier )
		    END IF
		END IF
C
C####		CALL LISTDATA ( nobs, ogx, ogy, obs, for, scl, iret )
C
C
C*		Do verification of FOR against OBS.
C
		IF ( proces .and. sttyp .eq. 'FHO' ) THEN
		    IF ( mfrq ) THEN
                        WRITE (6,*) ' Frequency matching requested.'
                    END IF
		    CALL GD2FHO ( vdbfrcid, vdbfrchr, vdbanlid,
     +                            vdbfrcgd, vdbstatt, vdbprmnm,
     +                            vdblvlnm, ifhr, iymd, ihhm,
     +                            regins, output,
     +                            nobs, ogx, ogy, obs, for, scl, 
     +                            mfrq, tmpg, tmpa, iret )
		else IF ( proces .and. sttyp .eq. 'PBS' ) THEN
		    CALL ST_CRNM ( thldgfnc, thval, ier )
                    conth = .not. ( ERMISS ( thval ) .or. ier .ne. 0 )
		    vdtm = "20"//sdattim(1:6)//sdattim(8:9)
                    CALL GDMHDR ( vdbfrcid, vdbfrchr, vdtm, vdbanlid,
     +                            vdbfrcgd, vdbstatt, vdbprmnm,
     +                            vdblvlnm, thval, conth, vhdrs, lhdrs,
     +                            iret )
		    IF ( iret .eq. 0 ) THEN
			DO x = 1, nobs, 1
			    thldg(x) = thval
			ENDDO
		        CALL GD2PBS ( catprobs, vhdrs, lhdrs, regins, 
     +                            nobs, ogx, ogy, obs, for, scl, thldg,
     +                            output, iret )
		    ELSE
			proces = .false.
		    END IF
		ELSE IF ( proces ) THEN
		    CALL GD2SLL ( vdbfrcid, vdbfrchr, vdbanlid,
     +                            vdbfrcgd, vdbstatt, vdbprmnm,
     +                            vdblvlnm, ifhr, iymd, ihhm,
     +                            regins, output,
     +                            nobs, ogx, ogy, obs, for, scl, iret )
		END IF
C
C*		Close the surface and grid files.
C
		IF  ( isffln .gt. 0 )  CALL SF_CLOS  ( isffln, ier )
C
		CALL IP_DYNM ( done, iperr )
	    END IF
	END DO
C
C*	Print general error messages if necessary.
C
	IF  (iperr .ne. 0)  CALL ER_WMSG ( 'GD2OBS', iperr, ' ', ier )
C
C*	Exit from GEMPLT and the TAE.
C
	CALL GENDP   ( 0, iret )
	CALL IP_EXIT ( iret )
C*
	END
