	SUBROUTINE GD2PBS ( catprobs, vhdrs, lhdrs, 
     +                      regions, nobs, ogx, ogy,
     +                      obs, for, scl, thldg, output, iret )
C************************************************************************
C*  GD2PBS								*
C*									*
C*  This program computes VSDB PBS statistic records given an analysis	*
C*  grid, a grid of forecast probabilities, and a threshold grid along	*
C*  with the categorical probability range boundary inputs.		*
C*									*
C*  GD2PBS ( CATPROBS, VHDRS, LHDRS, ANLYG, FRCPB, THLDG, MX, MY, 	*
C*           REGIONS, LUNS, NLUN, THVAL, CONTH, IRET )			*
C*									*
C* Input parameters:							*
C*	CATPROBS	CHAR*		List of boundaries of prb ranges*
C*	VHDRS (9)	CHAR*		VSDB record headers		*
C*	LHDRS (9)	INTEGER		VSDB record header lengths	*
C*	REGIONS		CHAR*		Name of file defining subregion *
C*					polygons			*
C*	LUNS (NLUN)	INTEGER		Output logical unit # array	*
C*	NLUN		INTEGER		Number of LUNS			*
C*      NOBS            INTEGER         Number of observation points    *
C*      OGX (NOBS)      REAL            Obs X frcst grid rel coordinates*
C*      OGY (NOBS)      REAL            Obs Y frcst grid rel coordinates*
C*      OBS (NOBS)      REAL            Observation values              *
C*      FOR (NOBS)      REAL            Forecast values at obs points   *
C*      SCL (NOBS)      REAL            Frcst grd box scale at obs pts  *
C*									*
C* Output parameter:							*
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/HPC		06/05						*
C* C. Bailey/WPC        10/15		Add PBS stats to gd2obs		*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER       ( MXPOLY = 1024 )
	PARAMETER	( MXRNGS = 12 )
C************************************************************************
	CHARACTER*(*)	catprobs, vhdrs (*), regions, output
	INTEGER		lhdrs (*)
	REAL		ogx (*), ogy (*), obs (*), for (*), scl (*),
     +                  thldg (*)
C*
	CHARACTER	cprj*4, sysin*2
	CHARACTER*80	record, entry (2)
	INTEGER		inout (LLMXGD)
	INTEGER         luns (4)
	REAL		rnav (LLNNAV)
	REAL		rlat (LLMXGD), rlon (LLMXGD)
	REAL            rnx (LLMXGD), rny (LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
C*
	CHARACTER	crgn*32, orec*128
	REAL		sgrd (LLMXGD)
	REAL		prng ( MXRNGS )
C------------------------------------------------------------------------
	iret = 0
	sysin = 'N'
	CALL ST_NULL ( sysin, sysin, lnn, ier )
C
C*	 Get the output units.
C
	CALL IN_OUTT (output, 'GDGPBS', luns, nlun,
     +                        devs, iret)
        IF ( iret .ne. 0 ) THEN
            CALL ER_WMSG ( 'IN', iret, ' ', ier )
	    ios = iret
        END IF
C*
	CALL GDBC2R ( catprobs, MXRNGS, prng, nrng, iret )
C*
	IF ( iret .ne. 0 ) RETURN
C
C*	Generate data records for subregions and whole grid.
C
	lunr = 0
	CALL FL_SOPN ( regions, lunr, ios )
	IF ( ios .eq. 0 ) THEN
C*
	    CALL GSMPRJ ( 'CED', 0., 0., 0., -90., 0., 90., 0.,
     +                    ier )
            IF ( ier .ne. 0 ) THEN
                WRITE (6,*) ' Cannot set map projection.'
                ios = ier
            END IF
            IF ( ios .eq. 0 ) THEN
                CALL GTRANS ( 'G', 'N', nobs, ogx, ogy,
     +                        rnx, rny, ier )
                IF ( ier .ne. 0 ) THEN
                    WRITE (6,*) ' Cannot get normalized grid point',
     +                          ' coordinates.'
                    ios = ier
                END IF
            END IF
        END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    crgn = entry(1)
		    CALL ST_LSTR ( crgn, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regions
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', crgn(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, nobs, rnx, rny,
     +                                    sysin, npoly, xpoly, ypoly,
     +                                    inout, ier )
			icnt = 0
			DO i = 1, nobs
                            icnt = icnt + inout (i)
                        END DO
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE IF ( icnt .gt. 0 ) THEN
			    record = vhdrs(6)(1:lhdrs(6)) // '/' //
     +				     crgn(1:lrgn)
			    crgn = record
			    CALL ST_LSTR ( crgn, lrgn, ier )
			    record = vhdrs(1)
			    orec = vhdrs(1)
			    DO i = 2, 9
				CALL ST_LSTR ( record, l1, ier )
				CALL ST_LSTR ( orec, l2, ier )
				IF ( i .ne. 6 ) THEN
				    record = orec(1:l2) // ' ' //
     +					     vhdrs(i)(1:lhdrs(i))
				ELSE
				    record = orec(1:l2) // ' ' //
     +					     crgn(1:lrgn)
				END IF
				orec = record
			    END DO
			    CALL MKGPBS ( obs, thldg, for, scl, nobs,
     +					  inout, prng, nrng, nlun, luns,
     +					  orec, iret )
			    IF ( iret .ne. 0 ) RETURN
			ELSE
			    WRITE (6,*) crgn(1:lrgn),
     +                            ' is not on the verification domain.'
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C
C*	Do entire grid.
C
        DO i = 1, nobs
            inout (i) = 1
        END DO
C*
	record = vhdrs(1)
	orec = vhdrs(1)
	DO i = 2, 9
	    CALL ST_LSTR ( record, l1, ier )
	    CALL ST_LSTR ( orec, l2, ier )
	    record = orec(1:l2) // ' ' //
     +	             vhdrs(i)(1:lhdrs(i))
	    orec = record
	END DO
	CALL MKGPBS ( obs, thldg, for, scl, nobs,
     +		      inout, prng, nrng, nlun, luns, orec, iret )
C*
	RETURN
	END
