	SUBROUTINE MKGPBS ( anlyg, thldg, fprb, sgrd, kxy, inout,
     +			    prng, nrng, nlun, luns, orec, iret )
C************************************************************************
C* MKGPBS								*
C*									*
C* This subroutine computes PBS_ record values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* MKGPBS ( ANLYG, THLDG, FPRB, SGRD, KXY, INOUT, PRNG, NRNG,		*
C*          NLUN, LUNS, OREC, IRET )					*
C*									*
C* Input parameters:							*
C*	ANLYG (KXY)	REAL		Analysis grid			*
C*	THLDG (KXY)	REAL		Threshold grid			*
C*	FPRB  (KXY)	REAL		Forecast probability grid	*
C*	SGRD  (KXY)	REAL		Normalized box area grid	*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	PRNG (NRNG)	REAL		Probability range bound array	*
C*	NRNG		INTEGER		Number of range bounds		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	OREC		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC      20070228						*
C* K. Brill/HPC      20070305	Set found=.true. for fprb = 1 case	*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=256, MXFOE=64 )
C*
	REAL 		anlyg (*), fprb (*), sgrd (*), thldg (*)
	REAL		prng (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	orec
	
C*
	REAL		foe (MXFOE)
C
C*         Let pN = prng (N)
C*	   Let M = nrng
C*	   foe (1) = fraction of events with 0<p<=p2 frcst
C*	   foe (2) = fraction of events with p2<p<=p3 frcst
C*	   foe (3) = fraction of events with p3<p<=p4 frcst
C*         . . . .
C*         foe (M-1) = fraction of events with pM-1<p<pM=1 frcst
C*         foe (M) = fraction of events with p=1 frcst
C*	   foe (M+1) = fraction of events obsvd & p=0 frcst
C*	   foe (M+2) = fraction of events obsvd & 0<p<=p2 frcst
C*	   foe (M+3) = fraction of events obsvd & p2<p<=p3 frcst
C*         . . . .
C*	   foe (M+M) = fraction of events obsvd & pM-1<p<pM=1 frcst
C*         foe (2M+1) = fraction of events obsvd & p=1 frcst
C*
	LOGICAL		found, obsd
	CHARACTER	cl1l2*(MXC)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL ST_LCUC ( orec, orec, ier )
	CALL ST_RXBL ( orec, orec, lnch, ier )
C
C*	Initialize counters for the fractions.
C
	mfoe = 2 * nrng + 1
	IF ( mfoe .gt. MXFOE ) THEN
	    iret = -23
	    RETURN
	END IF
	DO k = 1, mfoe
	    foe (k) = 0.0
	END DO
	rn = 0.0
	ibad = 0
	DO i = 1, kxy
	    IF ( .not. ERMISS ( anlyg (i) ) .and.
     +		 .not. ERMISS ( thldg (i) ) .and.
     +		 .not. ERMISS ( fprb (i) ) .and.
     +		 .not. ERMISS ( sgrd (i) ) .and.
     +		 inout (i) .eq. 1 ) THEN
C
C*		Correct for small interpolation induced bad
C*		probability values.
C
		IF ( fprb (i) .lt. 0.0 ) fprb (i) = 0.0
		IF ( fprb (i) .gt. 1.0 ) fprb (i) = 1.0
		rn = rn + sgrd (i)
		IF ( anlyg (i) .gt. thldg (i) ) THEN
		    obsd = .true.
		ELSE
	    	    obsd = .false.
		END IF
		indx = 0
		kp = 1
		kstop = nrng - 1
		found = .false.
		DO WHILE ( .not. found .and. kp .lt. kstop )
		    kp = kp + 1
		    indx = indx + 1
		    IF ( fprb (i) .gt. prng (kp-1) .and.
     +			 fprb (i) .le. prng (kp) ) THEN
			foe (indx) = foe (indx) + sgrd (i)
			found = .true.
		    END IF
		END DO
		IF ( .not. found ) THEN
		    kp = nrng
		    indx = indx + 1
		    IF ( fprb (i) .gt. prng (kp-1) .and.
     +		         fprb (i) .lt. prng (kp) ) THEN
		        foe (indx) = foe (indx) + sgrd (i)
		  	found = .true.
		    END IF
		END IF
		IF ( .not. found ) THEN
		    indx = indx + 1
		    IF ( fprb (i) .eq. prng (nrng) ) THEN
			foe (indx) = foe (indx) + sgrd (i)
			found = .true.
		    END IF
		END IF
	 	IF ( obsd ) THEN
		    IF ( .not. found .and. fprb (i) .ne. 0.0 ) THEN
			ibad = ibad + 1
			rn = rn - sgrd (i)
		    ELSE
			IF ( .not. found ) indx = 0
		        indx2 = nrng + indx + 1
		        foe (indx2) = foe (indx2) + sgrd (i)
		    END IF
		ELSE IF ( .not. found .and. fprb (i) .ne. 0.0 ) THEN
		    ibad = ibad + 1
		    rn = rn - sgrd (i)
		END IF
	    END IF
	END DO
C*
	nrn = NINT ( rn )
	rn = FLOAT ( nrn )
	IF ( nrn .gt. 0 ) THEN
	    DO k = 1, mfoe
		foe (k) = foe (k) / rn
	    END DO
	    WRITE (cl1l2,1000) nrn, (foe(k),k=1,mfoe)
1000	    FORMAT ( I7, 24(1X,F7.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,A,A)') orec (1:lnch),
     +				' = ', cl1l2 (1:lnch2)
	    END DO
	    IF ( ibad .ne. 0 ) THEN
		WRITE (6,*) ' WARNING:  Forecast probabilities have ',
     +                      'impossible values at ', ibad, ' points.'
	    END IF
	ELSE
	    WRITE (6,*) orec(1:lnch), ' --------:'
	    WRITE (6,*)
     +		' All points zero, missing, or not in region.'
	END IF
C*
	RETURN
	END
