	SUBROUTINE GDFOUT  ( luns, nlun, frcstr, anlsrc, ifhr,
     +			     iymd, ihhm, carea, i1lon, i2lon,
     +			     phibnd, idphi, parm, lvl, ivcord,
     +			     iw, pe, fa, aa, ptrn, fvarcn, tfvar,
     +			     ovarcn, tovar, wvlen, iwvnm, iret )
C************************************************************************
C* GDFOUT								*
C*									*
C* This subroutine prints data for the GDFAZR program.			*
C*									*
C* GDFOUT  ( LUNS, NLUN, FRCSTR, ANLSRC, IFHR, IYMD, IHHM,		*
C*	     CAREA, I1LON, I2LON, PHIBND, IDPHI,			*
C*	     PARM, LVL, IVCORD, IW, PE, FA, AA, PTRN, FVARCN, TFVAR,	*
C*	     OVARCN, TOVAR, FRCOV, WVLEN, IWVNM, IRET )			*
C*									*
C* Input parameters:							*
C*	LUNS (NLUN)	INTEGER		List of output unit numbers	*
C*	NLUN		INTEGER		Number of output units		*
C*	FRCSTR		CHAR*		Forecaster ID for FVS field 2	*
C*	ANLSRC		CHAR*		Analysis description field	*
C*	IFHR		INTEGER		Forecast hour			*
C*	IYMD		INTEGER		Date:  YYYYMMDD			*
C*	IHHM		INTEGER		TIME:  HHMM			*
C*	CAREA		CHAR*		Region name			*
C*	I1LON		INTEGER		West-most longitude of band	*
C*	I2LON		INTEGER		East-most longitude of band	*
C*	PHIBND		REAL		Center latitude of band		*
C*	IDPHI		INTEGER		Width of band (deg)		*
C*	PARM		CHAR*		Parameter name			*
C*	LVL		INTEGER		Vertical level			*
C*	IVCORD		INTEGER		GEMPAK vertical coord number	*
C*	IW		INTEGER		Ordinal number of spec comp	*
C*	PE		REAL		Phase shift error (KM)		*
C*	FA		REAL		Forecast amplitude		*
C*	AA		REAL		Analysis amplitude		*
C*	PTRN		REAL		Analysis phs ang (pattern id)	*
C*	FVARCN		REAL		Forcast variance contribution	*
C*	TFVAR		REAL		Total forecast variance		*
C*	OVARCN		REAL		Analysis variance contribution	*
C*	TOVAR		REAL		Total analysis variance		*
C*	WVLEN		REAL		Wave-length of spec component	*
C*	IWVNM		REAL		Wave-number of spec component	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -7 = invalid # of spec comps	*
C**									*
C* Log:									*
C* K. Brill/HPC          4/00						*
C* K. Brill/HPC		 6/00	Change output record			*
C* K. Brill/HPC		 8/00	Changes to output record (11 fields)	*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	INTEGER		luns (*)
	CHARACTER*(*)	frcstr, anlsrc, parm, carea
C*
	CHARACTER	vc*8, cphi*8, cdy*8, clev*8, ci1ln*8, ci2ln*8
	CHARACTER	region*32, cwvn*4, cdata*128, cwvln*8
C------------------------------------------------------------------------
	iret = 0
	IF ( iw .gt. 9 .or. iw .lt. 1 ) THEN
	    iret = -7
	    RETURN
	ENDIF
C
C*	Translate vertical coordinate.
C
	CALL ST_INCH ( lvl, clev, ier )
	CALL ST_LSTR ( clev, lnl, ier )
	IF ( ivcord .eq. 0 ) THEN
	    vc = 'SFC'
	ELSE IF ( ivcord .eq. 1 ) THEN
	    vc = 'P' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 2 ) THEN
	    vc = 'T' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 3 ) THEN
	    vc = 'Z' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 4 ) THEN
	    vc = 'S' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 5 ) THEN
	    vc = 'D' // clev (1:lnl)
	ELSE
	    vc = 'NONE'
	END IF
C
C*	Create character wave number and length.
C
	CALL ST_INCH ( iwvnm, cwvn, ier )
	CALL ST_LSTR ( cwvn, lwvn, ier )
	iwvln = NINT ( wvlen )
	CALL ST_INCH ( iwvln, cwvln, ier )
	CALL ST_LSTR ( cwvln, lwvln, ier )
	
C*
	CALL ST_LSTR ( vc, lvc, ier )
	CALL ST_LSTR ( frcstr, lfr, ier )
	CALL ST_LSTR ( parm, lpm, ier )
	CALL ST_LSTR ( anlsrc, las, ier )
C
C*	Create the region description field.
C
	IF ( carea .eq. ' ' ) THEN
	    CALL ST_RLCH ( phibnd, 1, cphi, ier )
	    CALL ST_LSTR ( cphi, lphi, ier )
	    CALL ST_INCH ( idphi, cdy, ier )
	    CALL ST_LSTR ( cdy, ldy, ier )
	    CALL ST_INCH ( i1lon, ci1ln, ier )
	    CALL ST_LSTR ( ci1ln, l1ln, ier )
	    CALL ST_INCH ( i2lon, ci2ln, ier )
	    CALL ST_LSTR ( ci2ln, l2ln, ier )
	    WRITE (region, 2222)
     +		 ci1ln(1:l1ln), ci2ln(1:l2ln),
     +		 cphi(1:lphi), cdy(1:ldy)
2222	    FORMAT (A,':', A,':',A,':',A)
	ELSE
	    region = carea
	END IF
	CALL ST_LSTR ( region, lrgn, ier )
C
C*	Build data portion of record.
C
	ae = fa - aa
	pefw = pe * fvarcn
	peow = pe * ovarcn
C*
	WRITE (cdata, 1111) '= 1', pe, ae, pefw, fvarcn,
     +			    peow, ovarcn,
     +			    ptrn, aa, tfvar, tovar
1111	FORMAT ( A, 1X, F7.0, 1X, F8.2, 4(1X, 1PE12.5),
     +		 0PF7.0, F8.2, 2(1X, 1PE12.5) )
	CALL ST_RXBL  ( cdata, cdata, lcdata, iret )
C*
	ihh = ihhm / 100
C
C*	Loop through each output device.
C
	DO  i = 1, nlun
	    lun = luns (i)
	    IF ( lun .ne. 6 ) THEN
		WRITE (lun,1001) 'V01', frcstr(1:lfr), ifhr, iymd, ihh,
     +		  anlsrc(1:las), region(1:lrgn), 'PHSE:', cwvn(1:lwvn),
     +		  cwvln(1:lwvln),
     +		  parm(1:lpm), vc(1:lvc), cdata (1:lcdata)
1001		FORMAT ( A, 1X, A, 1X, I3.3, 1X, I8, I2.2, 1X,
     +			 A, 1X, A, 1X, A, A, '/', A, 1X,
     +			 A, 1X, A, 1X, A )
	    ELSE
		WRITE (lun,1002) 'V01', frcstr(1:lfr), ifhr, iymd, ihh,
     +		  anlsrc(1:las), region(1:lrgn), 'PHSE:', cwvn(1:lwvn),
     +		  cwvln(1:lwvln),
     +		  parm(1:lpm), vc(1:lvc), cdata (1:lcdata)
1002		FORMAT ( A, 1X, A, 1X, I3.3, 1X, I8, I2.2, 1X,
     +			 A, 1X, A, 1X, A, A, '/', A, 1X,
     +			 A, 1X, A, 1X, /, A )
	    END IF
C
	END DO
C*
	RETURN
	END
