	SUBROUTINE GDDXDY  ( rnav, dx, dy, dxmax, dxmin, dymax, dymin,
     +			     iret )
C************************************************************************
C* GDDXDY								*
C*									*
C* This subroutine computes the X and Y  grid increments for the grid	*
C* defined by the navigation block, RNAV.				*
C*									*
C* The DX and DY increments returned are averages for the grid.		*
C*									*
C*  GDDXDY ( RNAV, DX, DY, DXMAX, DXMIN, DYMAX, DYMIN, IRET )		*
C*									*
C* Input parameters:							*
C*	RNAV (*)	REAL		Grid navigation block		*
C*									*
C* Output parameters:							*
C*	DX		REAL		Avg X grid spacing (KM)		*
C*	DY		REAL		Avg Y grid spacing (KM)		*
C*	DXMAX		REAL		Maximum X grid spacing		*
C*	DXMIN		REAL		Minimum X grid spacing		*
C*	DYMAX		REAL		Maximum Y grid spacing		*
C*	DYMIN		REAL		Minimum Y grid spacing		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -1 = DX, DY not computable	*
C*									*
C**									*
C* Log:									*
C* K. BRILL/HPC		 5/01						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	REAL		rnav (*)
C*
	REAL		rlt (LLMXGD), rln (LLMXGD)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL GR_SNAV ( 16, rnav, ier )
	kx = NINT ( rnav (5) )
	ky = NINT ( rnav (6) )
	n = 0
	DO j = 1, ky
	    DO i = 1, kx
		n = n + 1
		rlt (n) = i
		rln (n) = j
	    END DO
	END DO
	CALL GTRANS ( 'G', 'M', n, rlt, rln, rlt, rln, ier )
	dxmin = 1.E31
	dxmax = -1.E31
	dymin = 1.E31
	dymax = -1.E31
	dxavg = 0.0
	dyavg = 0.0
	DO i = 1, n
	    IF ( .not. ERMISS ( rlt (i) ) .and.
     +		 .not. ERMISS ( rln (i) ) ) THEN
		rlt (i) = rlt (i) * DTR
		rln (i) = rln (i) * DTR
	    END IF
	END DO
C*
	icnt = 0
	DO j = 2, ky-1
	    DO i = 2, kx-1
		ii = ( j - 1 ) * kx + i
		ip1 = ii + 1
		jp1 = ii + kx
		IF ( .not. ERMISS ( rlt (ii) ) .and.
     +		     .not. ERMISS ( rln (ii) ) .and.
     +		     .not. ERMISS ( rlt (ip1) ) .and.
     +		     .not. ERMISS ( rln (ip1) ) .and.
     +		     .not. ERMISS ( rlt (jp1) ) .and.
     +		     .not. ERMISS ( rln (jp1) ) ) THEN
		    xcos = COS ( rlt (ii) )
		    dlat = rlt (ip1) - rlt (ii)
		    IF ( rln (ip1) * rln (ii) .lt. 0.0 .and.
     +		      ( ABS (rln(ip1)) + ABS (rln(ii)) ) .gt. PI )
     +		    THEN
			dlon = TWOPI - ABS (rln(ip1)) - ABS (rln(ii))
		    ELSE
		        dlon = rln (ip1) - rln (ii)
		    END IF
		    dlon = 2. * ( 1. - COS ( dlon ) ) *
     +			   COS ( rlt(ip1) ) * xcos
		    dx = SQRT ( dlat * dlat + dlon )
		    dlat = rlt (jp1) - rlt (ii)
		    IF ( rln (jp1) * rln (ii) .lt. 0.0 .and.
     +		      ( ABS (rln(jp1)) + ABS (rln(ii)) ) .gt. PI )
     +		    THEN
			dlon = TWOPI - ABS (rln(jp1)) - ABS (rln(ii))
		    ELSE
		        dlon = rln (jp1) - rln (ii)
		    END IF
		    dlon = 2. * ( 1. - COS ( dlon ) ) *
     +			   COS ( rlt(jp1) ) * xcos
		    dy = SQRT ( dlat * dlat + dlon )
		    IF ( dx .gt. dxmax ) dxmax = dx
		    IF ( dy .gt. dymax ) dymax = dy
		    IF ( dx .lt. dxmin ) dxmin = dx
		    IF ( dy .lt. dymin ) dymin = dy
		    icnt = icnt + 1
		    dxavg = dxavg + dx
		    dyavg = dyavg + dy
		END IF
	    END DO
	END DO
	IF ( icnt .gt. 0 ) THEN
	    dd = FLOAT ( icnt )
	    dx = dxavg / dd
	    dy = dyavg / dd
	    dx = RADIUS * dx / 1000.
	    dy = RADIUS * dy / 1000.
	    dxmax = RADIUS * dxmax / 1000.
	    dxmin = RADIUS * dxmin / 1000.
	    dymax = RADIUS * dymax / 1000.
	    dymin = RADIUS * dymin / 1000.
	ELSE
	    iret = -1
	END IF
C*
	IF ( ABS ( dx - dy ) .lt. .001 ) dx = dy
C*
	RETURN
	END
