	SUBROUTINE GDBVDB ( gridid, frcstr, anlsrc, parm, regins,
     +                      statyp, ifhr, iymd, ihhm, level, ivcord,
     +                      luns, nlun, agrd, fgrd, kxf, kyf, gnav,
     +			    iret )
C************************************************************************
C* GDBVDB								*
C*									*
C* This subroutine computes GBS values and writes out VSDB records.	*
C*									*
C* GDBVDB  ( GRIDID, FRCSTR, ANLSRC, PARM, REGINS,			*
C*	     STATYP, IFHR, IYMD, IHHM, LEVEL, IVCORD, LUNS, NLUN,	*
C*	     AGRD, FGRD, KXF, KYF, GNAV, IRET )				*
C*									*
C* Input parameters:							*
C*	GRIDID		CHAR*		Grid ID for FVS field 6		*
C*	FRCSTR		CHAR*		Forecaster ID for FVS field 2	*
C*	ANLSRC		CHAR*		Analysis description field	*
C*	PARM		CHAR*		Parameter name			*
C*	REGINS		CHAR*		Regions table file name		*
C*	STATYP		CHAR*		Statistic type for FVS field 7	*
C*	IFHR		INTEGER		Forecast hour			*
C*	IYMD		INTEGER		Date:  YYYYMMDD			*
C*	IHHM		INTEGER		TIME:  HHMM			*
C*	LEVEL (2)	INTEGER		Vertical level			*
C*	IVCORD		INTEGER		GEMPAK vertical coord number	*
C*	LUNS (NLUN)	INTEGER		List of output unit numbers	*
C*	NLUN		INTEGER		Number of output units		*
C*	AGRD (KXF,KYF)	REAL		Analysis grid			*
C*	FGRD (KXF,KYF)	REAL		Forecast probability grid	*
C*	KXF		INTEGER		Grid X dimension		*
C*	KYF		INTEGER		Grid Y dimension		*
C*	GNAV (*)	REAL		Grid navigation block		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC         10/02						*
C* K. Brill/HPC		 3/03	Remove extra blanks from record		*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXPOLY = 256 )
C*
	INTEGER		luns (*), level (2)
	CHARACTER*(*)	gridid, frcstr, anlsrc, parm, regins, statyp
	REAL		agrd (*), fgrd (*), gnav (*)
C*
	REAL		rlat (LLMXGD), rlon (LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
	REAL		p1 (101), p2 (101), p3 (3)
	INTEGER		inout (LLMXGD)
	CHARACTER*64	sttps (2), sttyp
	CHARACTER	vc*8, clev*8
	CHARACTER	region*32, sysin*2
	CHARACTER*80	record
	CHARACTER*32	entry (2)
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
	ihh = ihhm / 100
	sysin = 'N'
	CALL ST_NULL ( sysin, sysin, lnn, ier )
C
C*	Get length of data descriptors.
C
	CALL ST_LSTR ( gridid, lgid, ier )
	CALL ST_LSTR ( frcstr, lfr, ier )
	CALL ST_LSTR ( anlsrc, las, ier )
	CALL ST_LSTR ( parm, lpm, ier )
C
C*	Parse the statistic type input.
C
	CALL ST_CLST ( statyp, '/', ' ', 2, sttps, nm, ier )
	IF ( ier .lt. 0 ) THEN
	    iret = -18
	    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
	    RETURN
	END IF
	IF ( nm .eq. 2 ) THEN
	    sttyp = sttps (1)
	    CALL ST_RLST ( sttps (2), '-', 0., 3, p3, nmp, ier )
	    IF ( ier .lt. 0 ) THEN
		iret = -18
		CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
		RETURN
	    END IF
C
C*	    P3 contains the starting, ending, and increment values for
C*	    probability ranges.
C
	    IF ( p3 (3) .eq. 0 ) THEN
		p1 (1) = p3 (1)
		p2 (1) = p3 (2)
		npr = 1
	    ELSE
		p1 (1) = p3 (1)
		pend = 0.0
		i = 1
		DO WHILE (  pend .lt. p3 (2) )
		    p2 (i) = p1 (1) + FLOAT (i) * p3 (3)
		    npr = i
		    i = i + 1
		    p1 (i) = p2 (npr)
		    IF ( ABS ( p2 (npr) - p3 (2) ) .lt. .00005 ) THEN
			pend = p3 (2)
		    ELSE
			pend = p2 (npr)
		    END IF
		END DO
	    END IF
	ELSE
	    npr = 0
	    sttyp = statyp
	END IF
	CALL ST_LSTR ( sttyp, lst, ier )
C
C*	Translate vertical coordinate.
C
	CALL ST_INCH ( level (1), clev, ier )
	CALL ST_LSTR ( clev, lnl, ier )
	IF ( ivcord .eq. 0 ) THEN
	    vc = 'SFC'
	ELSE IF ( ivcord .eq. 1 ) THEN
	    vc = 'P' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 2 ) THEN
	    vc = 'T' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 3 ) THEN
	    vc = 'Z' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 4 ) THEN
	    vc = 'S' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 5 ) THEN
	    vc = 'D' // clev (1:lnl)
	ELSE
	    vc = 'NONE'
	END IF
C*
	CALL ST_LSTR ( vc, lvc, ier )
C
C*	Generate data records for subregions and whole grid.
C
	CALL FL_SOPN ( regins, lunr, ios )
	IF ( ios .eq. 0 ) THEN
C
C*	    Prepare to call CGRINPOLY.
C
	    CALL GSMPRJ ( 'CED', 0., 0., 0., -90., 0., 90., 0.,
     +			  ier )
	    IF ( ier .ne. 0 ) THEN
		WRITE (6,*) ' Cannot set map projection.'
		ios = ier
	    END IF
	    IF ( ios .eq. 0 ) THEN
C
C*		Create test points on grid.
C
		CALL GR_SNAV ( 16, gnav, ier )
		IF ( ier .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot set grid navigation.'
		    ios = ier
		END IF
	    END IF
	    IF ( ios .eq. 0 ) THEN
		kxy = 0
		DO j = 1, kyf
		    DO i = 1, kxf
			kxy = kxy + 1
			rlat (kxy) = FLOAT (i)
			rlon (kxy) = FLOAT (j)
		    END DO
		END DO
		CALL GTRANS ( 'G', 'N', kxy, rlat, rlon,
     +			      rlat, rlon, ier )
		IF ( ier .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot get normalized grid point',
     +				' coordinates.'
		    ios = ier
		END IF
	    END IF
	END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    region = gridid(1:lgid) // '/' // entry(1)
		    CALL ST_LSTR ( region, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regins
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', region(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE
			    WRITE (record,1000) 'V01', frcstr(1:lfr),
     +				  ifhr, iymd, ihh,
     +		                  anlsrc(1:las), region(1:lrgn),
     +				  sttyp (1:lst), parm(1:lpm),
     +				  vc(1:lvc)
			    CALL ST_RXBL ( record, record, lln, ier )
			    CALL GBSNRM ( sttyp, p1, p2, npr,
     +					  agrd, fgrd, kxy,
     +					  inout, nlun, luns, record,
     +					  ier )
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C
C*	Do entire grid.
C
	kxy = kxf * kyf
	DO i = 1, kxy
	    inout (i) = 1
	END DO
C*
	WRITE (record,1000) 'V01', frcstr(1:lfr), ifhr, iymd, ihh,
     +	      anlsrc(1:las), gridid(1:lgid), sttyp (1:lst),
     +	      parm(1:lpm), vc(1:lvc)
1000	FORMAT ( A, 1X, A, 1X, I3, 1X, I8, I2.2, 5 (1X, A), ' =' )
C*
	CALL ST_RXBL ( record, record, lln, ier )
	CALL GBSNRM ( sttyp, p1, p2, npr, agrd, fgrd, kxy,
     +		      inout, nlun, luns, record, ier )
C*
	RETURN
	END
