	SUBROUTINE CMPUNC ( nrecs, nrgn, wgrd, gmiss, anlyg,
     +                      ipoly, kxy, ijskp, ubar, iret )
C************************************************************************
C*  CMPUNC								*
C*									*
C*  This program computes subregion area averages for the CRPS uncer-   *
C*  tainty term using the analysis values in ANLYG.  The subregions are *
C*  integer coded using values 1 through NRGN on the grid IPOLY.  If    *
C*  NRECS > NRGN an NRGN+1 average over all non-missing points of IPOLY *
C*  is also computed.  The averages are returned in the array UBAR.     *
C*									*
C*  CMPUNC ( NRECS, NRGN, WGRD, GMISS, ANLYG, IPOLY, KXY, WSUM, UBAR,   *
C*           IRET )                                                     * 
C*									*
C* Input parameters:							*
C*      NRECS           INTEGER         Number of averages expected     *
C*	NRGN            INTEGER		Number of regions coded in IPOLY*
C*      WGRD (KXY)      REAL            Grid box area weights           *
C*      GMISS (KXY)     REAL            Grid with missing values        *
C*	ANLYG (KXY)	REAL		Grid of analysis values         *
C*	IPOLY (KXY)	INTEGER		Region code numbers             *
C*	KXY		INTEGER		Number of grid points           *
C*      IJSKP           INTEGER         Number of points to skip        *
C*                                                                      *
C* Output parameter:							*
C*	UBAR (NRECS)	REAL		Array of averages returned      *
C*	IRET		INTEGER		Return code			*
C*                                        -22 = pt cnts disagree        *
C*									*
C* Log:									*
C* K. Brill/IMSG        06/16						*
C* K. Brill/IMSG        20170223        Use REAL*8 for accumlations     *
C* K. Brill/IMSG        20170316        Use IJSKP for skipping speed up *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C************************************************************************
	INTEGER		ipoly (*)
        REAL*8          ubar (*)
	REAL		anlyg (*), gmiss (*), wgrd (*)
C*
        REAL            gtmp (LLMXGD), wtmp (LLMXGD)
        REAL*8          wtsum, awsum
C*
        INCLUDE         'ERMISS.FNC'
C*
C------------------------------------------------------------------------
	iret = 0
        inc = ijskp + 1
C*
        IF ( nrgn .eq. 0 ) THEN
            ubar (1) = 0.0
            wtsum = 0.0
            npts = 0
            DO ii = 1, kxy, inc
                IF ( .not. ERMISS (anlyg(ii)) .and.
     +               .not. ERMISS (gmiss(ii)) .and.
     +               .not. ERMISS (wgrd(ii)) ) THEN
                    wtsum = wtsum + wgrd (ii)
                    npts = npts + 1
                    gtmp (npts) = anlyg (ii)
                    wtmp (npts) = wgrd (ii)
                END IF
            END DO
C
C*          Compute the uncertainty term.
C
            IF ( npts .gt. 1 ) THEN
                it1 = 1
                it2 = npts
                DO kk = it1+1, it2
                    DO ll = it1, kk-1
                        ubar (1) = ubar (1) +
     +                             ABS ( gtmp(kk) - gtmp(ll) ) *
     +                             wtmp (kk) * wtmp (ll)
                    END DO
                END DO
                ubar (1) = ubar (1) / (wtsum * wtsum )
            END IF
C
C*          Check for non-trivial indexes:
C
            IF ( it2 .lt. it1 ) THEN
                iret = -22
                RETURN
            END IF
C*
            RETURN
C*
        END IF
C 
C*	Outer loop is over regions:
C
        it1 = 1
        it = 0
        awsum = 0.0
        DO irgn = 1 , nrgn
C
C*          Create subregion array of points.
C
            ubar (irgn) = 0.0
            wtsum = 0.0
            npts = 0
            DO ii = 1, kxy, inc
                IF ( ipoly (ii) .eq. irgn .and.
     +               .not. ERMISS (anlyg(ii)) .and.
     +               .not. ERMISS (wgrd(ii)) .and.
     +               .not. ERMISS (gmiss(ii)) ) THEN
                    npts = npts + 1
                    it = it + 1
                    gtmp (it) = anlyg (ii)
                    wtmp (it) = wgrd (ii)
                    wtsum = wtsum + wgrd (ii)
                    awsum = awsum + wgrd (ii)
                END IF
            END DO
            it2 = it
C
C*          Compute the uncertainty term.
C
            IF ( npts .gt. 1 ) THEN
                DO kk = it1+1, it2
                    DO ll = it1, kk-1
                        ubar (irgn) = ubar (irgn) +
     +                                ABS ( gtmp(kk) - gtmp(ll) ) *
     +                                wtmp (kk) * wtmp (ll)
                    END DO
                END DO
                ubar (irgn) = ubar (irgn) / ( wtsum * wtsum )
            END IF
C
C*          Check for non-trivial indexes:
C
            IF ( it2 .lt. it1 ) THEN
                iret = -22
                RETURN
            END IF
C*
            it1 = it2 + 1
        END DO
C
C*      The array gtmp now contains all points on the domain.
C
        IF ( nrecs .gt. nrgn ) THEN
            irgn = nrgn + 1
            ubar (irgn) = 0.0
            npts = it2
            it1 = 1
            IF ( npts .gt. 1 )  THEN
                DO kk = it1+1, it2
                    DO ll = it1, kk-1
                        ubar (irgn) = ubar (irgn) +
     +                                ABS ( gtmp(kk) - gtmp(ll) ) *
     +                                wtmp (kk) * wtmp (ll)
                    END DO
                END DO
                ubar (irgn) = ubar (irgn) / ( awsum * awsum )
            ELSE
                awsum = 0
            END IF
            IF ( awsum .eq. 0 ) THEN
                iret = -22
                RETURN
            END IF
        END IF
C*
        RETURN
        END
