	SUBROUTINE GDBC2R ( catprobs, MXRNGS, prng, nrng, iret )
C************************************************************************
C* GDBC2R								*
C*									*
C* This subroutine parses the user input for the forecast probability	*
C* intervals.  It returns the probability interval bounding values in	*
C* ascending order, starting from zero and ending with 1.  The user	*
C* input values are either the number of intervals or a list of the	*
C* bounding values for the intervals.					*
C*									*
C* The number of values in PRNG is NRNG and is equal to the number of   *
C* forecast probabililty intervals plus one, including 0 and 1.		*
C*									*
C* CATPROBS is specified in the format p1;p2;p3; . . .; pN, where p1-N  *
C* are the forecast probability values.  If a single value is entered,  *
C* it must exceed 1.							*
C*									*
C* PRNG (1) is always zero, and PRNG (NRNG) is always 1.0.		*
C*									*
C* GDBC2R  ( CATPROBS, MXRNGS, PRNG, NRNG, IRET )			*
C*									*
C* Input parameters:							*
C*	CATPROBS	CHAR*		Forecast probability values	*
C*	MXRNGS		INTEGER		Maximum number of ranges
C*									*
C* Output parameters:							*
C*	PRNG (MXRNGS)	REAL		Order range bounds values	*
C*	NRNG		INTEGER		Number of range bounds values   *
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC      20070202						*
C************************************************************************
C*
	CHARACTER*(*)	catprobs
	REAL		prng (*)
C*
C------------------------------------------------------------------------
	iret = 0
C
C*	Parse the three category probabilities from CATPROBS.
C
	CALL ST_RLST ( catprobs, ';', -1, MXRNGS, prng, num, ier )
	IF ( ier .lt. 0 ) THEN
	    CALL ER_WMSG ( 'ST', ier, ' ', ier )
	    iret = -22
	END IF
C
C*	Check for single integer entry.
C
	IF ( num .eq. 1 ) THEN
	    IF ( prng (1) .le. 1.0 ) THEN
		iret = -24
	        RETURN
	    END IF
	    dp = 1.0 / prng (1)
	    sum = 0.0
	    i = 1
	    prng (1) = 0.0
	    DO WHILE ( sum .lt. 1 )
		sum = sum + dp
		IF ( sum .lt. 1.0 .and.
     +		     ABS ( sum - 1. ) .gt. dp/2. ) THEN
		    i = i + 1
		    IF ( i .ge. MXRNGS ) THEN
			iret = -23
			RETURN
		    END IF
		    prng (i) = sum
		END IF
	    END DO
	    i = i + 1
	    prng (i) = 1.0
	    nrng = i
C*
	    RETURN
C*
	END IF
C
C*	Check for erroneous entries in a list.
C
	DO i = 1, num
	    IF ( prng (i) .lt. 0 .or. prng (i) .gt. 1.0 ) THEN
		iret = -22
		RETURN
	    END IF
	END DO
C
C*	Add 0 and 1.  (Duplicates are eliminated by LV_SORT).
C
	prng (num+1) = 0.0
	num = num + 1
	prng (num+1) = 1.0
	num = num + 1
C
C*	Sort the values in ascending order.
C
	CALL LV_SORT ( 0, num, prng, iret )
	nrng = num
C*
	RETURN
	END
