	SUBROUTINE GDLDDS  ( cprj, angs, phi, kx, ky, gddx, gddy, iret )
C************************************************************************
C* GDLDDS								*
C*									*
C* This subroutine computes GDDX and GDDY for various projections.	*
C*									*
C* Usually PHI = ANGS (1), unless the coordinate system has been	*
C* rotated away from the standard position.				*
C*									*
C* GDLDDS  ( CPRJ, PHI, ANGS, KX, KY, GDDX, GDDY, IRET )		*
C*									*
C* Input parameters:							*
C*	CPRJ		CHAR*		Projection name			*
C*	ANGS		REAL		Angle 1-3 (degrees)		*
C*	PHI		REAL		True LAT (deg) in rotated coord *
C*	KX		INTEGER		Number of grid pts in X		*
C*	KY		INTEGER		Number of grid pts in Y		*
C*									*
C* Output parameters:							*
C* 	GDDX		REAL		X grid increment (KM)		*
C*	GDDY		REAL		Y grid increment (KM)		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-16 = error			*
C**									*
C* Log:									*
C* K. BRILL/HPC		 3/01						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	CHARACTER*(*)	cprj
	REAL		angs (3)
C*
	REAL		qix ( 2 ), qiy ( 2 ), rlt (2), rln (2)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
	gddx = RMISSD
	gddy = RMISSD
C
C*	Compute intermediate coordinate bounds of grid.
C
	qix (1) = 1.
	qiy (1) = 1.
	qix (2) = FLOAT (kx)
	qiy (2) = FLOAT (ky)
	CALL GTRANS ( 'G', 'I', 2, qix, qiy, qix, qiy, ier )
C*
	IF  ( ier .ne. 0 )  THEN
	    iret = -16
	    RETURN
	END IF
	dx = qix (2) - qix (1)
	dy = qiy (2) - qiy (1)
C*
	IF ( cprj .eq. 'CED' ) THEN
C
C*	   Compute average COSINE of latitude over latitude range.
C
	   CALL GTRANS ( 'I', 'M', 2, qix, qiy, rlt, rln, ier )
	   rlt (1) = rlt (1) * DTR
	   rlt (2) = rlt (2) * DTR
	   dphi = rlt (2) - rlt (1)
	   dsin = SIN ( rlt (2) ) - SIN ( rlt (1) )
C
C*	   Compute delta x and delta y for the grid.
C
	   gddx = RADIUS * dx * dsin / dphi
	   gddy = RADIUS * dy
C*
	ELSE IF ( cprj .eq. 'MER' ) THEN
C*
	   gddx = RADIUS * dx * COS ( phi * DTR )
	   gddy = RADIUS * dy * COS ( phi * DTR )
C*
	ELSE IF ( cprj .EQ. 'STR' ) THEN
C*
	   gddx = RADIUS * dx * ( 1. + SIN ( phi * DTR ) )
	   gddy = RADIUS * dy * ( 1. + SIN ( phi * DTR ) )
C*
	ELSE IF ( cprj .EQ. 'LCC' .OR. cprj .EQ. 'SCC' ) THEN
C
C*	    Compute cone constant.
C
	    rphi1 = 90. - ABS ( angs(1) )
	    rphi2 = 90. - ABS ( angs(3) )
	    IF ( rphi1 .eq. rphi2 ) THEN
		phy1 = DTR * rphi1
		concon = cos ( phy1 )
		hph1 = phy1 / 2.
	    ELSE
		phy1 = DTR * rphi1
		phy2 = DTR * rphi2
		hph1 = phy1 / 2.
		hph2 = phy2 / 2.
		concon =
     +		       ( ALOG ( SIN (phy1) ) - ALOG ( SIN (phy2) ) ) /
     +                 ( ALOG ( TAN (hph1) ) - ALOG ( TAN (hph2) ) )
	    END IF
	   rpsi = HALFPI - phi * DTR
	   sint = SIN ( rpsi ) / ( TAN ( rpsi / 2. ) ** concon )
	   gddx = RADIUS * dx * sint / concon
	   gddy = RADIUS * dy * sint / concon
C*
	ELSE
	   iret = -16
	   RETURN
	END IF
C
C*	The grid increments could be negative depending on grid layout.
C*	Convert to KM.
C
	gddx = ABS ( gddx ) / ( 1000. * FLOAT ( kx - 1 ) )
	gddy = ABS ( gddy ) / ( 1000. * FLOAT ( ky - 1 ) )
C*
	RETURN
	END
