	SUBROUTINE GDSNRM ( agrd, fgrd, kxy, inout, nlun, luns, chedr,
     +			    iret )
C************************************************************************
C* GDSNRM								*
C*									*
C* This subroutine computes scalar L1L2 values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an arrya of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* GDSNRM ( AGRD, FGRD, KXY, INOUT, NLUN, LUNS, CHEDR, IRET )		*
C*									*
C* Input parameters:							*
C*	AGRD (KXY) 	REAL		Analysis grid values		*
C*	FGRD (KXY) 	REAL		Forecast grid values		*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	CHEDR		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 4/01						*
C* K. Brill/HPC		06/07	Changes for ML1L2 instead of SL1L2	*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		agrd (*), fgrd (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	chedr
	
C*
	DOUBLE PRECISION	f, o, fo, ff, oo, rn, ae
	CHARACTER		cl1l2*(MXC)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	n = 0
	f = 0.
	o = 0.
	fo = 0.
	ff = 0.
	oo = 0.
	ae = 0.
	DO i = 1, kxy
	    IF ( .not. ERMISS ( agrd (i) ) .and.
     +		 .not. ERMISS ( fgrd (i) ) .and.
     +		 inout (i) .eq. 1 ) THEN
		n = n + 1
		f = f + fgrd (i)
		o = o + agrd (i)
		fo = fo + fgrd (i) * agrd (i)
		ff = ff + fgrd (i) * fgrd (i)
		oo = oo + agrd (i) * agrd (i)
		ae = ae + ABS ( fgrd (i) - agrd (i) )
	    END IF
	END DO
C*
	CALL ST_LCUC ( chedr, chedr, ier )
	iml = INDEX ( chedr, 'ML1L2' )
	CALL ST_LSTR ( chedr, lnch, ier )
	IF ( n .gt. 0 .and. iml .eq. 0 ) THEN
	    rn = DFLOAT (n)
	    rf = f / rn
	    ro = o / rn
	    rfo = fo / rn
	    rff = ff / rn
	    roo = oo / rn
	    WRITE (cl1l2,1000) n, rf, ro, rfo, rff, roo
1000	    FORMAT ( I8, 5(1X,1PE12.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
	    END DO
	ELSE IF ( n .gt. 0 ) THEN
	    rn = DFLOAT (n)
	    rf = f / rn
	    ro = o / rn
	    rfo = fo / rn
	    rff = ff / rn
	    roo = oo / rn
	    rae = ae / rn
	    WRITE (cl1l2,1001) n, rf, ro, rfo, rff, roo, rae
1001	    FORMAT ( I8, 6(1X,1PE12.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
	    END DO
	ELSE
	    WRITE (6,*) chedr(1:lnch), ' --------:'
	    WRITE (6,*) ' All points missing or not in region.'
	END IF
C*
	RETURN
	END
