	SUBROUTINE GDVNRM ( agrd, fgrd, avgrd, fvgrd, kxy, inout,
     +			    nlun, luns, chedr, iret )
C************************************************************************
C* GDVNRM								*
C*									*
C* This subroutine computes vector L1L2 values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an arrya of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* GDVNRM ( AGRD, FGRD, AVGRD, FVGRD, KXY, INOUT, NLUN, LUNS, CHEDR,	*
C* 	    IRET )							*
C*									*
C* Input parameters:							*
C*	AGRD (KXY) 	REAL		Analysis U grid values		*
C*	FGRD (KXY) 	REAL		Forecast U grid values		*
C*	AVGRD (KXY) 	REAL		Analysis V grid values		*
C*	FVGRD (KXY) 	REAL		Forecast V grid values		*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and ouput parameter:						*
C*	CHEDR		CHAR*		VSDB header record		*
C*					Returned in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 4/01						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		agrd (*), fgrd (*), avgrd (*), fvgrd (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	chedr
	
C*
	DOUBLE PRECISION	uf, vf, uo, vo, fdoto, ff, oo, rn
	CHARACTER		cl1l2*(MXC)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	n = 0
	uf = 0.
	vf = 0.
	uo = 0.
	vo = 0.
	fdoto = 0.
	ff = 0.
	oo = 0.
	DO i = 1, kxy
	    IF ( .not. ERMISS ( agrd (i) ) .and.
     +		 .not. ERMISS ( fgrd (i) ) .and.
     +		 .not. ERMISS ( avgrd (i) ) .and.
     +		 .not. ERMISS ( fvgrd (i) ) .and.
     +		 inout (i) .eq. 1 ) THEN
		n = n + 1
		uf = uf + fgrd (i)
		vf = vf + fvgrd (i)
		uo = uo + agrd (i)
		vo = vo + avgrd (i)
		fdoto = fdoto + fgrd (i) * agrd (i)
		fdoto = fdoto + fvgrd (i) * avgrd (i)
		ff = ff + fgrd (i) * fgrd (i)
		ff = ff + fvgrd (i) * fvgrd (i)
		oo = oo + agrd (i) * agrd (i)
		oo = oo + avgrd (i) * avgrd (i)
	    END IF
	END DO
C*
	CALL ST_LCUC ( chedr, chedr, ier )
	CALL ST_LSTR ( chedr, lnch, ier )
	IF ( n .gt. 0 ) THEN
	    rn = DFLOAT (n)
	    ruf = uf / rn
	    rvf = vf / rn
	    ruo = uo / rn
	    rvo = vo / rn
	    rfo = fdoto / rn
	    rff = ff / rn
	    roo = oo / rn
	    WRITE (cl1l2,1000) n, ruf, rvf, ruo, rvo,
     +			rfo, rff, roo
1000	    FORMAT ( I8, 7(1X,1PE12.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
	    END DO
	ELSE
	    WRITE (6,*) chedr(1:lnch), ' --------:'
	    WRITE (6,*) ' All points missing or not in region.'
	END IF
C*
	RETURN
	END
