	SUBROUTINE GDLANO ( vector, gdmnsd, level, ivcord, onav,
     +			    agrd, fgrd, avgrd, fvgrd, tmpg, stdz, iret )
C************************************************************************
C* GDLANO								*
C*									*
C* This subroutine opens a grid file containing MEAN and STDD fields	*
C* and uses them to convert AGRD and FGRD to deviations	from the mean	*
C* or standardized deviations.						*
C*									*
C* The grid file name is assumed to be of the form:			*
C*									*
C*                  /.../.../parm_YYYY-YYYY.MMDD_stats			*
C* or									*
C*									*
C		 /.../.../parm_level_vcord_YYYY-YYYY.MMDD_stats		*
C*									*
C* where parm is the parameter name, level is the vertical coordinate	*
C* level, vcord is the vertical coordinate name, YYYY-YYYY is the	*
C* year range of the climatology, and MMDD is the month and day.  The	*
C* date time for the grid is taken to be:				*
C*									*
C*                 YYMMDD/0000F000					*
C*									*
C* where YY comes from the end of the year range in the file name.	*
C*									*
C* For vectors, the parameters are U_MEAN, V_MEAN, U_STDD, and V_STDD.	*
C*									*
C* If no standard deviations can be read from GDMNSD, then non-		*
C* standardized anomalies (simple deviations from the mean) are		*
C* returned.								*
C*									*
C* GDLANO  ( VECTOR, GDMNSD, GDATIM, LEVEL, IVCORD, ONAV, AGRD, FGRD,	*
C*	     AVGRD, FVGRD, TMPG, STDZ, IRET )				*
C*									*
C* Input parameters:							*
C*	VECTOR		LOGICAL		.true. for vector verification	*
C*	GDMNSD		CHAR*		Name of GRID file containing	*
C*					MEAN & STDD grids		*
C*	LEVEL (2)	INTEGER		Grid Level			*
C*	IVCORD		INTEGER		Grid vertical coordinate	*
C*	ONAV (*)	REAL		Output grid navigation block	*
C*									*
C* Input and output parameters:						*
C*	AGRD (*)	REAL		Analysis grid or u component	*
C*	FGRD (*)	REAL		Forecast grid or u component	*
C*	AVGRD (*)	REAL		Analysis v component		*
C*	FVGRD (*)	REAL		Forecast v component		*
C*	TMPG (*)	REAL		Working grid for scratch	*
C*									*
C* Output parameters:							*
C*	STDZ		LOGICAL		.true. for standardized anomaly *
C*	IRET		INTEGER		Return code			*
C*					 +1 = blank file name		*
C*					  0 = normal return		*
C*					 -1 = error			*
C**									*
C* Log:									*
C* K. BRILL/HPC		 4/01						*
C* K. Brill/HPC	  	 5/05	Make ighdr big				*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	CHARACTER*(*)	gdmnsd
	REAL		agrd (*), fgrd (*), tmpg (*), onav (*)
	REAL		avgrd (*), fvgrd (*)
	INTEGER		level (2)
	LOGICAL		vector, stdz
C*
	REAL		cnav (LLNNAV), anlblk (LLNANL)
	REAL		tmpg2 (LLMXGD)
        CHARACTER       parm*12
	CHARACTER*20	gdatim (2)
	INTEGER		ighdr (256)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
	stdz = .false.
C*
	IF ( gdmnsd .eq. ' ' ) THEN
	    iret = +1
	    RETURN
	END IF
	kx = NINT ( onav (5) )
	ky = NINT ( onav (6) )
	kxky = kx * ky
C
C*	Open the grid file and get the grid and its navigation.
C
	CALL GD_OFIL  ( gdmnsd, .false., .false., igdfln, navsz,
     +			cnav, ianlsz, anlblk, ihsz, maxgd, iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'GD', iret, ' ', ier )
	    iret = -1
	    RETURN
	END IF
C
C*	Derive the date/time from the grid file name.
C
	CALL ST_LSTR ( gdmnsd, lns, ier )
	IF ( gdmnsd (lns-10:lns-10) .ne. '.' ) THEN
	    iret = -16
	    CALL ER_WMSG ( 'GDL1L2', iret, ' ', ier )
	    CALL GD_CLOS ( igdfln, ier )
	    RETURN
	END IF
	gdatim (1) = gdmnsd (lns-12:lns-11) // gdmnsd (lns-9:lns-6) //
     +		     '/0000F000'
	gdatim (2) = ' '
C
C*	Read the mean (MEAN).
C
	IF ( vector ) THEN
	    parm = 'U_MEAN'
	ELSE
	    parm = 'MEAN'
	END IF
	CALL GD_RDAT ( igdfln, gdatim, level, ivcord, parm, tmpg2,
     +		       igx, igy, ighdr, iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'GD', iret, ' ', ier )
	    iret = -1
	    CALL GD_CLOS ( igdfln, ier )
	    RETURN
	END IF
C
C*	Interpolate MEAN to comparison grid.
C
	CALL GDLINT ( 0, cnav, onav, tmpg2, tmpg, ier )
C
C*	Compute anomalies:
C
	DO i = 1, kxky
	    IF ( .not. ERMISS ( agrd (i) ) .and.
     +		 .not. ERMISS ( tmpg (i) ) ) THEN
		agrd (i) = agrd (i) - tmpg (i)
	    ELSE
		agrd (i) = RMISSD
	    END IF
	    IF ( .not. ERMISS ( fgrd (i) ) .and.
     +		 .not. ERMISS ( tmpg (i) ) ) THEN
		fgrd (i) = fgrd (i) - tmpg (i)
	    ELSE
		fgrd (i) = RMISSD
	    END IF
	END DO
	IF ( vector ) THEN
	    parm = 'V_MEAN'
	    CALL GD_RDAT ( igdfln, gdatim, level, ivcord, parm, tmpg2,
     +		       	   igx, igy, ighdr, iret )
	    IF  ( iret .ne. 0 )  THEN
		CALL ER_WMSG ( 'GD', iret, ' ', ier )
		iret = -1
		CALL GD_CLOS ( igdfln, ier )
		RETURN
	    END IF
C
C*	    Interpolate V MEAN to comparison grid.
C
	    CALL GDLINT ( 0, cnav, onav, tmpg2, tmpg, ier )
C
C*	    Compute anomalies:
C
	    DO i = 1, kxky
		IF ( .not. ERMISS ( avgrd (i) ) .and.
     +		     .not. ERMISS ( tmpg (i) ) ) THEN
		    avgrd (i) = avgrd (i) - tmpg (i)
		ELSE
		    avgrd (i) = RMISSD
		END IF
		IF ( .not. ERMISS ( fvgrd (i) ) .and.
     +		     .not. ERMISS ( tmpg (i) ) ) THEN
		    fvgrd (i) = fvgrd (i) - tmpg (i)
		ELSE
		    fvgrd (i) = RMISSD
		END IF
	    END DO
	END IF
C
C*	Read the standard deviation (STDD).
C
	IF ( vector ) THEN
	    parm = 'U_STDD'
	ELSE
	    parm = 'STDD'
	END IF
	CALL GD_RDAT ( igdfln, gdatim, level, ivcord, parm, tmpg2,
     +		       igx, igy, ighdr, iret )
	IF  ( iret .ne. 0 )  THEN
	    iret = 0
	    CALL ER_WMSG ( 'GDL1L2', +1, ' ', ier )
	    CALL GD_CLOS ( igdfln, ier )
	    RETURN
	ELSE
	    stdz = .true.
	END IF
C
C*	Interpolate STDD to comparison grid.
C
	CALL GDLINT ( 0, cnav, onav, tmpg2, tmpg, ier )
C
C*	Normalize the anomalies:
C
	DO i = 1, kxky
	    IF ( .not. ERMISS ( agrd (i) ) .and.
     +		 .not. ERMISS ( tmpg (i) ) .and. tmpg (i) .ne. 0. ) THEN
		agrd (i) = agrd (i) / tmpg (i)
	    ELSE
		agrd (i) = RMISSD
	    END IF
	    IF ( .not. ERMISS ( fgrd (i) ) .and.
     +		 .not. ERMISS ( tmpg (i) ) .and. tmpg (i) .ne. 0. ) THEN
		fgrd (i) = fgrd (i) / tmpg (i)
	    ELSE
		fgrd (i) = RMISSD
	    END IF
	END DO
	IF ( vector ) THEN
	    parm = 'V_STDD'
	    CALL GD_RDAT ( igdfln, gdatim, level, ivcord, parm, tmpg2,
     +		           igx, igy, ighdr, iret )
	    IF  ( iret .ne. 0 )  THEN
		CALL ER_WMSG ( 'GD', iret, ' ', ier )
		iret = -1
		CALL GD_CLOS ( igdfln, ier )
		RETURN
	    END IF
C
C*	    Interpolate V STDD to comparison grid.
C
	    CALL GDLINT ( 0, cnav, onav, tmpg2, tmpg, ier )
C
C*	    Normalize the anomalies:
C
	    DO i = 1, kxky
		IF ( .not. ERMISS ( avgrd (i) ) .and.
     +		     .not. ERMISS ( tmpg (i) ) .and. tmpg (i) .ne. 0. )
     +		THEN
		    avgrd (i) = avgrd (i) / tmpg (i)
		ELSE
		    avgrd (i) = RMISSD
		END IF
		IF ( .not. ERMISS ( fvgrd (i) ) .and.
     +		     .not. ERMISS ( tmpg (i) ) .and. tmpg (i) .ne. 0. )
     +		THEN
		    fvgrd (i) = fvgrd (i) / tmpg (i)
		ELSE
		    fvgrd (i) = RMISSD
		END IF
	    END DO
	END IF
C*
	CALL GD_CLOS ( igdfln, ier )
C*
	RETURN
	END
