	SUBROUTINE GDBC2G ( catprobs, frctg, mx, my, fgrd, iret )
C************************************************************************
C* GDBC2G								*
C*									*
C* This subroutine uses the three probability values in CATPROBS and	*
C* forecast probabilities in FRCTG to assign forecast probability	*
C* category numbers to the output grid, FGRD.  These numbers are 0 for	*
C* no risk, 1 for low, 2 for moderate, and 3 for high risk.		*
C*									*
C* CATPROBS is specified in the format p1;p2;p3, where, p1-3 describe	*
C* the probability categories as follows:				*
C*									*
C*           RISK CATEGORY              Probability (P) range		*
C*              No Risk                         P < p1			*
C*	       Low Risk                      p1 <= P < p2		*
C*	     Moderate Risk		     p2 <= P < p3		*
C*	       High Risk                       P >= p3			*
C*									*
C* GDBC2G  ( CATPROBS, FRCTG, MX, MY, FGRD, IRET )			*
C*									*
C* Input parameters:							*
C*	CATPROBS	CHAR*		Probability of risk categories	*
C*	FRCTG (MX,MY)   REAL		Forecast probability grid	*
C*	MX		INTEGER		Grid X dimension		*
C*	MY		INTEGER		Grid Y dimension		*
C*									*
C* Output parameters:							*
C*	FGRD (MX,MY)	REAL		Forecast risk category grid	*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC          6/05						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	CHARACTER*(*)	catprobs
	REAL		fgrd (*), frctg (*)
C*
	REAL		pcat (3)
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C
C*	Parse the three category probabilities from CATPROBS.
C
	CALL ST_RLST ( catprobs, ';', 0, 3, pcat, num, ier )
	IF ( num .ne. 3 .or. ier .ne. 0 ) THEN
	    iret = -22
	    RETURN
	END IF
C
C*	Set the ouput forecast grid to missing.
C*	The output relative grid box area size is set to 1.0.
C*	It can be scaled at a later date if needed.
C
	kxy = 0
	DO j = 1, my
	    DO i = 1, mx
		kxy = kxy + 1
		IF ( .not. ERMISS ( frctg (kxy) ) ) THEN
		    IF (  frctg (kxy) .lt. pcat (1) ) THEN
			fgrd (kxy) = 0.0
		    ELSE IF ( frctg (kxy) .ge. pcat (1) .and.
     +			      frctg (kxy) .lt. pcat (2) ) THEN
			fgrd (kxy) = 1.0
		    ELSE IF ( frctg (kxy) .ge. pcat (2) .and.
     +			      frctg (kxy) .lt. pcat (3) ) THEN
			fgrd (kxy) = 2.0
		    ELSE
			fgrd (kxy) = 3.0
		    END IF
		ELSE
		    fgrd (kxy) = RMISSD
		END IF
	    END DO
	END DO
C*
	RETURN
	END
