	SUBROUTINE PFRNRM ( sttyp, thlds, cthld, nth, agrd, fgrd, sgrd,
     +			    kxy, inout, nlun, luns, chedr, iret )
C************************************************************************
C* PFRNRM								*
C*									*
C* This subroutine computes PFR record values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* PFRNRM ( STTYP, THLDS, CTHLD, NTH, AGRD, FGRD, SGRD, KXY, INOUT,	*
C* 	    NLUN, LUNS, CHEDR, IRET )					*
C*									*
C* Input parameters:							*
C*	STTYP		CHAR*		Statistic type without list	*
C*	THLDS (NTH)	REAL		Threshold value list		*
C*	CTHLD (NTH)	CHAR*		Threshold strings		*
C*	NTH		INTEGER		Number of thresholds in list	*
C*	AGRD (KXY) 	REAL		Analysis grid values		*
C*	FGRD (KXY) 	REAL		Forecast grid values		*
C*	SGRD (KXY)	REAL		Normalized box area grid	*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	CHEDR		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-26 = invalid threshold		*
C**									*
C* Log:									*
C* K. Brill/HPC		 8/10						*
C* K. Brill/HPC          8/10	Allow only one threshold record if	*
C*				no obs exceed the threshold		*
C* K. Brill/HPC      20100930   Add data record values for evaluating   *
C*				P(F>O|F>T).				*
C* K. Brill/HPC      20101001   Add data values for evaluating		*
C*				P(F>O|F>T&O>T).				*
C* K. Brill/IMSG     20150505   Always write out trivial (0.0) records  *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		agrd (*), fgrd (*), sgrd (*), thlds (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	cthld (*), sttyp, chedr
	
C*
	LOGICAL		ok, both
	CHARACTER	cl1l2*(MXC)
	CHARACTER*32	csave
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL ST_LCUC ( chedr, chedr, ier )
	CALL ST_LSTR ( chedr, lnch, ier )
C
C*	Find end of statistic type field in header and
C*	save the trailing part in order to insert the
C*	threshold.
C
	ist = INDEX ( chedr, 'PFR' )
	iq = INDEX ( chedr (ist: ), ' ' )
	iadr = ist + iq
	csave = chedr (iadr:lnch)
	CALL ST_LSTR ( csave, lnsv, ier )
	iadr = iadr - 2
C
C*	Loop over each threshold.
C
	DO ith = 1, nth
	    IF ( ERMISS (thlds(ith)) ) THEN
		iret = -26
		CALL ER_WMSG ( 'GDPFR', iret, ' ', ier )
		RETURN
	    ELSE
		CALL ST_LSTR ( cthld (ith), lnr, ier )
		chedr = chedr (1:iadr) // cthld(ith) (1:lnr) // ' ' //
     +			csave (1:lnsv)
		CALL ST_LSTR ( chedr, lnch, ier )
	    END IF
	    rn = 0
	    rfgo = 0
	    rand = 0
	    rogt = 0
	    rfand = 0
	    rfgt = 0
	    rand3 = 0
	    rboth = 0
	    DO i = 1, kxy
		IF ( .not. ERMISS ( agrd (i) ) .and.
     +		     .not. ERMISS ( fgrd (i) ) .and.
     +		     inout (i) .eq. 1 ) THEN
		    rn = rn + sgrd (i)
		    ok = .false.
		    both = .true.
		    IF ( sttyp .eq. 'PFR>' ) THEN
			IF ( fgrd (i) .gt. agrd (i) ) THEN
			    rfgo = rfgo + sgrd (i)
			    ok = .true.
			END IF
			IF ( agrd (i) .ge. thlds (ith) ) THEN
			    rogt = rogt + sgrd (i)
			    IF ( ok ) rand = rand + sgrd (i)
			ELSE
			    both = .false.
			END IF
			IF ( fgrd (i) .ge. thlds (ith) ) THEN
			    rfgt = rfgt + sgrd (i)
			    IF ( ok ) rfand = rfand + sgrd (i)
			ELSE
			    both = .false.
			END IF
			IF ( both ) THEN
			    rboth = rboth + sgrd (i)
			    IF ( ok ) rand3 = rand3 + sgrd (i)
			END IF
		    ELSE
			iret = -27
			CALL ER_WMSG ( 'GDPFR', iret, ' ', ier )
			RETURN
		    END IF
		END IF
	    END DO
C
C*	    DO NOT Allow only one threshold to be written if P(O>=T) == 0.0.
C
C-------	    IF ( rogt .le. 0.0 .and. ith .gt. 1 ) RETURN
C*
	    IF ( rn .gt. 0 ) THEN
		f = rfgo / rn
		h = rand / rn
		o = rogt / rn
		hh = rfand / rn
		ff = rfgt / rn
		hhh = rand3 / rn
		fff = rboth / rn
		WRITE (cl1l2,1000) rn, f, h, o, hh, ff, hhh, fff
1000		FORMAT ( F10.2, 7(1X,1PE12.5) )
		CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
		DO i = 1, nlun
		    WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
		END DO
	    ELSE
		WRITE (6,*) chedr(1:lnch), ' --------:'
		WRITE (6,*)
     +		' All points zero, missing, or not in region.'
	    END IF
	END DO
C*
	RETURN
	END
