	SUBROUTINE RDTD_D2P ( ityp, mxt, mxd, npts, ndpth, itrc,
     +			      dtrace, rmiss, mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, iret )
C************************************************************************
C* RDTD_D2P								*
C*									*
C* This subroutine converts the values constituting the depth of a 	*
C* PBS trace to a new trace composed of the probabilities required for  *
C* an attributes diagram.  The first half of the trace returned is the  *
C* frequency of use.  The second half is composed of values for the	*
C* frequency of both event observed and forecast.			*
C*									*
C* This subroutine is also used to compress a CRPS time series for      *
C* quantile reliability depictions.                                     *
C*									*
C* For PBS, the first value (corresponding to the data count) is        *
C* replaced by 1 - SUM, where SUM is the sum of the fractions from 2    *
C* to ndpth/2.  For CRPS, the first value is 1.                         *
C*									*
C* RDTD_D2T ( ITYP, MXT, MXD, NPTS, NDPTH, ITRC, DTRACE, RMISS, MPTS,   *
C*	      XPTS, TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL, RLBL,     *
C*	      CLTYP, IPTYP, IRET )					*
C*									*
C* Input parameters:							*
C*      ITYP            INTEGER         Statistic type identifier:      *
C*                                         1 = PBS                      *
C*                                         2 = CRPS                     *
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	NDPTH           INTEGER		Number of values per point	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C* Output parameters:							*
C*	MPTS		INTEGER		Number of output trace points	*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 4 -> to force binned output	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/05						*
C* K. Brill/HPC      20070119	Documentation				*
C* K. Brill/IMSG     20160712   Changes for CRPS stat type              * 
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), cltyp
C*
	REAL*8		sn
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	nov2 = ndpth / 2
	IF ( nov2 * 2 .ne. ndpth ) THEN
	    iret = -59
	    RETURN
	END IF
	iptyp = 24
	xmin = 1.
	xmax = FLOAT ( ndpth )
	trcmin = 1.E29
	trcmax = -1.E29
	cltyp = 'r'
C
C*	Initialize trace elements to 0.0.
C
	DO id = 1, ndpth
	    trcdat (id) = 0.0
	END DO
C
C*	Initialize total data count to 0.0.
C
	sn = 0.0
C
C*	Combine all of the trace points.
C
	DO ip = 1, npts
C
C*	    Check that all trace data is not missing.
C
	    ok = .true.
	    id = 0
	    DO WHILE ( ok .and. id .lt. ndpth )
		id = id + 1
		ok = ( dtrace (itrc,id,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
C
C*	        Generate trace from data fields.
C
		sn = sn + dtrace (itrc,1,ip)
		DO id = 2, ndpth
		    trcdat (id) = trcdat (id) + dtrace (itrc,id,ip)
		END DO
	    END IF
	END DO
C
C*	Compute the mean for each value in the data field.
C
	IF ( sn .le. 0 )  THEN
	    DO id = 1, ndpth
		trcdat (id) = rmiss
	    END DO
	    mpts = 0
	    RETURN
	END IF
	sum = 0.0
	DO id = 2, ndpth
	    trcdat (id) = trcdat (id) / sn
	    IF ( id .le. nov2 ) THEN
	        sum = sum + trcdat (id)
	    END IF
	    IF ( trcdat (id) .lt. trcmin ) trcmin = trcdat (id)
	    IF ( trcdat (id) .gt. trcmax ) trcmax = trcdat (id)
	    xpts (id) = FLOAT (id)
	    clbl (id) = ' '
	    rlbl (id) = xpts (id)
	END DO
	trcdat (1) = 1.0 - sum
	IF ( trcdat (1) .lt. 0 ) trcdat (1) = 0.0
	IF ( trcdat (1) .gt. 1.0 ) trcdat (1) = 1.0
        IF ( ityp .eq. 2 ) trcdat (1) = 1.0
	IF ( trcdat (1) .lt. trcmin ) trcmin = trcdat (1)
	IF ( trcdat (1) .gt. trcmax ) trcmax = trcdat (1)
	mpts = ndpth
C*
	RETURN
	END
