	SUBROUTINE RDTD_HDM ( fx, hx, ox, ha, iret )
C************************************************************************
C* This subroutine computes the adjust value of hits, assuming that the *
C* ratio of incremental change in hits to change in false alarms is	*
C* proportional to un-hit area.						*
C*									*
C* The variables hx and ha may be the same variable.			*
C*									*
C*  dH/dA = b(O-H)							*
C*									*
C*  RDTD_HDM ( FX, HX, OX, HA, IRET )					*
C*									*
C* Input Parameters:							*
C*	FX		REAL*8		Forecast area or count		*
C*	HX		REAL*8		Hit area or count		*
C*	OX		REAL*8		Observed area or count		*
C*									*
C* Output Parameters:							*
C*	HA		REAL*8		Adjusted value of hits		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*									*
C* Log:									*
C* F. Mesinger/EMC   20070215	Supplied code				*
C* K. Brill/HPC      20070215	Created documented subroutine.		*
C* K. Brill/IMSG     20170724   Documentation edits                     *
C************************************************************************
	REAL*8 fx, hx, ox, ha
C*
        REAL O, Fb, Hb
        REAL F
C------------------------------------------------------------------------
	iret = 0
C
C*	Take care of special cases:
C
	IF ( fx .eq. hx .and. hx .ne. 0.0 ) THEN
	    ha = ox
	    RETURN
	ELSE IF ( hx .eq. ox ) THEN
	    ha = ox
	    RETURN
	ELSE IF ( hx .eq. 0.0 ) THEN
	    ha = 0.0
	    RETURN
	END IF
C
C*  Calculates H based on the assumption dH/dA=b(O-H)
C*  H stands for Hits, A for False Alarms ("Misses"), O for Observed,
C*  and Fb, Hb are the observed values of Forecast and Hit points, or
C*  areas, respectively
C
	O = ox
	Fb = fx
	Hb = hx
C
C* In order to calulate H for bias=1, use   	  
C
	F = O
C*
	X = O * log(O/(O-Hb)) / (Fb-Hb) *  (O/(O-Hb))**((O-F)/(Fb-Hb))
C*
	ha = O - (Fb-Hb)/log(O/(O-Hb)) * WEW_B(X,EN)
C*
	RETURN
	END
C========================================================================
C
C*	The following function inverts w*exp(w).
C
      REAL FUNCTION WEW_B ( X, EN )
	  
C  Code taken from http://www.netlib.org/toms/443
C
C  ITERATIVE SOLUTION OF X = W * EXP ( W ) WHERE X IS GIVEN.
C  (NOVEMBER 1970)
C  (REVISED - SEPTEMBER 1971)
C  VERSION B -- MAXIMUM RELATIVE ERROR 3.E-7.
C
C  INPUT PARAMETER:
C    X  ARGUMENT OF W(X)
C
C  OUTPUT PARAMETERS:
C    WEW  THE DESIRED SOLUTION.
C    EN   THE LAST RELATIVE CORRECTION TO W(X).
C
C  SET CONSTANTS...
C     .. Scalar Arguments ..
      REAL EN,X,F
C     ..
      REAL FLOGX,TEMP,WN,Y,ZN
C     ..
C     .. Intrinsic Functions ..
      INTRINSIC LOG
C     ..
C  COMPUTE INITIAL GUESS...
      FLOGX = LOG ( X )
      IF ( X - .7385 ) 30, 30, 40
30    WN = X*(3.0 + 4.0*X)/(3.0 + X*(7.0 + 2.5*X))
      GO TO 50
40    WN = FLOGX - 24. * ((FLOGX+2.) * FLOGX-3.) /
     +     (( .7 * FLOGX + 58. ) * FLOGX + 127. )
50    CONTINUE
C
C  ITERATION ONE...
      ZN = FLOGX - WN - LOG ( WN )
      TEMP = 1. + WN
      Y = 2. * TEMP * ( TEMP + ZN/1.5 ) - ZN
      EN = ZN * Y / ( TEMP * ( Y - ZN ) )
      WN = WN * ( 1. + EN )
C
C  RETURN...
      WEW_B = WN
      RETURN
      END
