	SUBROUTINE RDTD_LAG ( lag, itrc, iret )
C************************************************************************
C* RDTD_LAG								*
C*									*
C* This subroutine performs intra-trace data combination.		*
C*									*
C* If LAG is different from that previously applied to this trace,	*
C* the trace data is re-initialized.					*
C*									*
C* Each point on a trace is combined with the LAG - 1 preceding points.	*
C*									*
C* RDTD_LAG ( LAG, ITRC, IRET )						*
C*									*
C* Input parameters:							*
C*	LAG		INTEGER		Number of points to combine	*
C*	ITRC		INTEGER		Trace number			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/99						*
C* K. Brill/HPC		 7/03	Move re-initialization to RDTD_TRC	*
C* K. Brill/HPC      20081105	Allow lag to reset for lag < 0		*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
C*------------------------------------------------------------------------
	iret = 0
C*
	IF ( lag .eq. 0 ) RETURN
C*
	np = ntrpts ( itrc )
	nd = ndepth ( itrc )
	IF ( lag .gt. 0 ) THEN
	    DO ip = np, 2, -1
	        istrt = ip - lag + 1
	        istop = ip - 1
	        IF ( istrt .lt. 1 ) istrt = 1
	        DO i = istrt, istop, 1
		    DO j = 1, nd
		        d0 = dtrace (itrc,j,ip)
		        dadd = dtrace (itrc,j,i)
		        IF ( d0 .gt. -1.E30 .and. dadd .gt. -1.E30 ) THEN
		    	    dtrace (itrc,j,ip) = dtrace (itrc,j,ip) +
     +						dtrace (itrc,j,i)
		        END IF
		    END DO
	        END DO
	    END DO
	ELSE
	    llg = IABS ( lag )
	    DO j = 1, nd
	    	d0 = dtrace (itrc,j,1)
	    	DO ip = 2, np
		    IF ( MOD ( ip, llg ) .eq. 1 ) THEN
			d0 = dtrace (itrc,j,ip)
C
C*			Here the trace point does not change.  This is
C*                      the reset point.
C
		    ELSE
			d0 = d0 + dtrace (itrc,j,ip)
			dtrace (itrc,j,ip) = d0
		    END IF
		END DO
	    END DO
	END IF
	reinit = .true.
C*
	RETURN
	END
