	SUBROUTINE RDTD_LOD ( luntd, itype, nt, idpth, npts, crlbl,
     +			      cmprs, lrcnm, iret )
C************************************************************************
C* RDTD_LOD								*
C*									*
C* This subroutine reads and loads the data for a trace.		*
C*									*
C* LUNTD is the unit number to which the trace data file is connected.	*
C*									*
C* CRLBL gives the type of the trace point label data.  It is input as	*
C* c for character or r for real.  In the data structure, LBLTYP is set	*
C* to one of the following:  c = character, r = real, t = time (in	*
C* minutes).								*
C*									*
C*									*
C* RDTD_LOD ( LUNTD, ITYPE, NT, IDPTH, NPTS, CRLBL, CMPRS, LRCNM, IRET )*
C*									*
C* Input parameters:							*
C*	LUNTD		INTEGER		Unit number of trace data file	*
C*	ITYPE		INTEGER		Type of plot			*
C*					  1 = time series		*
C*					  2 = scatter plot		*
C*					  3 = skill score vs thresholds	*
C*					  4 = binned categories		*
C*	NT		INTEGER		Trace index number		*
C*	IDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		# of points in trace		*
C*	CRLBL		CHAR*1		Trace label type		*
C*					  c = character			*
C*					  r = real			*
C*	CMPRS		CHAR*1		Trace data compression flag	*
C*					  F = no compression		*
C*					  T = compression		*
C*	LRCNM		LOGICAL		Flag for record count number	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-17 = premature end of file	*
C*					-22 = label types differ	*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/HPC		 8/00	Declare CHRIN & TRCOUT using MXDPTH	*
C* K. Brill/HPC		12/01	Change to read # of contrib records	*
C* K. Brill/HPC		11/03	Detect and flag traces with all pt msng *
C* K. Brill/HPC		10/06	Increase # of data fields to 25;	*
C*				Warn (+6) and reset lbl type if changed *
C* K. Brill/IMSG	06/17	Increase # of data fields to 29 	*
C************************************************************************
	INCLUDE		'rdtd.cmn'
	CHARACTER*1	crlbl, cmprs
	LOGICAL		lrcnm
C*
	CHARACTER*7	chrin (MXDPTH+1)
	CHARACTER*24	clbl
	CHARACTER*1	lblold
	REAL*8		trcout (MXDPTH+1)
	LOGICAL		cmpres
C*------------------------------------------------------------------------
	iret = 0
	lblold = lbltyp
	IF ( cmprs .eq. 'T' .or. cmprs .eq. 't' ) THEN
	    cmpres = .true.
	ELSE
	    cmpres = .false.
	END IF
	ios = 0
	nrec = 0
	icntm = 0
	DO i = 1, npts
	    IF ( cmpres .and. .not. lrcnm ) THEN
		IF ( crlbl .eq. 'r' ) THEN
		    READ (luntd, '(E24.7,29(X,A7))', IOSTAT=ios )
     +				rlbl,
     +				( chrin (iq), iq = 1, idpth )
		ELSE
		    READ (luntd, '(A24,29(X,A7))', IOSTAT=ios )
     +				clbl,
     +				( chrin (iq), iq = 1, idpth )
		END IF
		IF ( ios .ne. 0 ) THEN
		    iret = -17
		    RETURN
		END IF
		CALL USR_DECD ( chrin, idpth, trcout, ier )
	    ELSE IF ( .not. lrcnm ) THEN
		IF ( crlbl .eq. 'r' ) THEN
		    READ (luntd, '(E24.7,29(D20.12))', IOSTAT=ios )
     +				rlbl,
     +				( trcout (iq), iq = 1, idpth )
		ELSE
		    READ (luntd, '(A24,29(D20.12))', IOSTAT=ios )
     +				clbl,
     +				( trcout (iq), iq = 1, idpth )
		END IF
		IF ( ios .ne. 0 ) THEN
		    iret = -17
		    RETURN
		END IF
	    ELSE IF ( cmpres ) THEN
		IF ( crlbl .eq. 'r' ) THEN
		    READ (luntd, '(E24.7,29(X,A7))', IOSTAT=ios )
     +				rlbl,
     +				( chrin (iq), iq = 1, idpth+1 )
		ELSE
		    READ (luntd, '(A24,29(X,A7))', IOSTAT=ios )
     +				clbl,
     +				( chrin (iq), iq = 1, idpth+1 )
		END IF
		IF ( ios .ne. 0 ) THEN
		    iret = -17
		    RETURN
		END IF
		idpo = idpth + 1
		CALL USR_DECD ( chrin, idpo, trcout, ier )
	    ELSE
		IF ( crlbl .eq. 'r' ) THEN
		    READ (luntd, '(E24.7,29(D20.12))', IOSTAT=ios )
     +				rlbl,
     +				( trcout (iq), iq = 1, idpth+1 )
		ELSE
		    READ (luntd, '(A24,29(D20.12))', IOSTAT=ios )
     +				clbl,
     +				( trcout (iq), iq = 1, idpth+1 )
		END IF
		IF ( ios .ne. 0 ) THEN
		    iret = -17
		    RETURN
		END IF
	    END IF
	    DO j = 1, idpth
		dtrace (nt,j,i) = trcout (j)
	    END DO
	    IF ( lrcnm ) then
		drecnm (nt,i) = trcout (idpth+1)
	    END IF
	    IF ( trcout (1) .lt. -1.E30 ) THEN
		icntm = icntm + 1
	    END IF
C
C*	    Store label.
C
	    IF ( crlbl .eq. 'r' ) THEN
		xrlbls (nt,i) = rlbl
		lbltyp = 'r'
		IF ( nt .gt. 1 .and. lbltyp .ne. ' ' .and.
     +		     lblold .ne. lbltyp ) THEN
		    xclbls (nt,i) = clbl
		    lbltyp = 'c'
		    CALL RDTD_ERR ( 6, ' ', ierr )
		END IF
	    ELSE
		xclbls (nt,i) = clbl
		lbltyp = 'c'
		IF ( nt .gt. 1 .and. lbltyp .ne. ' ' .and.
     +		     lblold .ne. lbltyp .and. lblold .ne. 't' ) THEN
		    xrlbls (nt,i) = rlbl
		    lbltyp = 'r'
		    CALL RDTD_ERR ( 6, ' ', ierr )
		END IF
	    END IF
	END DO
	ntrpts (nt) = npts
	ndepth (nt) = idpth
	alptms (nt) = ( icntm .eq. npts )
	    
C
C*	Make the time in minutes label values.
C
	IF ( itype .eq. 1 .or. itype .eq. 2 ) THEN
	    lbltyp = 't'
	    CALL RDTD_TTM ( crlbl, nt, iret )
	    IF ( iret .ne. 0 ) RETURN
	END IF
C*
	iptype = itype
C*
	RETURN
	END
