	SUBROUTINE RDTD_MDA ( tolrnc, iret )
C************************************************************************
C* RDTD_MDA								*
C*									*
C* This subroutine constructs real or character discrete x axis labels	*
C* and their relative positions for each trace point.			*
C*									*
C* Real case algorithm:							*
C*									*
C*   1.  Make a list of labels in XRLBLS (1,*) by adding labels found	*
C*	 in traces other than the reference trace to the end of the	*
C*	 list of labels for the reference trace.  The reference trace	*
C*	 is the first trace that is not all missing.			*
C*									*
C*   2.  Sort the list of labels without rearranging them in memory	*
C*	 by setting KPNTRS (1) to the index of the first label,		*
C*	 KPNTRS (2) to the index for the second label, and so on.	*
C*	 Do this only if no trace has all of the labels.  If a trace	*
C*	 has all of the labels, use the order found in it.		*
C*									*
C*   3.  Assign the relative positions of the trace points to KMNUTS so	*
C*	 that KMNUTS (itrace, ipoint) gives the index into KPNTRS such	*
C*	 that XRLBLS (1,KPNTRS(index)) is the correct label for that	*
C*	 point on the trace.						*
C*									*
C* The case for character data is similar, with XRLBLS changed to 	*
C* XCLBLS.								*
C*									*
C* RDTD_MDA ( IRET )							*
C*									*
C* Input parameters:							*
C*	TOLRNC		REAL		Tolerance for real equality	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-25 = cannot add more labels	*
C*					-26 = label not found		*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/EMC		 4/98	Set LTAXIS to false			*
C* K. Brill/EMC		 6/98	Set NPNTRS for 1 trace case		*
C* K. Brill/EMC		 7/98	Use trace with all labels as master	*
C* K. Brill/HPC		11/03	Check ALPTMS for all pts missing	*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	CHARACTER*24	clbl
	LOGICAL		found
C*-----------------------------------------------------------------------
	iret = 0
	ltaxis = .false.
C
C*	If there is only one trace, assign indexes in order.
C
	IF ( ntrace .eq. 1 ) THEN
	    npntrs = ntrpts (1)
	    DO ip = 1, ntrpts (1)
		kpntrs (ip) = ip
		kmnuts (1,ip) = ip
	    END DO
	    RETURN
	END IF
C
C*	Make list of all labels in first position of label array.
C
	mt = 0
	found = .false.
	DO WHILE ( .not. found .and. mt .lt. ntrace )
	    mt = mt + 1
	    found = .not. alptms (mt)
	END DO
	mastr = 0
	nstop = ntrpts (mt)
	IF ( lbltyp .eq. 'r' ) THEN
	    DO it = 1, ntrace
	      IF ( .not. alptms (it) .and. it .ne. mt ) THEN
		DO ip = 1, ntrpts (it)
		    rlbl = xrlbls (it,ip)
		    found = .false.
		    i = 0
		    DO WHILE ( i .lt. nstop .and. .not. found )
			i = i + 1
			IF ( ABS ( xrlbls (mt,i) - rlbl ) .le. tolrnc )
     +			    found = .true.
		    END DO
		    IF ( .not. found ) THEN
			nstop = nstop + 1
			IF ( nstop .gt. MXDPTS ) THEN
			    iret = -25
			    RETURN
			END IF
			xrlbls (mt,nstop) = rlbl
		    END IF
		END DO
	      END IF
	    END DO
	    IF ( nstop .ne. ntrpts (mt) ) THEN
		found = .false.
		it = 1
		DO WHILE ( it .lt. ntrace .and. .not. found )
		    it = it + 1
		    found =
     +		    ( ntrpts (it) .eq. nstop .and. .not. alptms (it) )
		END DO
		IF ( found ) mastr = it
	    ELSE
		mastr = mt
	    END IF
	ELSE
	    DO it = 2, ntrace
	      IF ( .not. alptms (it) .and. it .ne. mt ) THEN
		DO ip = 1, ntrpts (it)
		    clbl = xclbls (it,ip)
		    found = .false.
		    i = 0
		    DO WHILE ( i .lt. nstop .and. .not. found )
			i = i + 1
			IF ( xclbls (mt,i) .eq. clbl )
     +			    found = .true.
		    END DO
		    IF ( .not. found ) THEN
			nstop = nstop + 1
			IF ( nstop .gt. MXDPTS ) THEN
			    iret = -25
			    RETURN
			END IF
			xclbls (mt,nstop) = clbl
		    END IF
		END DO
	      END IF
	    END DO
	    IF ( nstop .ne. ntrpts (mt) ) THEN
		found = .false.
		it = 1
		DO WHILE ( it .lt. ntrace .and. .not. found )
		    it = it + 1
		    found =
     +		    ( ntrpts (it) .eq. nstop .and. .not. alptms (it) )
		END DO
		IF ( found ) mastr = it
	    ELSE
		mastr = mt
	    END IF
	END IF
C
C*	Use master trace with all the labels or do the sort.
C
	npntrs = nstop
	CALL RDTD_SRT ( mastr, tolrnc, iret )
C
C*	Assign the relative positions in KMNUTS.
C
	IF ( lbltyp .eq. 'r' ) THEN
	    DO it = 1, ntrace
	      IF ( .not. alptms (it) ) THEN
		DO ip = 1, ntrpts (it)
		    rlbl = xrlbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( ABS ( xrlbls (mt,kpntrs(i)) - rlbl )
     +				.lt. tolrnc ) THEN
			    kmnuts (it,ip) = i
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	      END IF
	    END DO
	ELSE
	    DO it = 1, ntrace
	      IF ( .not. alptms (it) ) THEN
		DO ip = 1, ntrpts (it)
		    clbl = xclbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( xclbls (mt,kpntrs(i)) .eq. clbl ) THEN
			    kmnuts (it,ip) = i
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	      END IF
	    END DO
	END IF
C*
	RETURN
	END
