	SUBROUTINE RDTD_PAE ( mxt, mxd, npts, ndpth, itrc, dtrace,
     +			      rmiss, mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_PAE								*
C*									*
C* This subroutine computes the series of probabilities for the dispo-	*
C* sition of the analysis relative to the ensemble (below, within,	*
C* above, and outside) for a single trace of RHET statistics from an	*
C* ensemble.								*
C*									*
C* RDTD_PAE ( MXT, MXD, NPTS, NDPTH, ITRC, DTRACE, RMISS, MPTS, XPTS,	*
C*	      TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL, RLBL, CLTYP,	*
C*	      IPTYP, PRMNAM, PRFCT, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	NDPTH           INTEGER		Number of values per point	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C* Output parameters:							*
C*	MPTS		INTEGER		Number of output trace points	*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 14 -> to force binned output	*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/04						*
C* K. Brill/HPC		 5/04	Change TLG.A stats to RH.T stats	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), prmnam, cltyp
C*
	REAL*8		tn, sn
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	IF ( npts .gt. 1 ) THEN
	    ierr = 4
	    CALL RDTD_ERR ( ierr, ' ', iret )
	END IF
	prfct = rmiss
	iptyp = 14
	xmin = 1.
	xmax = 4.0
	trcmin = 0.
	trcmax = 1.0
	cltyp = 'c'
	prmnam = 'PROBABILITY'
C
C*	Initialize trace elements to 0.0.
C
	DO id = 1, 4
	    trcdat (id) = 0.0
	END DO
C
C*	Initialize total data count to 0.0.
C
	sn = 0.0
C
C*	Combine all of the trace points.
C
	DO ip = 1, npts
C
C*	    Check that all trace data is not missing.
C
	    ok = .true.
	    id = 0
	    DO WHILE ( ok .and. id .lt. ndpth )
		id = id + 1
		ok = ( dtrace (itrc,id,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
C
C*	        Sum over all probabilities to compute residual for the
C*              last rank.
C
		sn = sn + dtrace (itrc,1,ip)
		trcdat (1) = trcdat (1) + dtrace (itrc,2,ip)
		tn = dtrace (itrc,2,ip)
		DO id = 3, ndpth
		    trcdat (2) = trcdat (2) + dtrace (itrc,id,ip)
		    tn = tn + dtrace (itrc,id,ip)
		END DO
		trcdat (3) = trcdat (3) +
     +				( dtrace (itrc,1,ip) - tn )
	    END IF
	END DO
C
C*	Compute the analysis disposition probabilities.
C
	IF ( sn .le. 0 )  THEN
	    iret = -52
	    RETURN
	END IF
	trcdat (1) = trcdat (1) / sn
	clbl (1) = 'A < E'
	trcdat (2) = trcdat (2) / sn
        clbl (2) = 'E < A < E'
        trcdat (3) = trcdat (3) / sn
	clbl (3) = 'A > E'
	trcdat (4) = trcdat (1) + trcdat (3)
	clbl (4) = 'A<E||A>E'
	DO iop = 1, 4
	    IF ( trcdat (iop) .gt. 1. ) trcdat (iop) = 1.0
	    IF ( trcdat (iop) .lt. 0. ) trcdat (iop) = 0.0
	    xpts (iop) = FLOAT (iop)
	END DO
	mpts = 4
C*
	RETURN
	END
