	SUBROUTINE RDTD_RCC ( mxt, mxd, ndpth, npts,
     +			      itrc, dtrace, rmiss,
     +			      prbs, npbs,
     +			      mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_RCC								*
C*									*
C* This subroutine computes the points on the ROC curve implied by the	*
C* data in an entire PBS time series trace.  The counts in bins for	*
C* assigned forecast probabilities are used to compute the sums for	*
C* counts in 2 X 2 contingency tables for each foreast probability	*
C* category.  These tables are summed to yield a single 2 X 2 		*
C* contingency table for each trace point.				*
C*									*
C* RDTD_RCC (  MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, PRBS, NPBS,	*
C*	       MPTS, XPTS, TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL,	*
C*	       RLBL, CLTYP, IPTYP, PRMNAM, PRFCT, IRET )		*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	PRBS (NPBS)	REAL		Forecast probabilities		*
C*	NPBS		INTEGER		Number of frcst probabilities	*
C*									*
C* Input and Output parameter:						*
C*	MPTS		INTEGER		Input:  maximum number of output*
C*						point allowed.		*
C*					Output:  actual number of output*
C*						 points.		*
C* Output parameters:							*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 4 -> to force binned output	*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/08						*
C* K. Brill/HPC      20090828	Created from prior rdtd_rcc		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		prbs (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), prmnam, cltyp
C*
	REAL*8		sumnz, res, tn, aa, bb, cc, dd, ysave, pod
	REAL*8		xn, bx, cx, oyes, fyes
	LOGICAL		done
C*-----------------------------------------------------------------------
	iret = 0
	prfct = rmiss
	iptyp = 4
	xmin = 0.
	xmax = 1.0
	trcmin = 0.
	trcmax = 1.0
	cltyp = 'r'
	prmnam = 'HIT RATE'
	ibad = 0
C
C*      Compute the number of probability bins.
C
	npb = ndpth / 2
	IF ( npb * 2 .ne. ndpth .or. npb .ne. npbs ) then
	    iret = -61
	    RETURN
	END IF
C
C*	Compute index of data field having number of events
C*      observed with zero probability forecast.
C
	ioapz = npb + 1
C
C*      Execute outer loop over PBS trace points.
C
	iop = 0
	DO ip = 1, npts
C
C*	    Compute number of non-zero probability forecasts
C* 	    and the residual (number of events with zero
C* 	    forecast probability).
C
	    tn = dtrace (itrc,1,ip)
	    IF ( tn .gt. 0.0 ) then
	        sumnz = 0.0
	        DO inz = 2, npb
		    sumnz = sumnz + dtrace (itrc,inz,ip)
	        END DO
	        res = tn - sumnz
C
C*		Construct a contingency table for each category.
C*		Sum all contingency tables together.
C
		xn = res
		aa = 0.0
		bb = 0.0
		cc = 0.0
		dd = 0.0
		DO inz = 1, npb
		    IF ( inz .gt. 1 ) THEN
			xn = dtrace (itrc,inz,ip)
		    END IF
		    ioap = inz + npb
		    fyes = prbs(inz) * xn
		    oyes = dtrace (itrc,ioap,ip)
		    IF ( oyes .gt. fyes ) THEN
			bx = 0.0
			cx = oyes - fyes
		    ELSE
			bx = fyes - oyes
			cx = 0.0
		    END IF
		    aa = aa + ( oyes - cx )
		    bb = bb + bx
		    cc = cc + cx
		    dd = dd + ( xn - ( oyes + bx ) )
		END DO
		IF ( ( aa + cc ) .gt. 0.0 .and.
     +		     ( bb + dd ) .gt. 0.0 ) THEN
	            fr = bb / ( bb + dd )
	            pod = aa / ( aa + cc )
		    IF ( fr .ge. 0. .and. fr .le. 1. .and.
     +			 pod .ge. 0. .and. pod .le. 1. ) THEN
		    	iop = iop + 1
	                xpts (iop) = fr
	                trcdat (iop) = pod
		    ELSE
			ibad = ibad + 1
		    END IF
		END IF
	    END IF
	END DO
	IF ( ibad .ne. 0 ) THEN
	    WRITE (6,*) ibad, ' bad ROC points rejected. '
	END IF
C
C*	Sort the output data from lowest value of xpts to highest.
C
	IF ( iop .gt. 0 ) THEN
	    done = .false.
	    i = 1
	    iswp = 0
	    DO WHILE ( .not. done )
	        IF ( xpts(i).gt. xpts(i+1) ) THEN
		    iswp = iswp + 1
		    xsave = xpts (i)
		    ysave = trcdat (i)
		    xpts(i) = xpts(i+1)
		    trcdat(i) = trcdat(i+1)
		    xpts (i+1) = xsave
		    trcdat (i+1) = ysave
	        END IF
	        i = i + 1
	        IF ( i .eq. iop ) THEN
		    done = ( iswp .eq. 0 )
		    i = 1
		    iswp = 0
	        END IF
	    END DO
	ELSE
	    mpts = 0	
	    iret = -62
	    RETURN
	END IF
	mpts = iop
C*
	RETURN
	END
