	SUBROUTINE RDTD_SRT ( mastr, eps, iret )
C************************************************************************
C* RDTD_SRT								*
C*									*
C* This subroutine sorts the labels in either XRLBLS (1,*) or XCLBLS	*
C* (1,*).  The labels are not rearranged.  KPNTRS contains indexes	*
C* of the sorted entries.						*
C*									*
C* If MASTR is not 0, then trace MASTR is used to determine the	order	*
C* of the labels, and no sort is done.					*
C*									*
C* The sort is done from the lowest value of XRLBLS or XCLBLS to the	*
C* highest.  LBLTYP determines the type of sort.			*
C*									*
C*									*
C* RDTD_SRT ( MASTR, EPS, IRET )					*
C*									*
C* Input parameters:							*
C*	MASTR		INTEGER		Master trace for labels		*
C*	EPS		REAL		Tolerance for real equality	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-27 = invalid label type	*
C*					-39 = mstr trc lbl not found	*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/EMC		 7/98	Changes for using master trace		*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	LOGICAL		found
C*------------------------------------------------------------------------
	iret = 0
C
C*	Initialize index array to current indexes.
C
	DO i = 1, npntrs
	    kpntrs (i) = i
	END DO
C
C*	Check for a master trace.
C
	IF ( mastr .gt. 0 .and. mastr .lt. ntrace ) THEN
	    IF ( lbltyp .eq. 'r' ) THEN
		DO ip = 1, npntrs
		    found = .false.
		    ii = 0
		    DO WHILE ( .not. found .and. ii .lt. npntrs )
			ii = ii + 1
			IF ( ABS ( xrlbls (mastr,ip) - xrlbls (1,ii) )
     +			     .lt. eps ) THEN
			    kpntrs (ip) = ii
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -39
			RETURN
		    END IF
		END DO
	    ELSE IF ( lbltyp .eq. 'c' ) THEN
		DO ip = 1, npntrs
		    found = .false.
		    ii = 0
		    DO WHILE ( .not. found .and. ii .lt. npntrs )
			ii = ii + 1
			IF ( xclbls (mastr,ip) .eq. xclbls (1,ii) ) THEN
			    kpntrs (ip) = ii
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			iret = -39
			RETURN
		    END IF
		END DO
	    ELSE
		iret = -27
	    END IF
C*
	    RETURN
C*
	END IF
C
C*	Do a sort.
C
	IF ( lbltyp .eq. 'r' ) THEN
	    i = 1
	    DO WHILE ( i .lt. npntrs )
		j = 1
		DO WHILE ( j .le. ( npntrs - i ) )
		    IF ( xrlbls ( 1, kpntrs (j) ) .gt.
     +                   xrlbls ( 1, kpntrs (j+1) ) ) THEN
			ksave = kpntrs (j)
			kpntrs (j) = kpntrs (j+1)
			kpntrs (j+1) = ksave
		    END IF
		    j = j + 1
		END DO
		i = i + 1
	    END DO
	ELSE IF ( lbltyp .eq. 'c' ) THEN
	    i = 1
	    DO WHILE ( i .lt. npntrs )
		j = 1
		DO WHILE ( j .le. ( npntrs - i ) )
		    IF ( xclbls ( 1, kpntrs (j) ) .gt.
     +                   xclbls ( 1, kpntrs (j+1) ) ) THEN
			ksave = kpntrs (j)
			kpntrs (j) = kpntrs (j+1)
			kpntrs (j+1) = ksave
		    END IF
		    j = j + 1
		END DO
		i = i + 1
	    END DO
	ELSE
	    iret = -27
	    RETURN
	END IF
C*
	RETURN
	END
