	SUBROUTINE RDTD_TGD ( mxt, mxd, cstat, npts, ndpth, itrc,
     +			      dtrace, rmiss, mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_TGD								*
C*									*
C* This subroutine computes the points on a Ranked Histogram diagram	*
C* given a single trace of RHET or RHNT statistics from an ensemble.	*
C*									*
C* RDTD_TGD ( MXT, MXD, CSTAT, NPTS, NDPTH, ITRC, DTRACE, RMISS, MPTS, 	*
C*	      XPTS, TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL, RLBL,	*
C*	      CLTYP, IPTYP, PRMNAM, PRFCT, IRET )			*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	CSTAT		CHAR*		Statistic type (RHET/RHNT)	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	NDPTH           INTEGER		Number of values per point	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C* Output parameters:							*
C*	MPTS		INTEGER		Number of output trace points	*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 14 -> to denote this output  *
C*					   as particular binned output  *
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/04						*
C* K. Brill/HPC		 5/04	Change TLG.A stats to RH.T stats	*
C************************************************************************
	CHARACTER*(*)	cstat
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), prmnam, cltyp
C*
	REAL*8		tn, sn
	CHARACTER*2	mbr
	LOGICAL		rhnt, ok
C*-----------------------------------------------------------------------
	iret = 0
	IF ( npts .gt. 1 ) THEN
	    ierr = 4
	    CALL RDTD_ERR ( ierr, ' ', iret )
	END IF
	prfct = rmiss
	iptyp = 14
	trcmin = 0.
	trcmax = 1.0
	prmnam = 'PROBABILITY'
	xmin = 1.
	xmax = FLOAT ( ndpth )
	rhnt = ( INDEX ( cstat, 'RHNT' ) .gt. 0 )
	cltyp = 'c'
C
C*	Initialize trace elements to 0.0.
C
	DO id = 1, ndpth
	    trcdat (id) = 0.0
	END DO
C
C*	Initialize total data count to 0.0.
C
	sn = 0.0
C
C*	Combine all of the trace points.
C
	DO ip = 1, npts
C
C*	    Check that all trace data is not missing.
C
	    ok = .true.
	    id = 0
	    DO WHILE ( ok .and. id .lt. ndpth )
		id = id + 1
		ok = ( dtrace (itrc,id,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
C
C*	        Sum over all probabilities to compute residual for the
C*              last rank.  Also accumulate rank sums.
C
		sn = sn + dtrace (itrc,1,ip)
		tn = 0.0
		iop = 0
		DO id = 2, ndpth
		    iop = iop + 1
		    trcdat (iop) = trcdat (iop) + dtrace (itrc,id,ip)
		    tn = tn + dtrace (itrc,id,ip)
		END DO
		iop = iop + 1
		trcdat (iop) = trcdat (iop) +
     +				( dtrace (itrc,1,ip) - tn )
	    END IF
	END DO
C
C*	Compute output probabilities and X axis label strings.
C
	DO iop = 1, ndpth
	    xpts (iop) = FLOAT (iop)
	    IF ( sn .gt. 0.0 ) THEN
		trcdat (iop) = trcdat (iop) / sn
		IF ( trcdat (iop) .lt. 0.0 ) trcdat (iop) = 0.0
		IF ( trcdat (iop) .gt. 1.0 ) trcdat (iop) = 1.0
	    ELSE
		trcdat (iop) = rmiss
	    END IF
	    IF ( rhnt ) THEN
		WRITE (mbr,'(I2.2)') iop
		clbl (iop) = mbr
	    ELSE
		IF ( iop .eq. 1 ) THEN
		    clbl (iop) = 'A<E'
		ELSE IF ( iop .lt. ndpth ) THEN
		    WRITE (mbr,'(I2.2)') iop
		    clbl (iop) = mbr
		ELSE
		    clbl (iop) = 'A>E'
		END IF
	    END IF
	END DO
	mpts = ndpth
C*
	RETURN
	END
