	SUBROUTINE RDTD_TRK (  icomp, itrc, rmiss, trcsav,
     +			       trcdat, trcmin, trcmax, prmnam, prfct,
     +			       iret )
C************************************************************************
C* RDTD_TRK								*
C*									*
C* This subroutine returns a specific trace of data for the TRK		*
C* statistic type.							*
C*									*
C* This subroutine handles the following computational codes:		*
C*									*
C*    101101 - 101115  L1L2 computations for TRK distance error.	*
C*    111101 - 111115  L1L2 computations for TRK PMSL error.		*
C*    121101 - 121115  L1L2 computations for TRK Max Wind speed error.	*
C*    131101 - 131115  L1L2 computations for TRK 850 Vort error.	*
C*									*
C* ICOMP tells what value to compute from data field numbers.		*
C*									*
C*	ICOMP			Action					*
C*	x1101		Compute BIAS (SAL1L2, SL1L2)			*
C*	x1102		Compute RMS error (SAL1L2, SL1L2)		*
C*	x1103		Compute Correlation (SAL1L2, SL1L2)		*
C*	x1104		Compute Covariance (SAL1L2,SL1L2)		*
C*	x1105		Compute Forecast Variance (SAL1L2, SL1L2)	*
C*	x1106		Compute Observation Variance (SAL1L2, SL1L2)	*
C*	x1107		Compute Forecast Std Dev (SAL1L2, SL1L2)	*
C*	x1108		Compute Obs Std Dev (SAL1L2, SL1L2)		*
C*	x1109		Compute Error Std Dev (SAL1L2, SL1L2)		*
C*	x1110		Compute BIAS + Error Std Dev (SAL1L2, SL1L2)	*
C*	x1111		Compute BIAS - Error Std Dev (SAL1L2, SL1L2)	*
C*	x1112		Compute BIAS**2					*
C*	x1113		Compute -2*Covariance				*
C*	x1114		Compute Error Variance				*
C*	x1115		Compute Mean Squared Error			*
C*									*
C* where x = 10, 11, 12, or 13 as indicated above.			*
C*									*
C* RDTD_TRK ( ICOMP, ITRC, RMISS, TRCSAV,				*
C*	      TRCDAT, TRCMIN, TRCMAX, PRMNAM, PRFCT, IRET )		*
C*									*
C* Input parameters:							*
C*	ICOMP		INTEGER		Computational code		*
C*	ITRC		INTEGER		Trace number			*
C*	RMISS		REAL		Missing value			*
C*									*
C* Output parameters:							*
C*	TRCSAV (*)	REAL		Working array			*
C*	TRCDAT (*)	REAL*8		Trace data			*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20061221 	Created					*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	REAL*8		trcdat (*)
	REAL		trcsav (*)
	CHARACTER*(*)	prmnam
C*
	CHARACTER*6	cnam
C*------------------------------------------------------------------------
	iret = 0
	prfct = rmiss
	prmnam = ' '
	npts = ntrpts (itrc)
	ndpt = ndepth (itrc)
C
C*	Split ICOMP into two parts.
C
	iprt1 = icomp / 10000
	icmp = MOD ( icomp, ( iprt1 * 1000 ) )
C
C*	On the basis of part 1, extract the data from dtrace and
C*      load it into trctrk array.
C
	IF ( iprt1 .eq. 10 ) THEN
	    cnam = 'DISTNC'
C
C*	    Populate the distance error L1L2 norms.
C
	    DO ip = 1, npts
		trktrc (1,ip) = dtrace (itrc,1,ip)
		trktrc (2,ip) = dtrace (itrc,5,ip)
		trktrc (3,ip) = 0.0
		trktrc (4,ip) = 0.0
	        trktrc (5,ip) = dtrace (itrc,6,ip)
		trktrc (6,ip) = 0.0
	    END DO
	ELSE IF ( iprt1 .gt. 10 .and. iprt1 .le. 13 ) THEN
	    IF ( iprt1 .eq. 11 ) THEN
		cnam = 'CENPRS'
		id2 = 9
		IF ( ndpt .lt. 13 ) THEN
		    iret = -56
		    RETURN
		END IF
	    ELSE IF ( iprt1 .eq. 12 ) THEN
		cnam = 'MAXWND'
		id2 = 14
		IF ( ndpt .lt. 18 ) THEN
		    iret = -57
		    RETURN
		END IF
	    ELSE IF ( iprt1 .eq. 13 ) THEN
		cnam = '850VOR'
		id2 = 19
		IF ( ndpt .lt. 23 ) THEN
		    iret = -58
		    RETURN
		END IF
	    END IF
	    DO ip = 1, npts
		trktrc (1,ip) = dtrace (itrc,1,ip)
		idx = id2
		DO idp = 2, 6
		    trktrc (idp,ip) = dtrace (itrc,idx,ip)
		    idx = idx + 1
		END DO
	    END DO
	ELSE
	    iret = -55
	    RETURN
	END IF
C*
	IF ( icmp .gt. 1100 .and. icmp .le. 1115 ) THEN
	    IF ( icmp .eq. 1101 ) THEN
		CALL CS_BIAS ( 0, 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCALR_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1102 ) THEN
		CALL CS_RMSE ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCALR_RMSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1103 ) THEN
		CALL CS_CORR ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCALR_CORR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1104 ) THEN
		CALL CS_COVA ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1105 ) THEN
		CALL CS_FVAR ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_FRVAR'
	    ELSE IF ( icmp .eq. 1106 ) THEN
		CALL CS_OVAR ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_OBVAR'
	    ELSE IF ( icmp .eq. 1107 ) THEN
		CALL CS_FSTD ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_FRSDV'
	    ELSE IF ( icmp .eq. 1108 ) THEN
		CALL CS_OSTD ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_OBSDV'
	    ELSE IF ( icmp .eq. 1109 ) THEN
		CALL CS_ESIG ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		prmnam = cnam // '_' // 'SCLR_ERR_SIG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1110 .or.
     +		      icmp .eq. 1111 ) THEN
		IF ( icmp .eq. 1110 ) THEN
		    sign = 1.0
		    prmnam = cnam // '_' // 'SCLR_BIAS+SIG'
		ELSE
		    sign = -1.0
		    prmnam = cnam // '_' // 'SCLR_BIAS-SIG'
		END IF
		CALL CS_BIAS ( 0, 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		DO ip = 1, npts
		    trcsav (ip) = trcdat (ip)
		END DO
		CALL CS_ESIG ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, npts
		    IF ( trcdat (ip) .ne. rmiss .and.
     +			 trcsav (ip) .ne. rmiss ) THEN
			trcdat (ip) = trcsav (ip) + sign * trcdat (ip)
			IF ( trcdat (ip) .gt. trcmax )
     +			    trcmax = trcdat (ip)
			IF ( trcdat (ip) .lt. trcmin )
     +			    trcmin = trcdat (ip)
			icnt = icnt + 1
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1112 ) THEN
		CALL CS_BIAS ( 0, 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, npts
		    IF ( trcdat (ip) .ne. rmiss ) THEN
			trcdat (ip) = trcdat (ip) * trcdat (ip)
			IF ( trcdat (ip) .gt. trcmax )
     +			    trcmax = trcdat (ip)
			IF ( trcdat (ip) .lt. trcmin )
     +			    trcmin = trcdat (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = cnam // '_' // 'SCALR_BIAS**2'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1113 ) THEN
		CALL CS_COVA ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdat (ip) .ne. rmiss ) THEN
			trcdat (ip) = -2.0 * trcdat (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = cnam // '_' // '-2*SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1114 ) THEN
		CALL CS_ESIG ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdat (ip) .ne. rmiss ) THEN
			trcdat (ip) = trcdat (ip) * trcdat (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = cnam // '_' // 'SCLR_ERR_VAR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1115 ) THEN
		CALL CS_RMSE ( 1, NNL1L2, npts,
     +			       1, trktrc, rmiss,
     +			       trcdat, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdat (ip) .ne. rmiss ) THEN
			trcdat (ip) = trcdat (ip) * trcdat (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = cnam // '_' // 'SCALR_MSE'
		prfct = 0.0
	    END IF
	END IF
C*
	RETURN
	END
