	SUBROUTINE RSMP_BAJ ( itrc, iba, np, nd, iret )
C************************************************************************
C* RSMP_BAJ								*
C*									*
C* This subroutine performs bias adjustment for FHO values.		*
C*									*
C*									*
C* RSMP_BAJ ( ITRC, IBA, NP, ND, IRET )					*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number in pari (1 or 2)	*
C*	IBA		INTEGER		Bias adjustment prefix #	*
C*					  0 = No bias adjustment	*
C*					101 = DH/DF based adjustment	*
C*					102 = Odds ratio based adjust.	*
C*					103 = DH/DM based adjustment	*
C*					104 = Frequency matching	*
C*	NP		INTEGER		Number of points in the sample	*
C*	ND		INTEGER		Data depth (should be 4)	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-05 = wrong data depth for FHO	*
C**									*
C* Log:									*
C* K. Brill/HPC      20120326	Adapted from RDTD_BAJ			*
C* K. Brill/WPC	     20140502	Add prefix 104 for frequency matching	*
C*				bias removal				*
C************************************************************************
	INCLUDE		'rsmp.cmn'
C*
	REAL*8		tn, f, h, o, td, dn
C*------------------------------------------------------------------------
	iret = 0
	IF ( iba .eq. 0 ) RETURN
C*
	kchk = 4
	IF ( iba .eq. 104 ) THEN
	    kchk = 5
	END IF
	IF ( nd .lt. kchk ) THEN
	    iret = -5
	    RETURN
	END IF
	DO ip = 1, np
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
            IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +		 tn .ne. 0.0 ) THEN
		IF ( iba .eq. 101 .and. o .gt. 0.0 .and. 
     +		     f .gt. 0.0 ) THEN
C
C*		    Fedor Mesinger's bias adjustment.
C
		    h = o * ( 1. - ( ( (o-h) / o ) ** (o/f) ) )
		    dtrace (itrc,2,ip) = o
		    dtrace (itrc,3,ip) = h
C*
	 	ELSE IF ( iba .eq. 102 ) THEN
C
C*		    The Odds Ratio bias adjustment.
C
		    IF ( ( f .eq. h .or. o .eq. h ) .and.
     +                     h .ne. 0 ) THEN
C
C*		        Perfect forecast, odds ratio is infinite.
C
		        dtrace (itrc,2,ip) = o
		        dtrace (itrc,3,ip) = o
C*
	 	    ELSE IF ( h .eq. 0 ) THEN
C
C*		        Degenerate case, odds ratio is zero.
C
		        dtrace (itrc,2,ip) = o
		        dtrace (itrc,3,ip) = 0.0
C*
		    ELSE IF ( o .gt. h .and.
     +			      f .gt. h .and. h .gt. 0 ) THEN
C
C*		        Odds ratio conservation bias adjustment.
C
		        td = h * ( tn - f - o + h )
		        dn = ( o - h ) * ( f - h )
		        td = td / dn
		        IF ( td .gt. 1.0 ) THEN
		            dn = o + .5 * ( tn / ( td - 1. ) )
		            h = dn - DSQRT ( dn * dn -
     +				   ( td * o * o ) / ( td - 1. ) )
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = h
		        ELSE IF ( td .eq. 1.0 ) THEN
C
C*			    Odds ratio is 1, forecast is random.
C
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = o * o
C*
		        ELSE
C
C*			    Odds ratio is less than 1.
C
		            dn = o - .5 * ( tn / ( 1. - td ) )
		            h = dn + DSQRT ( dn * dn +
     +				   ( td * o * o ) / ( 1. - td ) )
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = h
C*
		        END IF
		    END IF
	 	ELSE IF ( iba .eq. 103 ) THEN
C
C*		    Fedor Mesinger's dHdM method of bias adjustment:
C
		    CALL RDTD_HDM ( f, h, o, h, ier )
		    dtrace (itrc,2,ip) = o
		    dtrace (itrc,3,ip) = h
C*
		ELSE IF ( iba .eq. 104 ) THEN
C
C*		    Use frequency matched hit and forecast values:
C
		    IF ( nd .gt. 5 ) THEN
C			Replace F value if present.
		        dtrace (itrc,2,ip) = dtrace (itrc,6,ip)
		    ELSE
C			Forecast value becomes same as obs value.
		        dtrace (itrc,2,ip) = dtrace (itrc,4,ip)
		    END IF
C		    Replace the hit rate.
		    dtrace (itrc,3,ip) = dtrace (itrc,5,ip)
C*
	 	END IF
	    END IF
	END DO
C*
	RETURN
	END
