	SUBROUTINE RSMP_SRT ( arry, nmbr, rmiss, nprct, prctl, wrka,
     +			      amin, amax, iret )
C************************************************************************
C* RSMP_SRT								*
C*									*
C* This subroutine sorts an array of values and returns the requested	*
C* percentile values.							*
C*									*
C* The
C*									*
C* RSMP_SRT ( ARRY, NMBR, RMISS, NPRCT, PRCTL, IRET )			*
C*									*
C* Input parameters:							*
C*	ARRY		REAL*8		Input array of values		*
C*	NMBR		INTEGER		Number of values in the array	*
C*	RMISS		REAL		Missing value			*
C*	NPRCT		INTEGER		Number of percentiles requested *
C*									*
C* Input and Output parameter:						*
C*	PRCTL (NPRCT)	REAL		Input:  percentile levels in	*
C*						range 0 to 1		*
C*					Output: corresponding percentile*
C*						values			*
C*	WRKA		REAL*8		Work array (contents not	*
C*					relevant on input or output)	*
C*									*
C* Output parameters:							*
C*	AMIN		REAL		Minimum value in ARRY		*
C*	AMAX		REAL		Maximum value in ARRY		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20120329	Created					*
C* K. Brill/HPC	     20120330	Add max and min output			*
C************************************************************************
	REAL*8		arry (*), wrka (*)
	REAL		prctl (*)
C*
	REAL*8		save
C*------------------------------------------------------------------------
C*
	iret = 0
C
C*	Remove any missing values.
C
	nv = 0
	DO kk = 1, nmbr
	    IF ( ABS (arry (kk) - rmiss) .gt. .0005 ) THEN
		nv = nv + 1
		wrka (nv) = arry (kk)
	    END IF
	END DO
	IF ( nv .eq. 0 ) THEN
	    DO i = 1, nprct
		prctl (i) = rmiss
	    END DO
	    iret = -11
	    RETURN
	END IF
C
C*	Do a bubble sort to generate order statistics.
C
	DO i = 1, nv-1
	    DO j = i+1, nv
		IF ( wrka (i) .gt. wrka (j) ) THEN
		    save = wrka (i)
		    wrka (i) = wrka (j)
		    wrka (j) = save
		END IF
	    END DO
	END DO
C*
	amin = wrka (1)
	amax = wrka (nv)
C
C*	Convert percentile levels into counts and assign values:
C
	DO i = 1, nprct
C*
	    prctl (i) = FLOAT (nv) * prctl (i)
C
C*	    Assign percentile values from the order statistics.
C
	    ilo = INT ( prctl (i) )
	    ihi = ilo + 1
	    IF ( ilo .le. 1 ) then
		prctl (i) = wrka (1)
	    ELSE IF ( ihi .ge. nv ) THEN
		prctl (i) = wrka (nv)
	    ELSE
		di = prctl (i) - ilo
		prctl (i) = wrka (ilo) +
     +			    di * ( wrka (ihi) - wrka (ilo) )
	    END IF
C*
	END DO
C*
	RETURN
	END
