	SUBROUTINE SRCH_CHK ( cvrsn, cmdl, fh, rfw, ymdhn, rymdhw,
     +			      rymdhi, canl, crgn, cstat, cstth, rthrsh,
     +			      lthflg, cprm, clvl, rlvl, nlev, icmb, 
     +			      icode, ncdip, ifeld, clist, rlist, nlist,
     +			      indvar, ok, clbl, rlbl, iret )
C************************************************************************
C* SRCH_CHK								*
C*									*
C* This subroutine performs a rigid check of the parsed input data	*
C* record to see if it is to be included in a trace.			*
C*									*
C* If the comparison check is of type character and the flag INDVAR is	*
C* .TRUE., then CLBL is assigned a character string to be used as a	*
C* label for combining the data.  If the comparison check if of type	*
C* real and INDVAR is .TRUE., then RLBL is assigned a real value to be	*
C* used as a label for data combination.				*
C*									*
C* If OK is .TRUE., then this record must be accepted.			*
C*									*
C* NCDIP is the number of conditionally determined independent varible	*
C* points and is used to set the correct label values for checks on	*
C* independent variable conditions.  When only one independent variable	*
C* condition is being applied, the value found is that needed for a	*
C* label when range checking is in effect.  NCDIP = 0 if checking is	*
C* for a dependent variable.						*
C*									*
C* SRCH_CHK ( CVRSN, CMDL, FH, RFW, YMDHN, RYMDHW, RYMDHI, CANL, CRGN,	*
C*	      CSTAT, CSTTH, RTHRSH, LTHFLG, CPRM, CLVL, RLVL, NLEV,	*
C*	      ICMB, ICODE, NCDIP, IFELD, CLIST, RLIST, NLIST, INDVAR,	*
C*	      OK, CLBL, RLBL, IRET )					*
C*									*
C* Input parameters:							*
C*	CVRSN		CHAR*		Version number field		*
C*	CMDL		CHAR*		Model verified			*
C*	FH		REAL		Forecast hour			*
C*	RFW		REAL		Forecast time window (h)	*
C*	YMDHN		CHAR*12		YYYYMMDDHHNN (NN = minutes)	*
C*	RYMDHW		REAL		Verifying time window (h)	*
C*	RYMDHI		REAL		Time increment (h)		*
C*	CANL		CHAR*		Verifying analysis		*
C*	CRGN		CHAR*		Verifying region		*
C*	CSTAT		CHAR*		Statistic type without threshold*
C*	CSTTH		CHAR*		Statistic type with threshold	*
C*	RTHRSH		REAL		Real value threshold		*
C*	LTHFLG		INTEGER		Threshold type flag		*
C*					 = -1 if lower bound		*
C*					 = 0 if no threshold value	*
C*					 = +1 if upper bound		*
C*	CPRM		CHAR*		Parameter name			*
C*	CLVL		CHAR*		Level identifier		*
C*	RLVL (2)	REAL		Levels				*
C*	NLEV		INTEGER		Number of levels		*
C*	ICMB		INTEGER		Combination code for data	*
C*	ICODE		INTEGER		Comparison condition type #	*
C*	NCDIP		INTEGER		# of cond. determined iv pts	*
C*	IFELD		INTEGER		Descriptor/data field element #	*
C*	CLIST (NLIST)	CHAR*		Character strings to match	*
C*	RLIST (NLIST)	REAL		Real values to match		*
C*	NLIST		INTEGER		Number of char/real values	*
C*	INDVAR		LOGICAL		Independent variable flag	*
C*									*
C* Output parameters:							*
C*	OK		LOGICAL		Acceptance flag			*
C*	CLBL		CHAR		Char ind var label string	*
C*	RLBL		REAL		Real ind var label value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-18 = real cond is invalid	*
C*					-19 = char cond is invalid	*
C*					-20 = field # points beyond data*
C*					-21 = field # is invalid	*
C*					-33 = time period invalid	*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		 9/97	Add call SRCH_FNP for time periods 	*
C* K. Brill/EMC		10/97	Added NCDIP; add field 15 (HHNN)	*
C* K. Brill/HPC		 3/03	Accept stat type with threshold		*
C* K. Brill/HPC		04/11	Check for icode .eq. 21			*
C* K. Brill/HPC         04/11	Check for ifeld .eq. 17			*
C* K. Brill/IMSG        01/16   Set ifdndx for SRCH_FNC to chng hfield  *
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	CHARACTER*(*)	cvrsn, cmdl, canl, crgn,
     +			cstat, cstth, cprm, clvl, clist (*), clbl
	CHARACTER*12	ymdhn
	REAL		rlvl (2), rlist (*)
	LOGICAL		indvar, ok, ror
C*
	CHARACTER*4	chhnn
	CHARACTER*2	chh
C*------------------------------------------------------------------------
	iret = 0
C*
	ok = .false.
	rlbl = -1.1E31
	clbl = ' '
	ror = icode .eq. 21
C
C*      Set common variable ifdndx so that SRCH_FNC can modify hfield
C*      if necessary.
C
        ifdndx = ifdmap ( ifeld )
C*
	IF ( ifeld .eq. 1 ) THEN
C
C*	   Checking the version number.
C
	   ok = icode .eq. 0
	   IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		rvrsn = FLOAT ( ivrson )
		CALL SRCH_FNR ( icode, ncdip, rvrsn, rlist, nlist,
     +				ok, rlbl, ier )
	   ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, cvrsn, clist, nlist,
     +				ok, clbl, ier )
	   ELSE IF ( ok .and. indvar ) THEN
		clbl = cvrsn
	   END IF
C*
	ELSE IF ( ifeld .eq. 2 ) THEN
C
C*	    Checking the model being verified.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, cmdl, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = cmdl
	    END IF
C*
	ELSE IF ( ifeld .eq. 3 ) THEN
C
C*	    Checking forecast hour.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, fh, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (3) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. fh .gt. -1.E30 ) THEN
		rlbl = fh
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C*
	ELSE IF ( ifeld .eq. 4 ) THEN
C
C*	    Checking forecast time window.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, rfw, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (4) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. rfw .gt. -1.E30 ) THEN
		rlbl = rfw
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C*
	ELSE IF ( ifeld .eq. 5 ) THEN
C
C*	    Checking verification time.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 .and.
     +			icode .le. 18 ) THEN
		CALL SRCH_FNC ( icode, ncdip, ymdhn, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 19 ) THEN
		CALL SRCH_FNP ( icmb, icode, ncdip, ymdhn,  rymdhw,
     +				clist, ok, clbl, iret )
		IF ( iret .ne. 0 ) RETURN
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = ymdhn
	    END IF
C*
	ELSE IF ( ifeld .eq. 6 ) THEN
C
C*	    Checking the verifying time window.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, rymdhw, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (6) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. rymdhw .gt. -1.E30 ) THEN
		rlbl = rymdhw
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C*
	ELSE IF ( ifeld .eq. 7 ) THEN
C
C*	    Checking the verifying time increment.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, rymdhi, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (7) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. rymdhi .gt. -1.E30 ) THEN
		rlbl = rymdhi
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C*
	ELSE IF ( ifeld .eq. 8 ) THEN
C
C*	    Checking the verifying analysis.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, canl, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = canl
	    END IF
C*
	ELSE IF ( ifeld .eq. 9 ) THEN
C
C*	    Checking the verifying region.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, crgn, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = crgn
	    END IF
C*
	ELSE IF ( ifeld .eq. 10 ) THEN
C
C*	    Checking the statistic type.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, cstat, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = cstat
	    END IF
	    IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, cstth, clist, nlist,
     +				ok, clbl, ier )
	    END IF
C*
	ELSE IF ( ifeld .eq. 11 ) THEN
C
C*	    Checking the threshold value.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, rthrsh, rlist,
     +				nlist, ok, rlbl, ier )
		IF ( ok .and. indvar ) THEN
		    rlbl = rthrsh
		END IF
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (11) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. lthflg .ne. 0 ) THEN
		rlbl = rthrsh
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C*
	ELSE IF ( ifeld .eq. 12 ) THEN
C
C*	    Checking the parameter name.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, cprm, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = cprm
	    END IF
C*
	ELSE IF ( ifeld .eq. 13 ) THEN
C
C*	    Checking the level identifier.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, clvl, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = clvl
	    END IF
C*
	ELSE IF ( ifeld .eq. 14 ) THEN
C
C*	    Checking the level value.
C
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		IF ( nlev .eq. 2 ) THEN
		    iret = -18
		    RETURN
		END IF
		CALL SRCH_FNR ( icode, ncdip, rlvl, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, hfield ( ifdmap (14) ),
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		IF ( nlev .eq. 1 .and. rlvl (1) .gt. -1.E30 ) THEN
		    rlbl = rlvl (1)
		ELSE
		    clbl = hfield ( ifdmap (14) )
		END IF
	    END IF
C*
	ELSE IF ( ifeld .eq. 15 ) THEN
C
C*	    Checking the verifying HHNN (hour minute).
C
	    chhnn = ymdhn ( 9:12 )
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		iret = -18
		RETURN
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL SRCH_FNC ( icode, ncdip, chhnn, clist, nlist,
     +				ok, clbl, ier )
	    ELSE IF ( ok .and. indvar ) THEN
		clbl = chhnn
	    END IF
C*
	ELSE IF ( ifeld .eq. 17 ) THEN
C
C*	    Checking the initial HH (hour).
C
	    chh = ymdhn ( 9:10 )
	    CALL ST_NUMB ( chh, nhh, ier )
	    ifh = INT ( fh + .0005 )
	    ifm24 = MOD ( ifh, 24 )
	    ihh = nhh - ifm24
	    IF ( ihh .lt. 0 ) THEN
		ihh = ihh + 24
	    END IF
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
	        rih = FLOAT ( ihh )
		CALL SRCH_FNR ( icode, ncdip, rih, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		CALL ST_INCH ( ihh, chh, ier )
		CALL SRCH_FNC ( icode, ncdip, chh,
     +				clist, nlist, ok, clbl, ier )
	    ELSE IF ( ok .and. indvar .and. rih .gt. -1.E30 ) THEN
		rlbl = rih
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
C
C*	Add future descriptor field checks here.
C
	ELSE IF ( ifeld .gt. 100 ) THEN
C
C*	    Checking a datam value.
C
	    indx = ifeld - 100
	    IF ( indx .gt. numrel ) THEN
		iret = -20
		RETURN
	    END IF
	    dval = reldat ( indx )
	    ok = icode .eq. 0
	    IF ( .not. ok .and. ( icode .lt. 10 .or. ror ) ) THEN
		CALL SRCH_FNR ( icode, ncdip, dval, rlist, nlist,
     +				ok, rlbl, ier )
	    ELSE IF ( .not. ok .and. icode .ge. 10 ) THEN
		iret = -19
		RETURN
	    ELSE IF ( ok .and. indvar .and. dval .gt. -1.E30 ) THEN
		rlbl = dval
	    ELSE IF ( ok .and. indvar ) THEN
		ok = .false.
	    END IF
	ELSE
	    iret = -21
	END IF
C*
	RETURN
	END
