	SUBROUTINE SRCH_CMC ( nt, itrcs, mfq, mstrt, iret )
C************************************************************************
C* SRCH_CMC								*
C*									*
C* This subroutine combines multiple trace data at point locations at	*
C* which the data count is MSTFRQ for that trace.			*
C* 									*
C*									*
C* SRCH_CMC ( NT, ITRCS, MFQ, MSTRT, IRET )				*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*	MFQ (MXTRCS)	INTEGER		Most frequent count values	*
C*	MSTRT (MXTRCS)  INTEGER		Index of 1st pt with MFQ values *
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +2 = a trace has 0 points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-40 = all traces have 0 points	*
C*					-49 = data count not reached	*
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*), mfq (*), mstrt (*)
C*
	REAL*8		rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
C*-----------------------------------------------------------------------
	iret = 0
	ntotl = 0
	DO it = 1, nt
	    itrc = itrcs (it)
	    mstfrq = mfq (itrc)
	    ipt1 = mstrt (itrc)
	    iaccp = 0
	    ndat = 0
	    DO ipnt = ipt1, ndatap (itrc)
		IF ( kounts (itrc,ipnt) .eq. mstfrq ) THEN
		    DO jd = 1, ndepth (itrc)
			rhold (jd) = 0.0
		    END DO
		    in = 0
		    icnt = 0
		    DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			       icnt .lt. kounts (itrc,ipnt) )
			in = in + 1
			IF ( kpoint (itrc,in) .eq. ipnt ) THEN
			    iaccp = iaccp + 1
			    iswap = in
			    dtmsv = conchk (itrc,in)
			    icnt = icnt + 1
			    IF ( kdvcmb (itrc) .eq. 0 ) THEN
				DO jd = 1, ndepth (itrc)
				    rhold (jd) = dtrace (itrc,jd,in)
				END DO
			    ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
				DO jd = 1, ndepth (itrc)
				    rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
				END DO
			    ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
				DO jd = 1, ndepth (itrc)
				    IF ( jd .eq. indxdc (itrc) ) THEN
					rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				    ELSE
					r1 =
     +					   dtrace (itrc,indxdc(itrc),in)
					rn = dtrace (itrc,jd,in)
					rhold (jd) = rhold (jd) +
     +							r1 * rn
				    END IF
				END DO
			    ELSE 
				iret = -3
				RETURN
			    END IF
			END IF
		    END DO
		    IF ( icnt .eq. kounts (itrc,ipnt) ) THEN
			ndat = ndat + 1
			DO jd = 1, ndepth (itrc)
			    dtrace (itrc,jd,iswap) =
     +						dtrace (itrc,jd,ndat)
			    dtrace (itrc,jd,ndat) = rhold (jd)
			END DO
			conchk (itrc,iswap) = conchk (itrc,ndat)
			conchk (itrc,ndat) = dtmsv
			kpoint (itrc,iswap) = kpoint (itrc,ndat)
			kpoint (itrc,ndat) = ipnt
C
C*			Set counts and labels for this point.
C
			kounts (itrc,ndat) = icnt
			ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
			rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		    ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
			binmty (itrc,ipnt) = .true.
		    ELSE
			iret = -49
			RETURN
		    END IF
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -40
C*
	RETURN
	END
