	SUBROUTINE SRCH_CMS ( nt, itrcs, iret )
C************************************************************************
C* SRCH_CMS								*
C*									*
C* This subroutine combines multiple trace data at point locations at	*
C* which the data count is the same throughout all traces.		*
C* 									*
C*									*
C* SRCH_CMS ( NT, ITRCS, IRET )						*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +2 = a trace has zero points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-41 = all traces have 0 points	*
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*)
C*
	INTEGER		ipcnt (MXTRCS)
	REAL*8		rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
	LOGICAL		ok, found
C*-----------------------------------------------------------------------
	iret = 0
C
C*	Find the most frequent count throughout all of the traces.
C*	The count must be the same in all traces.
C
	ntotl = 0
	mstfq = 0
	icmax = 0
	nleft = 0
	DO it = 1, nt
	    nleft = nleft + ndatap (itrcs(it))
	END DO
	ipmax = nleft
	istrt = 0
	ip = 0
	it = 1
	DO WHILE ( icmax .lt. nleft .and. it .eq. 1 )
	    istrt = istrt + 1
	    ip = ip + 1
	    IF ( ip .gt. ndatap (itrcs (it)) ) THEN
		ip = 1
		it = it + 1
	    END IF
	    inum = 0
	    IF ( kounts (itrcs(it),ip) .ne. mstfq ) THEN
		DO iq = 1, nt
		    ipcnt (iq) = 0
		END DO
		jstrt = istrt
		ip2 = ip
		it2 = it
		DO WHILE ( jstrt .lt. ipmax )
		    jstrt = jstrt + 1
		    ip2 = ip2 + 1
		    IF ( ip2 .gt. ndatap (itrcs(it2)) ) THEN
			ip2 = 1
			it2 = it2 + 1
		    END IF
		    IF ( kounts (itrcs(it2),ip2) .eq.
     +			 kounts (itrcs(it),ip) )
     +		    THEN
			inum = inum + 1
			ipcnt (it2) = ipcnt (it2) + 1
		    END IF
		END DO
		ok = .true.
		iq = 0
		DO WHILE ( iq .lt. nt .and. ok )
		    iq = iq + 1
		    ok = ( ipcnt (iq) .gt. 0 )
		END DO
		IF ( inum .gt. icmax .and. ok ) THEN
		    icmax = inum
		    mstfq = kounts (itrcs(it),ip)
		    nleft = ipmax - icmax
		END IF
	    END IF
	END DO
C
C*	Go through all the traces, stop at all points with a data
C*	count equal to MSTFQ in all traces and set KPOINT to negative.
C
	DO jt = 1, nt
	    it = itrcs (jt)
	    DO ip = 1, ndatap (it)
C
C*		Find this point on all other traces.
C
		ok = ( kounts (it,ip) .eq. mstfq )
		jot = 0
		DO WHILE ( jot .lt. nt .and. ok )
		    jot = jot + 1
		    iot = itrcs (jot)
		    IF ( iot .ne. it ) THEN
			found = .false.
			iop = 0
			DO WHILE ( iop .lt. ndatap (iot) .and.
     +				   .not. found )
			    iop = iop + 1
			    IF ( ctrcid (iot,iop) .eq. ctrcid (it,ip)
     +						 .and.
     +				 rtrcid (iot,iop) .eq. rtrcid (it,ip)
     +				) THEN
				    found = .true.
				    ok = ( kounts (iot,iop) .eq.
     +					   kounts (it,ip) )
			    END IF
			END DO
		    END IF
		END DO
C*
		IF ( ok ) THEN
		    DO i = 1, nxtelm (it)
			IF ( kpoint (it,i) .eq. ip ) THEN
			    kpoint (it,i) = - kpoint (it,i)
			END IF
		    END DO
		END IF
	    END DO
	END DO
C
C*	Now combine data for all points where KPOINT is negative.
C
	DO it = 1, nt
	    itrc = itrcs (it)
	    ndat = 0
	    iaccp = 0
	    DO ipnt = 1, ndatap (itrc)
		DO jd = 1, ndepth (itrc)
		    rhold (jd) = 0.0
		END DO
		in = 0
		icnt = 0
		DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			   icnt .lt. kounts (itrc,ipnt) )
		    in = in + 1
		    IF ( kpoint (itrc,in) .eq. -ipnt ) THEN
			iaccp = iaccp + 1
			iswap = in
			dtmsv = conchk (itrc,in)
			icnt = icnt + 1
			IF ( kdvcmb (itrc) .eq. 0 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
			    DO jd = 1, ndepth (itrc)
				IF ( jd .eq. indxdc (itrc) ) THEN
				    rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				ELSE
				    r1 = dtrace (itrc,indxdc(itrc),in)
				    rn = dtrace (itrc,jd,in)
				    rhold (jd) = rhold (jd) + r1 * rn
				END IF
			    END DO
			ELSE 
			    iret = -3
			    RETURN
			END IF
		    END IF
		END DO
		IF ( icnt .gt. 0 ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,iswap) = dtrace (itrc,jd,ndat)
			dtrace (itrc,jd,ndat) = rhold (jd)
		    END DO
		    conchk (itrc,iswap) = conchk (itrc,ndat)
		    conchk (itrc,ndat) = dtmsv
		    kpoint (itrc,iswap) = kpoint (itrc,ndat)
		    kpoint (itrc,ndat) = ipnt
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = icnt
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -41
C*
	RETURN
	END
