	SUBROUTINE SRCH_DMS ( nt, itrcs, mfq, mstrt, iret )
C************************************************************************
C* SRCH_DMS								*
C*									*
C* This subroutine combines multiple trace data at point locations at	*
C* which the data count is the same for all traces and the date/times	*
C* of verification exactly match at all points for all traces.		*
C* 									*
C*									*
C* SRCH_DMS ( NT, ITRCS, MFQ, MSTRT, IRET )				*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*	MFQ (MXTRCS)	INTEGER		Most frequent count values	*
C*	MSTRT (MXTRCS)  INTEGER		Index of 1st pt with MFQ values *
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +3 = uncombined data IO failed	*
C*					 +2 = a trace has zero points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-39 = traces have 0 points	*
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/98	Add CALL SRCH_TM2			*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C* K. Brill/HPC         02/12   Write out uncombined data		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*), mfq (*), mstrt (*)
C*
	REAL*8		rhld (MXDPTH), rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	ntotl = 0
C
C*	Find the least most frequent count.  The trace with it becomes
C*	the master trace.
C
	lstfq = 2 * MAXNXT
	DO it = 1, nt
	    itrc = itrcs (it)
	    IF ( mfq (itrc) .lt. lstfq ) THEN
		lstfq = mfq (itrc)
		mastr = itrc
	    END IF
	END DO
C
C*	Go through the master trace, stop at all points with a data
C*	count equal to LSTFQ.  Loop over all other trace points,
C*	checking to see if the verifications times all occur at the
C*	same frequency as at the test point in the master trace.
C*	Count the number of points obtained for each test point.
C*	The template point is the test point with the largest count.
C
	mxfnd = 0
	DO mtp = mstrt (mastr), ndatap (mastr)
	    IF ( kounts (mastr,mtp) .eq. lstfq ) THEN
		lfnd = 0
		DO jt = 1, nt
		    it = itrcs (jt)
		    DO iop = 1, ndatap (it)
			IF ( it .ne. mastr .or. iop .ne. mtp ) THEN
			    ok = .true.
			    inxm = 0
			    DO WHILE ( inxm .lt. nxtelm (mastr) .and.
     +					ok )
				inxm = inxm + 1
				IF ( kpoint (mastr,inxm) .eq. mtp ) THEN
				    dtmsv = conchk (mastr, inxm)
				    kpoint (mastr,inxm) =
     +						-kpoint (mastr,inxm)
				    icnt = 1
				    inxm2 = inxm
				    DO WHILE
     +					( inxm2 .lt. nxtelm (mastr) )
					inxm2 = inxm2 + 1
					IF (
     +					  kpoint (mastr,inxm2) .eq. mtp
     +						.and.
     +					  conchk (mastr,inxm2) .eq.
     +					  dtmsv ) THEN
					    icnt = icnt + 1
					    kpoint (mastr,inxm2) =
     +						-kpoint (mastr,inxm2)
					END IF
				    END DO
				    jcnt = 0
				    DO inxs = 1, nxtelm (it)
					IF ( kpoint (it,inxs) .eq. iop
     +					 .and.
     +					 conchk (it,inxs) .eq. dtmsv )
     +					THEN
					    jcnt = jcnt + 1
					END IF
				    END DO
				    ok = jcnt .eq. icnt
				END IF
			    END DO
			    IF ( ok ) lfnd = lfnd + 1
			END IF
		    END DO
		END DO
		IF ( lfnd .gt. mxfnd ) THEN
		    mxfnd = lfnd
		    mpoin = mtp
		END IF
C
C*		Rest KPOINT flag values.
C
		DO inxm = 1, nxtelm (mastr)
		    IF ( kpoint (mastr,inxm) .lt. 0 )
     +			 kpoint (mastr,inxm) =
     +				    -kpoint (mastr,inxm)
		END DO
	    END IF
	END DO
C
C*	Set negative flag at MPOIN.
C
	DO inxm = 1, nxtelm (mastr)
	    IF ( kpoint (mastr,inxm) .eq. mpoin ) THEN
		kpoint (mastr,inxm) = -kpoint (mastr,inxm)
	    END IF
	END DO
C
C*	Now set KPOINT values negative at all combination points.
C
	mtp = mpoin
	DO jt = 1, nt
	    it = itrcs (jt)
	    DO iop = 1, ndatap (it)
		IF ( it .ne. mastr .or. iop .ne. mtp ) THEN
		    ok = .true.
		    inxm = 0
		    DO WHILE ( inxm .lt. nxtelm (mastr) .and. ok )
			inxm = inxm + 1
			IF ( kpoint (mastr,inxm) .eq. -mtp ) THEN
			    dtmsv = conchk (mastr,inxm)
			    kpoint (mastr,inxm) = -kpoint (mastr,inxm)
			    icnt = 1
			    inxm2 = inxm
			    DO WHILE ( inxm2 .lt. nxtelm (mastr) )
				inxm2 = inxm2 + 1
				IF ( kpoint (mastr,inxm2) .eq. -mtp
     +						.and.
     +				     conchk (mastr,inxm2) .eq. dtmsv )
     +				THEN
				    icnt = icnt + 1
				    kpoint (mastr,inxm2) =
     +						-kpoint (mastr,inxm2)
				END IF
			    END DO
			    jcnt = 0
			    DO inxs = 1, nxtelm (it)
				IF ( kpoint (it,inxs) .eq. iop
     +					 .and.
     +				     conchk (it,inxs) .eq. dtmsv ) THEN
				    jcnt = jcnt + 1
				END IF
			    END DO
			    ok = jcnt .eq. icnt
			END IF
		    END DO
		    IF ( ok ) THEN
			DO inxm = 1, nxtelm (mastr)
			    IF ( kpoint (mastr,inxm) .eq. mtp ) THEN
				dtmsv = conchk (mastr,inxm)
				kpoint (mastr,inxm) =
     +					-kpoint (mastr,inxm)
				inxm2 = inxm
				DO WHILE ( inxm2 .lt. nxtelm (mastr) )
				    inxm2 = inxm2 + 1
				    IF ( kpoint (mastr,inxm) .eq. mtp
     +						.and.
     +				       conchk (mastr,inxm2) .eq. dtmsv
     +				    ) THEN
					kpoint (mastr,inxm2) =
     +						-kpoint (mastr,inxm2)
				    END IF
				END DO
				DO inxs = 1, nxtelm (it)
				    IF ( kpoint (it,inxs).eq. iop
     +						.and.
     +					 conchk (it,inxs) .eq. dtmsv )
     +				    THEN
					kpoint (it,inxs) =
     +						-kpoint (it,inxs)
				    END IF
				END DO
			    END IF
			END DO
		    ELSE
C
C*		 	Set any positive KPOINT values at the master
C*			trace template point back to negative.
C
			DO inxm = 1, nxtelm (mastr)
			    IF ( kpoint (mastr,inxm) .eq. mtp )
     +			    kpoint (mastr,inxm) = - kpoint (mastr,inxm)
			END DO
		    END IF
		END IF
	    END DO
	END DO
C
C*	Now combine data for all points where KPOINT is negative.
C
	DO it = 1, nt
	    iaccp = 0
	    ndat = 0
	    itrc = itrcs (it)
	    DO ipnt = 1, ndatap (itrc)
		DO jd = 1, ndepth (itrc)
		    rhold (jd) = 0.0
		END DO
		in = 0
		icnt = 0
		DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			   icnt .lt. kounts (itrc,ipnt) )
		    in = in + 1
		    IF ( kpoint (itrc,in) .eq. -ipnt ) THEN
			iaccp = iaccp + 1
			iswap = in
			dtmsv = conchk (itrc,in)
			icnt = icnt + 1
			IF ( kdvcmb (itrc) .eq. 0 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = dtrace (itrc,jd,in)
				rhld (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
				rhld (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
			    DO jd = 1, ndepth (itrc)
				IF ( jd .eq. indxdc (itrc) ) THEN
				    rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				    rhld (jd) = dtrace (itrc,jd,in)
				ELSE
				    r1 = dtrace (itrc,indxdc(itrc),in)
				    rn = dtrace (itrc,jd,in)
				    rhold (jd) = rhold (jd) + r1 * rn
				    rhld (jd) = r1 * rn
				END IF
			    END DO
			ELSE 
			    iret = -3
			    RETURN
			END IF
			IF ( iret .eq. 0 .and. okwucd ) THEN
			    WRITE (lunucd, IOSTAT = ios) idnmbr (itrc),
     +			    itrc, ipnt, (rhld(jj),jj=1,ndepth(itrc))
			    IF ( ios .ne. 0 ) iret = 3
			END IF
		    END IF
		END DO
		IF ( icnt .gt. 0 ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,iswap) = dtrace (itrc,jd,ndat)
			dtrace (itrc,jd,ndat) = rhold (jd)
		    END DO
		    conchk (itrc,iswap) = conchk (itrc,ndat)
		    conchk (itrc,ndat) = dtmsv
		    kpoint (itrc,iswap) = kpoint (itrc,ndat)
		    kpoint (itrc,ndat) = ipnt
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = icnt
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -39
	IF ( iret .ge. 0 .and. nt .gt. 1 )
     +	    CALL SRCH_TM2 ( nt, itrcs, iret )
C*
	RETURN
	END
