	SUBROUTINE SRCH_FNC ( icode, ncdip, cdat, clist, nlist,
     +			      ok, clbl, iret )
C************************************************************************
C* SRCH_FNC								*
C*									*
C* This subroutine performs a character type data check.		*
C*									*
C* NCDIP is the number of conditionally determined independent varible	*
C* points and is used to set the correct label values for checks on	*
C* independent variable conditions.  When only one independent variable	*
C* condition is being applied, the value found is that needed for a	*
C* label when range checking is in effect.  NCDIP = 0 if checking is	*
C* for a dependent variable.						*
C*									*
C* If OK is .TRUE., then this data must be accepted.			*
C*									*
C* If ICODE is 18 and the search condition string ends in /, then	*
C* anything following the slash is accepted.  This allows a wild card	*
C* search for qualifiers following the slash.  If the search condition  *
C* begins with /, then anything preceding the slash is accepted.  This  *
C* allows a wild card search for qualifiers preceding the slash.        *
C*									*
C* SRCH_FNC ( ICODE, NCDIP, CDAT, CLIST, NLIST, OK, CLBL, IRET )	*
C*									*
C* Input parameters:							*
C*	ICODE		INTEGER		Comparison condition type #	*
C*	NCDIP		INTEGER		# of conditionally determined	*
C*					points for indep variable	*
C*	CDAT		CHAR*		CHAR data value			*
C*	CLIST (NLIST)	CHAR*		CHAR values to match		*
C*	NLIST		INTEGER		Number of CHAR values		*
C*									*
C* Output parameters:							*
C*	OK		LOGICAL		Acceptance flag			*
C*	CLBL		CHAR*		CHAR label value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		10/97	Added NCDIP				*
C* K. Brill/HPC		 6/00	/ wildcard feature for equality check	*
C* K. Brill/HPC		04/11	Handle icode = 22			*
C* K. Brill/IMSG        01/16   Expand / wild card to allow acceptance  *
C*                              of anything preceding /; change hfield  *
C*                              for this special case                   *
C************************************************************************
        INCLUDE         'srch.cmn'
C*
	CHARACTER*(*)	clist (*), cdat, clbl
	LOGICAL		ok
C*
C*------------------------------------------------------------------------
	iret = 0
	IF ( icode .eq. 0 ) THEN
	    ok = .true.
	    clbl = cdat
	    RETURN
	END IF
C*
	clbl = ' '
	ok = .false.
	IF ( cdat .eq. ' ' .or. nlist .le. 0 ) RETURN
C*
	IF ( icode .eq. 10 ) THEN
	    ok = cdat .lt. clist (1)
	    clbl = cdat
	ELSE IF ( icode .eq. 11 ) THEN
	    ok = cdat .le. clist (1)
	    clbl = cdat
	ELSE IF ( icode .eq. 12 ) THEN
	    ok = cdat .gt. clist (1)
	    clbl = cdat
	ELSE IF ( icode .eq. 13 ) THEN
	    ok = cdat .ge. clist (1)
	    clbl = cdat
	ELSE IF ( icode .eq. 14 ) THEN
	    ok = cdat .gt. clist (1) .and. cdat .lt. clist (2)
	    IF ( ncdip .ne. 1 ) THEN
		clbl = clist (1)
	    ELSE
		clbl = cdat
	    END IF
	ELSE IF ( icode .eq. 15 ) THEN
	    ok = cdat .ge. clist (1) .and. cdat .le. clist (2)
	    IF ( ncdip .ne. 1 ) THEN
		clbl = clist (1)
	    ELSE
		clbl = cdat
	    END IF
	ELSE IF ( icode .eq. 16 ) THEN
	    ok = cdat .gt. clist (1) .and. cdat .le. clist (2)
	    IF ( ncdip .ne. 1 ) THEN
		clbl = clist (1)
	    ELSE
		clbl = cdat
	    END IF
	ELSE IF ( icode .eq. 17 ) THEN
	    ok = cdat .ge. clist (1) .and. cdat .lt. clist (2)
	    IF ( ncdip .ne. 1 ) THEN
		clbl = clist (1)
	    ELSE
		clbl = cdat
	    END IF
	ELSE IF ( icode .eq. 18 ) THEN
	    i = 0
	    DO WHILE ( .not. ok .and. i .lt. nlist )
		i = i + 1
                istrt = 1
		islsh = INDEX ( clist (i), '/' )
		IF ( islsh .gt. 1 ) THEN
		    CALL ST_LSTR ( clist (i), lng, ier )
		    IF ( islsh .eq. lng ) THEN
			ok = cdat (1:lng) .eq. clist (i) (1:lng)
		    ELSE
			ok = cdat .eq. clist (i)
		    END IF
                ELSE IF ( islsh .eq. 1 ) THEN
		    CALL ST_LSTR ( clist (i), lng, ier )
		    CALL ST_LSTR ( cdat, lng2, ier )
                    is2 = INDEX ( cdat, '/' )
                    ok = cdat (is2:lng2) .eq. clist (i) (1:lng)
                    istrt = 2
                    IF ( ok ) THEN
                        hfield ( ifdndx ) = clist (i) (istrt:lng)
                    END IF
		ELSE
		    ok = cdat .eq. clist (i)
		END IF
		CALL ST_LSTR ( clist (i), lng, ier )
		IF ( ok ) clbl = clist (i) (istrt:lng)
	    END DO
	ELSE IF ( icode .eq. 22 ) THEN
	    ok = cdat .eq. clist (1) .or. cdat .eq. clist (2)
	    clbl = cdat
	END IF
C*
	RETURN
	END
