	SUBROUTINE SRCH_FNR ( icode, ncdip, rdat, rlist, nlist,
     +			      ok, rlbl, iret )
C************************************************************************
C* SRCH_FNR								*
C*									*
C* This subroutine performs a real type data check.			*
C*									*
C* NCDIP is the number of conditionally determined independent varible	*
C* points and is used to set the correct label values for checks on	*
C* independent variable conditions.  When only one independent variable	*
C* condition is being applied, the value found is that needed for a	*
C* label when range checking is in effect.  NCDIP = 0 if checking is	*
C* for a dependent variable.						*
C*									*
C* If OK is .TRUE., then this data must be accepted.			*
C*									*
C* SRCH_FNR ( ICODE, NCDIP, RDAT, RLIST, NLIST, OK, RLBL, IRET )	*
C*									*
C* Input parameters:							*
C*	ICODE		INTEGER		Comparison condition type #	*
C*	NCDIP		INTEGER		# of conditionally determined	*
C*					indep. variable points		*
C*	RDAT		REAL		Real data value			*
C*	RLIST (NLIST)	REAL		Real values to match		*
C*	NLIST		INTEGER		Number of real values		*
C*									*
C* Output parameters:							*
C*	OK		LOGICAL		Acceptance flag			*
C*	RLBL		REAL		Real label value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		10/97	Added NCDIP				*
C* K. Brill/HPC		04/11	Handle icode = 21			*
C************************************************************************
	REAL		rlist (*)
	LOGICAL		ok
C*
	DATA	epsln / 1.E-6 /
C*------------------------------------------------------------------------
	iret = 0
	IF ( icode .eq. 0 ) THEN
	    ok = .true.
	    rlbl = rdat
	    RETURN
	END IF
C*
	rlbl = -1.1E31
	ok = .false.
	IF ( rdat .lt. -1.E30 .or. nlist .le. 0 ) RETURN
C*
	IF ( icode .eq. 1 ) THEN
	    ok = rdat .lt. rlist (1)
	    rlbl = rdat
	ELSE IF ( icode .eq. 2 ) THEN
	    ok = rdat .le. rlist (1)
	    rlbl = rdat
	ELSE IF ( icode .eq. 3 ) THEN
	    ok = rdat .gt. rlist (1)
	    rlbl = rdat
	ELSE IF ( icode .eq. 4 ) THEN
	    ok = rdat .ge. rlist (1)
	    rlbl = rdat
	ELSE IF ( icode .eq. 5 ) THEN
	    ok = rdat .gt. rlist (1) .and. rdat .lt. rlist (2)
	    IF ( ncdip .eq. 1 ) THEN
		rlbl = rdat
	    ELSE
		rlbl = rlist (1)
	    END IF
	ELSE IF ( icode .eq. 6 ) THEN
	    ok = rdat .ge. rlist (1) .and. rdat .le. rlist (2)
	    IF ( ncdip .eq. 1 ) THEN
		rlbl = rdat
	    ELSE
		rlbl = rlist (1)
	    END IF
	ELSE IF ( icode .eq. 7 ) THEN
	    ok = rdat .gt. rlist (1) .and. rdat .le. rlist (2)
	    IF ( ncdip .eq. 1 ) THEN
		rlbl = rdat
	    ELSE
		rlbl = rlist (1)
	    END IF
	ELSE IF ( icode .eq. 8 ) THEN
	    ok = rdat .ge. rlist (1) .and. rdat .lt. rlist (2)
	    IF ( ncdip .eq. 1 ) THEN
		rlbl = rdat
	    ELSE
		rlbl = rlist (1)
	    END IF
	ELSE IF ( icode .eq. 9 ) THEN
	    i = 0
	    DO WHILE ( .not. ok .and. i .lt. nlist )
		i = i + 1
		ok = ABS ( rlist (i) - rdat ) .lt. epsln
		IF ( ok ) rlbl = rlist (i)
	    END DO
	ELSE IF ( icode .eq. 21 ) THEN
	    ok = rdat .eq. rlist (1) .or. rdat .eq. rlist (2)
	    rlbl = rdat
	END IF
C*
	RETURN
	END
