	SUBROUTINE SRCH_SET ( itrc, kmch, kase, kpadz, kltp,
     +			      idplt, iddfld, icntyp,
     +			      ivrtyp, icmtyp, charcn, realcn, ncn,
     +			      iret )
C************************************************************************
C* SRCH_SET								*
C*									*
C* This subroutine sets a single search condition for a single trace.	*
C*									*
C* KMCH triggers consistent data combination.  KMCH has the following	*
C* meaning for non-time series searches:				*
C*									*
C*	KMCH value		Meaning					*
C*									*
C*	    0   	No consistency checking				*
C*	    1   	Data counts will be identical at corresponding	*
C*			points (inter or intra trace, accordingly)	*
C*	    2   	Verification times and counts will be identical	*
C*			at corresponding points				*
C*									*
C* When KMCH is not 0, points with the most frequently occurring data	*
C* count will constitute the trace.					*
C*									*
C* For time series searches, KMCH has the following meaning:		*
C*									*
C*	KMCH value		Meaning					*
C*									*
C*	    0 		No consistency checking				*
C*	    1		Inter and/or intra trace counts are consistent	*
C*	    2		Points not found in ALL traces are eliminated   *
C*									*
C* Traces idenitified to be on the same plot will be made consistent	*
C* in accordance with the KMCH value.  Once KMCH is set for a trace,	*
C* subsequent values of KMCH are ignored.  The value of KMCH set for	*
C* the first trace of several having the same IDPLT operates for all	*
C* of them.								*
C*									*
C* KASE specifies how the consistency checking associated with the	*
C* KMCH value is applied.  KASE has the following meaning:		*
C*									*
C*	KASE value		  Meaning				*
C*									*
C*	    0	    Automatically determined				*
C*	    1	    Intra trace consistency (varying trace to trace)	*
C*	    2	    Inter trace consistency (varying point to point)	*
C*	    3	    Total consistency (along and through the traces)	*
C*									*
C* Like KMCH, once KASE is set for a trace, subsequent values of KASE	*
C* are ignored.  The value of KASE set for the first trace of several	*
C* having the same IDPLT operates for all of them.			*
C*									*
C* KPADZ is provided to allow records with all zero FHO values to be	*
C* absent in the input VSDB data file.  These values will be padded in	*
C* if KPADZ > 0.  Padding takes place only when the independent		*
C* variable is threshold.						*
C*									*
C* KLTP is a value ranging from 0 to 99 that gives the percentage of	*
C* data loss allowed before relaxation of the data combination con-	*
C* sistency checking specified by KMCH.  For example, if KLTP = 66,	*
C* then up to 66% of data can be lost and data consistency checking	*
C* will remain in force.  If KLTP = 10, only 10% of data can be lost	*
C* with consistency checking in force---if consistency checks would	*
C* eliminate more than 10% of data the consistency requirements are	*
C* removed.  This percentage is applied to each trace.  If any one	*
C* trace fails the criterion, consistency checking is lifted.  KLTP	*
C* is used only when KASE = 0.						*
C*									*
C* Once KMCH, KASE, KPADZ, and KLTP are set for a trace, subsequent	*
C* values are ignored; only the first setting is used.			*
C*									*
C* IDPLT is an arbitrary positive integer used to mark this trace as	*
C* belonging to a particular plot.  When the data is combined, all	*
C* traces with the same value of IDPLT must have the same number and	*
C* times of contributions at corresponding points.  Once IDPLT is set	*
C* for a trace, subsequent values of IDPLT in calls to SRCH_SET for	*
C* the same trace are ignored.						*
C*									*
C* This search criterion applies to the descriptor data whose element	*
C* number in TABLE 1 below matches the value in IDDFLD.  If IDDFLD is	*
C* greater than 100, the condition applies to a data value.  During a	*
C* search, if the number of data values (including the count) exceeds	*
C* MXDPTH, then only the values for which there exists a dependent	*
C* variable condition will be stored in the array DTRACE.  The array	*
C* KINDEX in COMMON records the data indexes actually stored in DTRACE.	*
C* If the data index is 1, that is the count data field.		*
C*									*
C*			     TABLE 1.					*
C*									*
C*  Element	  Data Field Description	Data type  Desc Field 	*
C*									*
C*    1		    Version number		 CHAR		1	*
C*    2		    Model being verified	 CHAR		2	*
C*    3		    Forecast hour		 REAL		3	*
C*    4		    Forecast time window	 REAL		3	*
C*    5		    Verification YYYYMMDDHHNN	 CHAR		4	*
C*    6		    Verifying time window	 REAL		4	*
C*    7		    Time increment for data	 REAL		4	*
C*    8		    Verifying analysis		 CHAR		5	*
C*    9		    Verifying region		 CHAR		6	*
C*   10		    Statistic type identifier	 CHAR		7	*
C*   11		    Threshold for data		 REAL		7	*
C*   12		    Parameter name		 CHAR		8	*
C*   13		    Level identifier		 CHAR		9	*
C*   14		    Level value			 REAL		9	*
C*   15		    Verifying HHNN		 CHAR		5	*
C*   16             Time period for combination  CHAR           4       *
C*   17             Initial hour of forecast     REAL       3 & 4	*
C*  101		    Count value			 REAL		-	*
C*  102 + ...	    Statistic values		 REAL		-	*
C*									*
C*									*
C* The type of conditional check is determined by ICNTYP.  TABLE 2	*
C* below gives the search type associated with the possible values	*
C* for ICNTYP:								*
C*									*
C*			     TABLE 2.					*
C*									*
C*    ICNTYP			Meaning					*
C*									*
C*	0	Wild card -- no checks					*
C*	1	Real check for x <  REALCN (1,*)			*
C*	2	Real check for x <= REALCN (1,*)			*
C*	3	Real check for x >  REALCN (1,*)			*
C*	4	Real check for x >= REALCN (1,*)			*
C*	5	Real check for REALCN (1,*) <  x <  REALCN (2,*)	*
C*	6	Real check for REALCN (1,*) <= x <= REALCN (2,*)	*
C*	7	Real check for REALCN (1,*) <  x <= REALCN (2,*)	*
C*	8	Real check for REALCN (1,*) <= x <  REALCN (2,*)	*
C*	9	Real check for elements in the list REALCN (1,NCN)	*
C*     10	Char check for c <  CHARCN (1,*)			*
C*     11	Char check for c <= CHARCN (1,*)			*
C*     12	Char check for c >  CHARCN (1,*)			*
C*     13	Char check for c >= CHARCN (1,*)			*
C*     14	Char check CHARCN (1,*) <  c <  CHARCN (2,*)		*
C*     15	Char check CHARCN (1,*) <= c <= CHARCN (2,*)		*
C*     16	Char check CHARCN (1,*) <  c <= CHARCN (2,*)		*
C*     17	Char check CHARCN (1,*) <= c <  CHARCN (2,*)		*
C*     18	Char check for elements in the list CHARCN (1,NCN)	*
C*     19       Time period check for finding existing period averages	*
C*     20	Time period check for making period averages		*
C*     21       Real check for x = REALCN (1,*) OR REALCN (2,*)		*
C*     22	Char check for c = CHARCN (1,*) OR CHARCN (2,*)		*
C*									*
C*	where x is some real value, and c is some character string.	*
C*									*
C* Only independent variables can have more than one pair of comparison	*
C* values and, hence, more than one value of ICNTYP.  Dependent		*
C* variable listed values are always in position (1,i), where i ranges	*
C* from 1 to NCN, the number in the list.				*
C*									*
C* If a character type check is indicated for a data descriptor that	*
C* is type REAL in TABLE 1, then the check will be made against the	*
C* entire character header field associated with the data descriptor.	*
C* Note that verification time checking (IDDFLD = 5) is always of	*
C* type character.							*
C*									*
C* Time period checks are be specified as a string of one or more of	*
C* a set of single-character time period designators (P).  These	*
C* designators are interpreted using the values in elements 5 and 6 	*
C* of TABLE 1.  TABLE 3 below relates each single character period	*
C* designator (P) to the value in element 6 and the string value in	*
C* the indicated segment of element 5 required for a search match when  *
C* ICNTYP = 19.  If ICNTYP = 20, the date is checked for the time range	*
C* corresponding to the designator.  If it is within the time window	*
C* the data is used.							*
C*									*
C*			    TABLE 3.					*
C*									*
C*  P  Meaning  Element 6  Element 5 Segment  Element 5 Segment Value	*
C*									*
C*  D  Daily	    24		    HHNN	       1200		*
C*  M  Monthly	   730		  DDHHNN	     150000		*
C*  1  1st qrtr	  2190		MMDDHHNN	   02150000		*
C*  2  2nd qrtr   2190		MMDDHHNN	   05150000		*
C*  3  3rd qrtr	  2190		MMDDHHNN	   08150000		*
C*  4  4th qrtr   2190		MMDDHHNN	   11150000		*
C*  A  1st half	  4380		MMDDHHNN	   04010000		*
C*  B  2nd half	  4380		MMDDHHNN	   10010000		*
C*  Y  year	  8760		MMDDHHNN	   07010000		*
C*  W  winter	  2190		MMDDHHNN	   01150000		*
C*  V  spring	  2190		MMDDHHNN	   04150000		*
C*  S  summer	  2190		MMDDHHNN	   07150000		*
C*  F  fall	  2190		MMDDHHNN	   10150000		*
C*									*
C* More than one P designator may be entered, which has the effect of	*
C* a list---the condition is satisfied if any one of the P designators	*
C* is satisfied. 							*
C*									*
C* If the condition applies to control how values will be accumulated	*
C* to appear as a function of some other set of contitions, then the	*
C* condition is for a dependent variable.  If the condition discrimi-	*
C* nates among the various points along a trace, then that condition is	*
C* for the independent variable.  IVRTYP is set according to TABLE 4.	*
C*									*
C*			    TABLE 4.					*
C*									*
C*	IVRTYP				Meaning				*
C*									*
C*	  0	->	condition applies to a dependent variable	*
C*	  1	->	condition applies to an independent variable	*
C*									*
C* ICNTYP = 0 may be useful for either an independent variable or a	*
C* dependent variable.  For example, for a time series, all verifying	*
C* times may be desired with verifying time as the independent variable.*
C* In this case, ICNTYP = 0 for verifying time.  In the case of a	*
C* dependent variable, ICNTYP = 0 for conditions that are only being	*
C* used to indicate the data position.  This is particularly useful	*
C* when the search records have more than MXDPTH number of data values.	*
C*									*
C* There are different ways in which the data can be combined.  The	*
C* method of combination is specified in ICMTYP.  TABLE 5 gives the	*
C* possible values and meanings of ICMTYP:				*
C*									*
C*			    TABLE 5.					*
C*									*
C*	ICMTYP				Meaning				*
C*									*
C*	  0	->	No combination					*
C*	  1	->	Averaging by summing counts and partial sums	*
C*	  2	->	Sum data counts and the count-value products	*
C*			(i.e., values are multiplied by the count)	*
C*									*
C* Once ICMTYP is set for a trace, it cannot be changed.  Although	*
C* SRCH_SET must be called at least once, and perhaps many times more	*
C* for a given trace, the value of ICMTYP passed in the first call	*
C* is used, the rest are ignored.					*
C*									*
C* SRCH_INI should be called before beginning a new set of calls to	*
C* to SRCH_SET.  SRCH_INI erases all previous search settings.		*
C*									*
C* SRCH_SET ( ITRC, KMCH, KASE, KPADZ, KLTP, IDPLT, IDDFLD, ICNTYP,	*
C*	      IVRTYP, ICMTYP, CHARCN, REALCN, NCN, IRET )		*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Number of trace			*
C*	KMCH		INTEGER		Code for consistent combination *
C*	KASE		INTEGER		Consistency application method	*	
C*	KPADZ		INTEGER		Flag for zero padding operation *
C*	KLTP		INTEGER		Data loss tolerance percentage	*
C*	IDPLT		INTEGER		Plot identifier for this trace	*
C*	IDDFLD		INTEGER		Search data element number	*
C*	ICNTYP (NCN)	INTEGER		Type of condition		*
C*	IVRTYP		INTEGER		Type of variable 		*
C*	ICMTYP		INTEGER		Method of data combination	*
C*	CHARCN (2,NCN)	CHAR*		List/bounds for char condition	*
C*	REALCN (2,NCN)	REAL		List/bounds for real condition	*
C*	NCN		INTEGER		# in list or # of comp pairs	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = invalid hdr fld number	*
C*					 -2 = invalid var type		*
C*					 -3 = invalid combination type	*
C*					 -4 = invalid condition type	*
C*					 -5 = char list not expected	*
C*					 -6 = real list not expected	*
C*					 -7 = # ind var pts not same	*
C*					 -9 = too many items in list	*
C*					-10 = trace # is too large	*
C*					-11 = too many dep var conds	*
C*					-12 = too many indep var conds	*
C*					-13 = too many indep var points *
C*					-17 = combination type not same *
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		 9/97	Add condition types 19 and 20		*
C* K. Brill/EMC		10/97	Add field 15 (HHNN, documentation only) *
C* K. Brill/EMC		10/97	Set IFDLST to IFDMAP values		*
C* K. Brill/EMC		11/97	Changes for post-search data combination*
C* K. Brill/EMC		 3/98	Changes KMCH				*
C* K. Brill/EMC		 4/98	CALL SRCH_CHX				*
C* K. Brill/EMC		10/98	Added KLTP input			*
C* K. Brill/EMC		 1/99	Added KASE input; seperate KMCH & KPADZ *
C* K. Brill/HPC		 1/00	Set CATBIN for categorical bins		*
C* K. Brill/HPC		 8/00	Set KDVCHK & KDVNCK for con checks	*
C* K. Brill/HPC		10/02	CALL SRCH_LBL ( )			*
C* K. Brill/HPC         04/11	Add condition type 21 and 22		*
C* K. Brill/HPC         04/11   Add element 17 to Table 1 (doc block)	*
C* K. Brill/IMSG        09/17   Set the setc17 flag                     *
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	CHARACTER*(*)	charcn (2,*)
	REAL		realcn (2,*)
	INTEGER		icntyp (*)
C*
C*------------------------------------------------------------------------
	iret = 0
C
C*	Screen the conditions for gross validity.
C
	DO i = 1, ncn
	    CALL SRCH_TCN ( icntyp (i), iddfld, iret )
	    IF ( iret .ne. 0 ) THEN
		CALL SRCH_ERR ( iret, ' ', iii )
		RETURN
	    END IF
	END DO
C
C*	Do preliminary error checking.
C
	IF ( iddfld .le. 0 .or. ( iddfld .gt. MXDFDS .and.
     +	     iddfld .lt. 100) ) THEN
	    iret = -1
	    RETURN
	END IF
	IF ( ivrtyp .lt. 0 .or. ivrtyp .gt. 1 ) THEN
	    iret = -2
	    RETURN
	END IF
	IF ( icmtyp .lt. 0 .or. icmtyp .gt. 2 ) THEN
	    iret = -3
	    RETURN
	END IF
	IF( itrc .gt. MXTRCS ) THEN
	    iret = -10
	    RETURN
	END IF
	IF ( icntyp (1) .lt. 0 .or. icntyp (1) .gt. 22 ) THEN
	    iret = -4
	    RETURN
	END IF
C
C*	Set the plot ID for this trace.
C
	IF ( idnmbr (itrc) .le. 0 ) THEN
	    IF ( idplt .le. 0 ) THEN
		iret = -34
		RETURN
	    END IF
	    idnmbr (itrc) = idplt
C
C*	    Check for valid consistency check code.
C*	    Set flag for consistent data combination.
C
	    IF ( kmatch (itrc) .lt. 0 ) THEN
		IF ( kmch .lt. 0 .or. kmch .gt. 2 ) THEN
		    iret = -44
		    CALL SRCH_ERR ( iret,
     +		    		    'Value must be 0, 1, or 2', iier )
		    RETURN
		END IF
		kmatch (itrc) = kmch
		IF ( kltp .gt. 99 ) THEN
		    kprcnt (itrc) = 99
		ELSE IF ( kltp .lt. 0 ) THEN
		    kprcnt (itrc) = 0
		ELSE
		    kprcnt (itrc) = kltp
		END IF
		IF ( kase .gt. 3 .or. kase .lt. 0 ) THEN
		    kmcase (itrc) = 0
		ELSE
		    kmcase (itrc) = kase
		END IF
		padzro (itrc) = ( kpadz .gt. 0 )
	    END IF
	END IF
C
C*	Set the code for the method of combining data for the trace
C*	if it is not already set.
C
	IF ( kdvcmb (itrc) .lt. 0 ) THEN
	    kdvcmb (itrc) = icmtyp
	END IF
C
C*	Check for dependent versus independent variable.
C
	IF ( ivrtyp .eq. 0 ) THEN
	    nls = ncn
C
C*	    Set the ID field for use in consistency checks.
C
	    IF ( iddfld .gt. 0 .and. iddfld .le. MXDFDS ) THEN
		idf = ifdmap (iddfld)
                IF ( iddfld .eq. 17 ) THEN
                    setc17 (itrc) = .true.
                END IF
C
C*		Valid time is always included in checking.
C
		IF ( idf .eq. 4 ) idf = 0
	    ELSE
		idf = 0
	    END IF
C
C*	    Set up for dependent variable.
C
	    idvcn = kdvncn (itrc) + 1
	    IF ( idvcn .gt. MXDVCN ) THEN
		iret = -11
		RETURN
	    END IF
	    IF ( ncn .gt. MXDVLS ) THEN
		iret = -9
		RETURN
	    END IF
C*
	    IF ( icntyp (1) .eq. 0 ) THEN
C
C*		Wild carded field -- include in consistency check.
C
		IF ( idf .ne. 0 ) THEN
		    kdvnck ( itrc ) = kdvnck ( itrc ) + 1
		    kdvchk ( itrc, kdvnck (itrc) ) = idf
		END IF
C
C*		Otherwise, do nothing.
C
	    ELSE IF ( icntyp (1) .gt. 9 .and.
     +		      icntyp (1) .ne. 21 ) THEN
C
C*		Character comparison is indicated.
C
		IF ( ncn .gt. 1 .and. icntyp (1) .ne. 18 ) THEN
		    iret = -5
		    RETURN
		END IF
		cdvcnd ( itrc, idvcn, 1 ) = charcn (1,1)
		IF ( ( icntyp (1) .ge. 14 .and. icntyp (1) .le. 17 )
     +		  .or. icntyp (1) .eq. 22 ) THEN
		    cdvcnd ( itrc, idvcn, 2 ) = charcn (2,1)
		    nls = 2
		END IF
		IF ( icntyp (1) .eq. 18 .and. ncn .gt. 1 ) THEN
		    DO i = 2, ncn
			cdvcnd ( itrc, idvcn, i ) = charcn (1,i)
		    END DO
		    CALL SRCH_CHX ( itrc, iddfld, charcn, ncn, ier )
C
C*		    Multiple listed field requires consistency check.
C
		    IF ( idf .ne. 0 ) THEN
			kdvnck ( itrc ) = kdvnck ( itrc ) + 1
			kdvchk ( itrc, kdvnck (itrc) ) = idf
		    END IF
		ELSE IF ( icntyp (1) .eq. 18 ) THEN
		    CALL SRCH_CHX ( itrc, iddfld, charcn, 1, ier )
		END IF
	    ELSE
C
C*		Real comparison is indicated.
C
		IF ( ncn .gt. 1 .and. icntyp (1) .ne. 9 ) THEN
		    iret = -6
		    RETURN
		END IF
		rdvcnd ( itrc, idvcn, 1 ) = realcn (1,1)
		IF ( ( icntyp (1) .ge. 5 .and. icntyp (1) .le. 8 )
     + 		  .or. icntyp (1) .eq. 21 ) THEN
		    rdvcnd ( itrc, idvcn, 2 ) = realcn (2,1)
		    nls = 2
		END IF
		IF ( icntyp (1) .eq. 9 .and. ncn .gt. 1 ) THEN
		    DO i = 2, ncn
			rdvcnd ( itrc, idvcn, i ) = realcn (1,i)
		    END DO
C
C*		    Multiple listed field requires consistency check.
C
		    IF ( idf .ne. 0 ) THEN
			kdvnck ( itrc ) = kdvnck ( itrc ) + 1
			kdvchk ( itrc, kdvnck (itrc) ) = idf
		    END IF
		END IF
	    END IF
	    kdvcod (itrc, idvcn) = icntyp (1)
	    kdvfld (itrc, idvcn) = iddfld
	    kdvnls (itrc, idvcn) = nls
	    kdvncn (itrc) = idvcn
C*
	ELSE IF ( ivrtyp .eq. 1 ) THEN
C
C*	    Set up for independent variable.
C
	    jivcn = kivncn (itrc) + 1
	    IF ( jivcn .gt. MXIVCN ) THEN
		iret = -12
		RETURN
	    END IF
	    IF ( ncn .gt. MXIVPT ) THEN
		iret = -13
		RETURN
	    END IF
	    IF ( jivcn .gt. 1 .and. ncn .ne. kivnpt (itrc) ) THEN
		iret = -7
		RETURN
	    END IF
	    icnt18 = 0
	    DO ipt = 1, ncn
		IF ( icntyp (ipt) .lt. 0 .or. icntyp (ipt) .gt. 22 )
     +		THEN
		    iret = -4
		    RETURN
		END IF
		IF ( icntyp (ipt) .eq. 0 ) THEN
C
C*		    Do nothing.
C
		ELSE IF ( icntyp (ipt) .ge. 10 ) THEN
		    civcnd ( itrc, jivcn, ipt, 1 ) = charcn (1,ipt)
		    IF ( ( icntyp (ipt) .ge. 14 .and.
     +			 icntyp (ipt) .le. 17 ) .or.
     +			 icntyp (ipt) .eq. 22 )
     +		      civcnd ( itrc, jivcn, ipt, 2 ) = charcn (2,ipt)
		ELSE
		    rivcnd ( itrc, jivcn, ipt, 1 ) = realcn (1,ipt)
		    IF ( ( icntyp (ipt) .ge. 5 .and.
     +			 icntyp (ipt) .le. 8 ) .or.
     +			 icntyp (ipt) .eq. 21 )
     +		      rivcnd ( itrc, jivcn, ipt, 2 ) = realcn (2,ipt)
		END IF
		kivcod ( itrc, jivcn, ipt ) = icntyp ( ipt )
		IF ( icntyp (ipt) .eq. 18 ) THEN
		    icnt18 = icnt18 + 1
		END IF
		CALL SRCH_LBL ( itrc, jivcn, ipt, iret )
	    END DO
	    IF ( ncn .eq. icnt18 ) THEN
	        CALL SRCH_CHX ( itrc, iddfld, charcn, ncn, ier )
	    END IF
	    kivfld ( itrc, jivcn ) = iddfld
	    kivncn ( itrc ) = jivcn
	    kivnpt ( itrc ) = ncn
	    catbin ( itrc ) = ( ncn .gt. 1 )
	END IF
	ntrace = MAX ( itrc, ntrace )
C*
	RETURN
	END
