	SUBROUTINE SRCH_SRT ( itrc, mxpts, ksrti, srtyp, iret )
C************************************************************************
C* SRCH_SRT								*
C*									*
C* This subroutine builds a sorting index array based on CTRCID or	*
C* RTRCID in COMMON.  The sorting is done on trace number ITRC.		*
C*									*
C* The sort is done from the lowest value of CTRCID or RTRCID to the	*
C* highest.  SRTYP returns the type of search.  If SRTYP is c on	*
C* return, then CTRCID was used in the sort.  If SORTYP is r, then	*
C* RTRCID was used in the sort.						*
C*									*
C* If no sorting is necessary, SRTYP is n and the elements of KSRTI are	*
C* just the index values along the trace in order (i.e., KSRTI (1) = 1,	*
C* KSRTI (2) = 2, etc.).						*
C*									*
C*									*
C* SRCH_SRT ( ITRC, MXPTS, KSRTI, SRTYP, IRET )				*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number for this data	*
C*									*
C* Input and output parameters:						*
C*	MXPTS		INTEGER		Max # of points along trace	*
C*									*
C* Output parameters:							*
C*	KSRTI (MXPTS)	INTEGER		Sorted indexes into DTRACE	*
C*	SRTYP		CHAR*1		Type of sort:			*
C*					  c = character			*
C*					  r = real			*
C*					  n = no sort			*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-30 = MXPTS is too small	*
C*					-32 = search lbls are invalid	*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		ksrti (*)
	CHARACTER*1	srtyp
C*
C*------------------------------------------------------------------------
	iret = 0
	srtyp = ' '
C*
	ndp = ndatap ( itrc )
	IF ( ndp .gt. mxpts ) THEN
	    iret = -30
	    RETURN
	ELSE
	    mxpts = ndp
	END IF
C
C*	Initialize index array to current indexes.
C
	DO i = 1, mxpts
	    ksrti (i) = i
	END DO
C
C*	No sort if search conditions determine trace points.
C
	IF ( kivnpt ( itrc ) .ne. 1 ) THEN
	    srtyp = 'n'
	    RETURN
	END IF
C
C*	Sort is necessary.
C
	IF ( ctrcid (itrc,1) .eq. ' ' .and.
     +	     rtrcid (itrc,1) .gt. -1.E30 ) THEN
	    srtyp = 'r'
	    i = 1
	    DO WHILE ( i .lt. mxpts )
		j = 1
		DO WHILE ( j .le. ( mxpts - i ) )
		    IF ( rtrcid ( itrc, ksrti (j) ) .gt.
     +                   rtrcid ( itrc, ksrti (j+1) ) ) THEN
			ksave = ksrti (j)
			ksrti (j) = ksrti (j+1)
			ksrti (j+1) = ksave
		    END IF
		    j = j + 1
		END DO
		i = i + 1
	    END DO
	ELSE IF ( rtrcid (itrc,1) .lt. -1.E30 .and.
     +	     ctrcid (itrc,1) .ne. ' ' ) THEN
	    srtyp = 'c'
	    i = 1
	    DO WHILE ( i .lt. mxpts )
		j = 1
		DO WHILE ( j .le. ( mxpts - i ) )
		    IF ( ctrcid ( itrc, ksrti (j) ) .gt.
     +                   ctrcid ( itrc, ksrti (j+1) ) ) THEN
			ksave = ksrti (j)
			ksrti (j) = ksrti (j+1)
			ksrti (j+1) = ksave
		    END IF
		    j = j + 1
		END DO
		i = i + 1
	    END DO
	ELSE
	    iret = -32
	    RETURN
	END IF
C*
	RETURN
	END
