	SUBROUTINE SRCH_TM2 ( nt, itrcs, iret )
C************************************************************************
C* SRCH_TM2								*
C*									*
C* This subroutine limits multiple trace data to points	found in all	*
C* traces.								*
C*									*
C* NOTE:  The data must already be combined before this is called.	*
C*									*
C* SRCH_TM2 ( NT, ITRCS, IRET )						*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +2 = a trace has 0 points	*
C*				 	  0 = normal return 		*
C*					-51 = all traces have 0 points	*
C**									*
C* Log:									*
C* K. Brill/EMC		 4/98						*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*)
C*
	INTEGER		jpnt ( MXTRCS )
	LOGICAL		ok, found
C*-----------------------------------------------------------------------
	iret = 0
	mflag = - ( 2 * MAXNXT )
	ntotl = 0
C
C*	Find the trace with the least number of points.
C
	lstnu = 2 * MXDPTS
	DO it = 1, nt
	    itrc = itrcs (it)
	    IF ( ndatap (itrc) .lt. lstnu ) THEN
		lstnu = ndatap (itrc)
		mastr = itrc
	    END IF
	END DO
C
C*	Go through the master trace point by point.  Search for the
C*	same point in all the other traces.  If that point is found
C*	in all other traces, set the KPOINT values to a flag value.
C
	DO mtp = 1, ndatap (mastr)
	    ok = .true.
	    jt = 0
	    DO WHILE ( ok .and. jt .lt. nt )
		jt = jt + 1
		it = itrcs (jt)
		IF ( it .ne. mastr ) THEN
		    found = .false.
		    ip = 0
		    DO WHILE ( ip .lt. ndatap (it) .and. .not. found )
			ip = ip + 1
			found = (
     +			    ctrcid (it,ip) .eq. ctrcid (mastr,mtp)
     +					   .and.
     +			    rtrcid (it,ip) .eq. rtrcid (mastr,mtp) )
		    END DO
		    ok = found
		    jpnt (jt) = ip
		ELSE
		    jpnt (jt) = mtp
		END IF
	    END DO
	    IF ( ok )  THEN
		DO jt = 1, nt
		    kpoint (itrcs (jt),jpnt(jt)) = mflag
		END DO
	    END IF
	END DO
C
C*	Now collect data for all points where KPOINT is flagged.
C
	DO it = 1, nt
	    itrc = itrcs (it)
	    irjct = 0
	    ndat = 0
	    DO ipnt = 1, ndatap (itrc)
		IF ( kpoint (itrc,ipnt) .eq. mflag ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,ndat) = dtrace (itrc,jd,ipnt)
		    END DO
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = kounts (itrc,ipnt)
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		    irjct = irjct + kounts (itrc,ipnt)
		ELSE
		    irjct = irjct + kounts (itrc,ipnt)
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    krejct (itrc) = krejct (itrc) + irjct
	END DO
	IF ( ntotl .eq. 0 ) iret = -51
C*
	RETURN
	END
