	SUBROUTINE STX_MODE ( icmp, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* STX_MODE								*
C*									*
C* This subroutine computes several diagnostic parameters for the MODE  *
C* spatial technique (ST) statistic type records.			*
C*									*
C*									*
C* STX_MODE ( ICMP, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE,		*
C*	      RMISS, TRCDAT, TRCMIN, TRCMAX, IRET )			*
C*									*
C* Input parameters:							*
C*	ICMP		INTEGER		Computation flag:		*
C*					  1 = Intensity bias		*
C*					  2 = Area bias			*
C*					  3 = Obs->frcst compass drctn  *
C*					  4 = POD for objects		*
C*					  5 = Threat score for objects  *
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = Computation not possible	*
C**									*
C* Log:									*
C* K. Brill/HPC	     20080623						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		rn
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	IF ( ndpth .gt. 17 ) THEN
	    iret = -1
	    RETURN
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    IF ( dtrace (itrc,1,ip) .gt. -1.E30 ) THEN
		rn = dtrace (itrc,1,ip)
	        IF ( icmp .eq. 1 ) THEN
		    ok = ( dtrace (itrc,10,ip) .gt. -1.E30 )
		    ok = ( ok .and. dtrace (itrc,11,ip) .gt. -1.E30 )
		    IF ( ok .and. rn .gt. 0.0 ) THEN
			trcdat (ip) = ( dtrace (itrc,10,ip) -
     +				      dtrace (itrc,11,ip) ) / rn
			IF ( trcdat (ip) .lt. trcmin ) THEN
			    trcmin = trcdat (ip)
			END IF
			IF ( trcdat (ip) .gt. trcmax ) THEN
			    trcmax = trcdat (ip)
			END IF
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END IF
	        IF ( icmp .eq. 2 ) THEN
		    ok = ( dtrace (itrc,12,ip) .gt. -1.E30 )
		    ok = ( ok .and. dtrace (itrc,13,ip) .gt. 0.0 )
		    IF ( ok ) THEN
			trcdat (ip) = ( dtrace (itrc,12,ip) /
     +				      dtrace (itrc,13,ip) )
			IF ( trcdat (ip) .lt. trcmin ) THEN
			    trcmin = trcdat (ip)
			END IF
			IF ( trcdat (ip) .gt. trcmax ) THEN
			    trcmax = trcdat (ip)
			END IF
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END IF
	        IF ( icmp .eq. 3 ) THEN
		    ok = ( dtrace (itrc,8,ip) .gt. -1.E30 )
		    ok = ( ok .and. dtrace (itrc,9,ip) .gt. -1.E30 )
		    IF ( ok .and. rn .gt. 0.0 ) THEN
			ru = dtrace (itrc,8,ip) / rn
			rv = dtrace (itrc,9,ip) / rn
			ang = ATAN2 ( ru, rv ) * 57.29578
			IF ( ang .lt. 0.0 ) THEN
			    ang = ang + 360.
		        END IF
			trcdat (ip) = ang
			IF ( trcdat (ip) .lt. trcmin ) THEN
			    trcmin = trcdat (ip)
			END IF
			IF ( trcdat (ip) .gt. trcmax ) THEN
			    trcmax = trcdat (ip)
			END IF
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END IF
	        IF ( icmp .eq. 4 ) THEN
		    ok = ( dtrace (itrc,15,ip) .gt. -1.E30 )
		    ok = ( ok .and. dtrace (itrc,13,ip) .gt. 0.0 )
		    IF ( ok ) THEN
			trcdat (ip) = ( dtrace (itrc,15,ip) /
     +				      dtrace (itrc,13,ip) )
			IF ( trcdat (ip) .lt. trcmin ) THEN
			    trcmin = trcdat (ip)
			END IF
			IF ( trcdat (ip) .gt. trcmax ) THEN
			    trcmax = trcdat (ip)
			END IF
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END IF
	        IF ( icmp .eq. 5 ) THEN
		    ok = ( dtrace (itrc,15,ip) .gt. -1.E30 )
		    ok = ( ok .and. dtrace (itrc,16,ip) .gt. 0.0 )
		    IF ( ok ) THEN
			trcdat (ip) = ( dtrace (itrc,15,ip) /
     +				      dtrace (itrc,16,ip) )
			IF ( trcdat (ip) .lt. trcmin ) THEN
			    trcmin = trcdat (ip)
			END IF
			IF ( trcdat (ip) .gt. trcmax ) THEN
			    trcmax = trcdat (ip)
			END IF
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
C*
	END DO
C*
	RETURN
	END
