	SUBROUTINE USR_FLNM ( lunctl, lunfls, lunmdl, day1, today,
     +			      nfiles, nmdls, iret )
C************************************************************************
C* USR_FLNM								*
C*									*
C* This subroutine writes the names of all of the VSDB files required	*
C* by a set of search conditions as defined in a search control file.	*
C* It can also writes the names of the models (directory names).	*
C*									*
C* The control file is assumed to be open and connected to unit LUNCTL.	*
C*									*
C* The file list is written to LUNFLS, which is assumed to be connected	*
C* to an open file.  NFILES is the number of file names written.	*
C*									*
C* The list of model names is returned in the output file assumed open	*
C* and connected to unit LUNMDL.  If LUNMDL = 0, no output is done.	*
C*									*
C* USR_FLNM ( LUNCTL, LUNFLS, LUNMDL, DAY1, TODAY, NFILES, NMDLS, IRET )*
C*									*
C* Input parameters:							*
C*	LUNCTL		INTEGER		Unit number of control file	*
C*	LUNFLS		INTEGER		Unit number of file list file	*
C*	LUNMDL		INTEGER		Unit number of model list file	*
C*	DAY1		CHAR*8		Earliest date in the archive	*
C*	TODAY		CHAR*8		Current YYYYMMDD		*
C*									*
C* Output parameters:							*
C*	NFILES		INTEGER		# of file names written		*
C*	NMDLS		INTEGER		# of model names written	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = invalid hdr rec		*
C*					 -2 = too few cndtn rec		*
C*					 -3 = invalid cndtn rec		*
C*					 -4 = no dates found		*
C*					 -5 = request predates archive	*
C*					 -7 = write err to file list fl	*
C*					 -8 = bad cndtn code for mdl nam*
C*					 -9 = mdl name has 0 length	*
C*					-10 = write err to mdl list fl	*
C*					-11 = no model names found	*	
C**									*
C* Log:									*
C* K. Brill/EMC		 9/97						*
C* K. Brill/EMC		 3/98	Add model names; output to files	*
C************************************************************************
	CHARACTER*(*)	day1, today
C*
	CHARACTER*80	record, recout
	CHARACTER*512	models
	CHARACTER*8	ymdbeg, ymdend
	CHARACTER*24	ccond (5), cmdl
	INTEGER		ihdr (5), idpm (12)
	LOGICAL		letter
C*------------------------------------------------------------------------
	iret = 0
	nfiles = 0
	nmdls = 0
	models = ' '
	mlng = 0
	ymdbeg = '99999999'
	ymdend = '00000000'
	idpm (1) = 31
	idpm (2) = 28
	idpm (3) = 31
	idpm (4) = 30
	idpm (5) = 31
	idpm (6) = 30
	idpm (7) = 31
	idpm (8) = 31
	idpm (9) = 30
	idpm (10) = 31
	idpm (11) = 30
	idpm (12) = 31
C
C*	Scan the control file to find the range of dates required.
C
	REWIND lunctl
	iostat = 0
	DO WHILE ( iostat .eq. 0 )
	    READ ( lunctl, '(A)', IOSTAT=iostat ) record
	    IF ( iostat .eq. 0 ) THEN
		CALL ST_ILST ( record, ' ', -99, 5, ihdr, num, ier )
		IF ( ier .lt. 0 .or. num .ne. 5 ) THEN
		    iret = -1
		    RETURN
		END IF
		iddfld = ihdr (2)
		ncn = ihdr (5)
		IF ( iddfld .eq. 2 ) THEN
		    DO icn = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			ELSE
			    CALL ST_CLST ( record, ' ', ' ', 5,
     +					   ccond, ncnd, ier )
			    IF ( ncnd .ne. 5 .or. ier .ne. 0 ) THEN
				iret = -3
				RETURN
			    END IF
			    CALL ST_NUMB ( ccond (1), icntyp, ier )
			    IF ( icntyp .ne. 18 ) THEN
				iret = -8
				RETURN
			    END IF
			    CALL ST_LSTR ( ccond (4), lng, ier )
			    iq = 0
			    letter = .true.
			    record = ' '
			    DO WHILE ( iq .lt. lng .and. letter )
				iq = iq + 1
				IF ( ( ccond (4) (iq:iq) .ge. 'A'
     +				   .and. ccond (4) (iq:iq) .le. 'Z' )
     +				   .or.
     +				     ( ccond (4) (iq:iq) .ge. '0'
     +				   .and. ccond (4) (iq:iq) .le. '9' )
     +				   ) THEN
				    record (iq:iq) = ccond (4) (iq:iq)
				ELSE
				    letter = .false.
				END IF
			    END DO
			    IF ( iq .eq. 0 ) THEN
				iret = -9
				RETURN
			    END IF
			    record = record (1:iq) // ' '
			    iq = iq + 1
			    ifnd = INDEX ( models, record (1:iq) )
			    IF ( ifnd .eq. 0 ) THEN
				IF ( mlng .eq. 0 ) THEN
				    models = record (1:iq)
				    mlng = iq
				ELSE
				    models = models (1:mlng) //
     +						record (1:iq)
				    mlng = mlng + iq + 1
				END IF
				IF ( lunmdl .gt. 0 ) THEN
				    WRITE ( lunmdl, '(A)', IOSTAT=ios )
     +					 record (1:iq)
				    IF ( ios .ne. 0 ) THEN
					iret = -10
					RETURN
				    END IF
				END IF
				nmdls = nmdls + 1
			    END IF
			END IF
		    END DO
		ELSE IF ( iddfld .eq. 5 ) THEN
		    DO iq = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			ELSE
			    CALL ST_CLST ( record, ' ', ' ', 5,
     +					   ccond, ncnd, ier )
			    IF ( ncnd .ne. 5 .or. ier .ne. 0 ) THEN
				iret = -3
				RETURN
			    END IF
			    CALL ST_NUMB ( ccond (1), icntyp, ier )
			    IF ( icntyp .eq. 10 .or. icntyp .eq. 11 )
     +				ymdbeg = day1
			    DO ix = 4, 5
				CALL ST_LSTR ( ccond (ix), lng, ier )
				IF ( lng .eq. 12 ) THEN
				    IF ( ccond (ix)(1:8) .lt. ymdbeg )
     +				      ymdbeg = ccond (ix)(1:8)
				    IF ( ccond (ix)(1:8) .gt. ymdend )
     +				      ymdend = ccond (ix)(1:8)
			 	END IF
			    END DO
			END IF
		    END DO
		ELSE
C
C*		    Skip these records.
C
		    DO iq = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			END IF
		    END DO
		END IF
	    END IF
	END DO
	mlng = mlng - 1
C*
	IF ( mlng .eq. 0 ) THEN
	    iret = -11
	    RETURN
	END IF
C
C*	Check the date range.
C
	IF ( ymdbeg .eq. '99999999' ) THEN
	    ymdbeg = day1 (1:8)
	END IF
	IF ( ymdend .eq. '00000000' ) THEN
	    ymdend = today (1:8)
	END IF
	IF ( ymdbeg .eq. ' ' .or. ymdend .eq. ' ' ) THEN
	    iret = -4
	    RETURN
	END IF
	IF ( ymdbeg .lt. day1 (1:8) ) THEN
	    iret = -5
	    RETURN
	END IF
C
C*	Build the file names.
C
	CALL ST_UCLC ( models, models, ier )
	models = models (1:mlng) // ' END'
	nfiles = 0
	DO WHILE ( ymdbeg .le. ymdend )
C
C*	    Create and write a file name.
C
	    nfiles = nfiles + 1
	    record = '_' // ymdbeg(1:8) // '.vsdb'
	    cmdl = ' '
	    iptr = 0
	    icmd = 0
	    DO WHILE ( cmdl .ne. 'END' )
		iptr = iptr + 1
		IF ( models (iptr:iptr) .ne. ' ' ) THEN
		    icmd = icmd + 1
		    cmdl (icmd:icmd) = models (iptr:iptr)
		ELSE IF ( cmdl .ne. 'END' .and. icmd .ne. 0 ) THEN
		    recout = cmdl (1:icmd) // '/' // cmdl (1:icmd) //
     +			     record (1:14)
		    lnrc = 2 * icmd + 15
		    WRITE ( lunfls, '(A)', IOSTAT=ios ) recout (1:lnrc)
		    IF ( ios .ne. 0 ) THEN
			 iret = -7
			 RETURN
		    END IF
		    icmd = 0
		    cmdl = ' '
		END IF
	    END DO
C
C*	    Add on a day.
C
	    READ ( ymdbeg, '(I4,I2,I2)' ) iy, im, id
	    id = id + 1
	    IF ( MOD ( iy, 4 ) .eq. 0 ) THEN
		IF ( MOD ( iy, 400 ) .ne. 0 .and.
     +		     MOD ( iy, 100 ) .eq. 0 ) THEN
		    idpm (2) = 28
		ELSE
		    idpm (2) = 29
		END IF
	    ELSE
		idpm (2) = 28
	    END IF
	    IF ( id .gt. idpm (im) ) THEN
		id = 1
		im = im + 1
		IF ( im .gt. 12 ) THEN
		    im = 1
		    iy = iy + 1
		END IF
	    END IF
	    WRITE ( ymdbeg, '(I4.4,2I2.2)' ) iy, im, id
	END DO
C*
	RETURN
	END
