	SUBROUTINE USR_YMRG ( lunctl, lunlst, lunmdl, day1, today,
     +			      nrngs, nmdls, iret )
C************************************************************************
C* USR_YMRG								*
C*									*
C* This subroutine writes a series of YYYYMMDD ranges required by a set	*
C* of search conditions as defined in a search control file.  It can	*
C* also writes the names of the models (directory names).		*
C*									*
C* The control file is assumed to be open and connected to unit LUNCTL.	*
C*									*
C* The YYYYMMDD range lists are written to LUNLST, which is assumed to  *
C* be connected to an open file.  NRNGS is the number of YYYYMMDD	*
C* ranges written.							*
C*									*
C* The list of model names is returned in the output file assumed open	*
C* and connected to unit LUNMDL.  If LUNMDL = 0, no output is done.	*
C*									*
C* USR_YMRG ( LUNCTL, LUNLST, LUNMDL, DAY1, TODAY, NRNGS, NMDLS, IRET )	*
C*									*
C* Input parameters:							*
C*	LUNCTL		INTEGER		Unit number of control file	*
C*	LUNLST		INTEGER		Unit # of YYYYMMDD list file	*
C*	LUNMDL		INTEGER		Unit number of model list file	*
C*	DAY1		CHAR*		Starting YYYYMMDD of archive	*
C*	TODAY		CHAR*		YYYYMMDD of today		*
C*									*
C* Output parameters:							*
C*	NRNGS		INTEGER		# of YYYYMMDD ranges written	*
C*	NMDLS		INTEGER		# of model names written	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = invalid hdr rec		*
C*					 -2 = too few cndtn rec		*
C*					 -3 = invalid cndtn rec		*
C*					 -4 = no dates found		*
C*					 -5 = request predates archive	*
C*					 -7 = write err to file list fl	*
C*					 -8 = bad cndtn code for mdl nam*
C*					 -9 = mdl name has 0 length	*
C*					-10 = write err to mdl list fl	*
C*					-11 = no model names found	*	
C**									*
C* Log:									*
C* K. Brill/HPC		 3/03						*
C* K. Brill/HPC		12/03	Allow "." or "-" in model name		*
C* K. Brill/HPC		11/05	Allow model name that is embedded in	*
C*				another model name			*
C* K. Brill/HPC         07/08   Allow "_" in the model name		*
C************************************************************************
	CHARACTER*(*)	day1, today
C*
	CHARACTER*80	record
	CHARACTER*512	models
	CHARACTER*8	ymdbeg, ymdend, ymdbsv, ymdesv
	CHARACTER*24	ccond (5)
	CHARACTER*1	cbfor
	INTEGER		ihdr (5)
	LOGICAL		letter
C*------------------------------------------------------------------------
	iret = 0
	nrngs = 0
	nmdls = 0
	models = ' '
	mlng = 0
	ymdbsv = ' '
	ymdesv = ' '
C
C*	Scan the control file to find the range of dates required.
C
	REWIND lunctl
	iostat = 0
	DO WHILE ( iostat .eq. 0 )
	    READ ( lunctl, '(A)', IOSTAT=iostat ) record
	    IF ( iostat .eq. 0 ) THEN
		CALL ST_ILST ( record, ' ', -99, 5, ihdr, num, ier )
		IF ( ier .lt. 0 .or. num .ne. 5 ) THEN
		    iret = -1
		    RETURN
		END IF
		iddfld = ihdr (2)
		ncn = ihdr (5)
		IF ( iddfld .eq. 2 ) THEN
		    DO icn = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			ELSE
			    CALL ST_CLST ( record, ' ', ' ', 5,
     +					   ccond, ncnd, ier )
			    IF ( ncnd .ne. 5 .or. ier .ne. 0 ) THEN
				iret = -3
				RETURN
			    END IF
			    CALL ST_NUMB ( ccond (1), icntyp, ier )
			    IF ( icntyp .ne. 18 ) THEN
				iret = -8
				RETURN
			    END IF
			    CALL ST_LSTR ( ccond (4), lng, ier )
			    iq = 0
			    letter = .true.
			    record = ' '
			    DO WHILE ( iq .lt. lng .and. letter )
				iq = iq + 1
				IF ( ( ccond (4) (iq:iq) .ge. 'A'
     +				   .and. ccond (4) (iq:iq) .le. 'Z' )
     +				   .or.
     +				     ( ccond (4) (iq:iq) .ge. '0'
     +				   .and. ccond (4) (iq:iq) .le. '9' )
     +				   .or.
     +				     ( ccond (4) (iq:iq) .eq. '.' .or.
     +				       ccond (4) (iq:iq) .eq. '-' )
     +				   .or.
     +				     ( ccond (4) (iq:iq) .eq. '_' )
     +				   ) THEN
				    record (iq:iq) = ccond (4) (iq:iq)
				ELSE
				    letter = .false.
				END IF
			    END DO
			    IF ( iq .eq. 0 ) THEN
				iret = -9
				RETURN
			    END IF
			    record = record (1:iq) // ' '
			    iq = iq + 1
			    ifnd = INDEX ( models, record (1:iq) )
			    ifnm1 = ifnd - 1
			    IF ( ifnm1 .gt. 0 ) THEN
			        cbfor = models (ifnm1:ifnm1)
			    ELSE
				cbfor = ' '
			    END IF
			    IF ( ifnd .eq. 0 .or. cbfor .ne. ' ' ) THEN
				IF ( mlng .eq. 0 ) THEN
				    models = record (1:iq)
				    mlng = iq
				ELSE
				    models = models (1:mlng) //
     +						record (1:iq)
				    mlng = mlng + iq + 1
				END IF
				IF ( lunmdl .gt. 0 ) THEN
				    WRITE ( lunmdl, '(A)', IOSTAT=ios )
     +					 record (1:iq)
				    IF ( ios .ne. 0 ) THEN
					iret = -10
					RETURN
				    END IF
				END IF
				nmdls = nmdls + 1
			    END IF
			END IF
		    END DO
		ELSE IF ( iddfld .eq. 5 ) THEN
		    ymdbeg = ' '
		    ymdend = ' '
		    DO iq = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			ELSE
			    CALL ST_CLST ( record, ' ', ' ', 5,
     +					   ccond, ncnd, ier )
			    IF ( ncnd .ne. 5 .or. ier .ne. 0 ) THEN
				iret = -3
				RETURN
			    END IF
			    CALL ST_NUMB ( ccond (1), icntyp, ier )
			    IF ( icntyp .eq. 10 .or. icntyp .eq. 11 )
     +				ymdbeg = day1
			    DO ix = 4, 5
				CALL ST_LSTR ( ccond (ix), lng, ier )
				IF ( lng .eq. 12 .and. ix .eq. 4 ) THEN
				    ymdbeg = ccond (ix)(1:8)
				ELSE IF ( lng .eq. 12 ) THEN
				    ymdend = ccond (ix)(1:8)
			 	END IF
			    END DO
			END IF
			IF ( ymdbeg .eq. ' ' ) ymdbeg = day1 (1:8)
			IF ( ymdend .eq. ' ' ) ymdend = today (1:8)
			IF ( icntyp .eq. 18 ) ymdend = ymdbeg
			IF ( icntyp .lt. 19 ) THEN
			    WRITE ( lunlst, '(A,1X,A)', IOSTAT=ios )
     +				    ymdbeg (1:8), ymdend (1:8)
			    nrngs = nrngs + 1
			ELSE
			    ymdbsv = ymdbeg (1:8)
			    ymdesv = ymdend (1:8)
			END IF
		    END DO
		ELSE
C
C*		    Skip these records.
C
		    DO iq = 1, ncn
			READ ( lunctl, '(A)', IOSTAT=iostat ) record
			IF ( iostat .ne. 0 ) THEN
			    iret = -2
			    RETURN
			END IF
		    END DO
		END IF
	    END IF
	END DO
	IF ( nrngs .eq. 0 .and. ymdbsv .ne. ' ' ) THEN
	    WRITE ( lunlst, '(A,1X,A)', IOSTAT=ios )
     +		    ymdbsv (1:8), ymdesv (1:8)
	END IF
	mlng = mlng - 1
C*
	IF ( mlng .eq. 0 ) THEN
	    iret = -11
	    RETURN
	END IF
C*
	RETURN
	END
