	SUBROUTINE VSDB_FST ( rcrd, field, nfld, ivrsn, cdata, nval,
     +			      cvrsn, cmdl, fh, rfw, ymdhn, rymdhw,
     +			      rymdhi, canl, crgn, cstat, cstth, rthrsh,
     +			      lthflg, cprm, clvl, rlvl, nlev,
     +			      value, iret )
C************************************************************************
C* VSDB_FST								*
C*									*
C* This subroutine parses a record from a Verification Statistic Data	*
C* Base and returns all of the component fields and values as described *
C* below.  This parser is provided to support search functions and	*
C* should work faster than VSDB_PAR.					*
C*									*
C* If RCRD is equal to NULL ('NULL'), then FIELD, NFLD, IVRSN, and	*
C* CDATA are assumed to already have been set by VSDB_FLD and are used	*
C* as input strings from which the output parameters are extracted.	*
C*									*
C* A maximum of two values can be returned in LEVEL with NLEV giving	*
C* the number.  If NLEV = 2, a layer is implied.  If NLEV = 1, then	*
C* CLVL is a single letter denoting the vertical coordinate; otherwise, *
C* CLVL is the entire level descriptor string.				*
C*									*
C*									*
C* VSDB_FST  ( RCRD, FIELD, NFLD, IVRSN, CDATA, NVAL,			*
C*	       CVRSN, CMDL, FH, RFW, YMDHN, RYMDHW, RYMDHI, CANL,	*
C*	       CRGN, CSTAT, CSTTH, RTHRSH, LTHFLG, CPRM, CLVL, RLVL,	*
C*	       NLEV, VALUE, IRET )					*
C*									*
C* Input parameters:							*
C*	RCRD		CHAR*		Record from a VSDB file		*
C*									*
C* Input or output parameters:						*
C*	FIELD (NFLD)	CHAR*		Descriptor fields		*
C*	NFLD		INTEGER		Number of descriptor fields	*
C*	IVRSN		INTEGER		VSDB version number		*
C*	CDATA		CHAR*		Data field			*
C*	NVAL		INTEGER		On input = max # of data values	*
C*					On output = # of values found	*
C*									*
C* Output parameters:							*
C*	CVRSN		CHAR*		Version number field		*
C*	CMDL		CHAR*		Model verified			*
C*	FH		REAL		Forecast hour			*
C*	RFW		REAL		Forecast time window (h)	*
C*	YMDHN		CHAR*12		YYYYMMDDHHNN (NN = minutes)	*
C*	RYMDHW		REAL		Verifying time window (h)	*
C*	RYMDHI		REAL		Time increment (h)		*
C*	CANL		CHAR*		Verifying analysis		*
C*	CRGN		CHAR*		Verifying region		*
C*	CSTAT		CHAR*		Statistic type without threshold*
C*	CSTTH		CHAR*		Statistic type with threshold	*
C*	RTHRSH		REAL		Real value threshold		*
C*	LTHFLG		INTEGER		Threshold type flag		*
C*					 = -1 if lower bound		*
C*					 = 0 if no threshold value	*
C*					 = +1 if upper bound		*
C*	CPRM		CHAR*		Parameter name			*
C*	CLVL		CHAR*		Level identifier		*
C*	RLVL (2)	REAL		Levels				*
C*	NLEV		INTEGER		Number of levels		*
C*	VALUE (NVAL)	REAL*8		Values following the = in record*
C*	IRET		INTEGER		Return code			*
C*					+03 = more than NVAL values	*
C*					+01 = data field is blank	*
C*				 	  0 = normal return 		*
C*					-05 = invalid record		*
C*					-06 = invalid version number	*
C*					-07 = invalid number of fields  *
C*					-08 = invalid forecast hour	*
C*					-09 = invalid verifying time	*
C*					-10 = invalid threshold set	*
C*					-12 = invalid level id		*
C*					-13 = invalid data field	*
C**									*
C* Log:									*
C* K. Brill/NMC		 7/97						*
C* K. Brill/HPC		01/00	0 -> 0.0 in CALL VSDB_RLN for linux	*
C* K. Brill/HPC		06/02	Allow /range in statistic type parm	*
C*				and return missing threshold if |	*
C* K. Brill/HPC		 3/03	Return stat type with threshold		*
C* K. Brill/HPC		 3/04	Use VSDB_SLN instead of ST_CLST		*
C* K. Brill/IMSG         4/17   Accommodate REAL*8                      *   
C************************************************************************
	CHARACTER*(*)	rcrd, field (*), cdata, cvrsn, cmdl, canl, crgn,
     +			cstat, cstth, cprm, clvl
	CHARACTER*12	ymdhn
	REAL		rlvl (2)
	REAL*8		value (*)
C*
	CHARACTER*16	substr (3)
	CHARACTER*16	cpar, crng
	CHARACTER*2	cnn
	REAL*8		rv (4)
C*------------------------------------------------------------------------
	iret = 0
C
C*	Get identifier fields and the version number if RCRD is not NULL.
C
	IF ( rcrd .ne. 'NULL' ) THEN
	    CALL VSDB_FLD ( rcrd, nfld, field, ivrsn, cdata, iret )
	    IF ( iret .ne. 0 ) RETURN
	END IF
	cvrsn = field (1)
	cmdl =  field (2)
C
C*	Get the forecast hour.
C
	islsh = INDEX ( field (3), '/' )
	IF ( islsh .ne. 0 ) THEN
	    CALL VSDB_RLN ( field (3), '/', 0.0D00, 2, rv, num, ier )
	ELSE
	    CALL ST_CRNM ( field (3), xrv, ier )
            rv (1) = xrv
	    num = 1
	END IF
	IF ( ier .lt. 0 ) THEN
	    iret = -8
	    RETURN
	END IF
	IF ( num .eq. 1 ) rv (2) = 0.0
	fh = rv (1)
	rfw = FLOAT ( NINT ( rv (2) ) )
C
C*	Get the verifying time components.
C
	islsh = INDEX ( field (4), '/' )
	IF ( islsh .ne. 0 ) THEN
	    CALL VSDB_SLN ( field (4), '/', ' ', 3, substr, num, ier )
	    IF ( num .le. 0 .or. ier .lt. 0 ) THEN
		iret = -9
		RETURN
	    END IF
	ELSE
	    substr (1) = field (4)
	    num = 1
	END IF
	idot = INDEX ( substr (1), '.' )
	IF ( idot .ne. 0 ) THEN
	    CALL ST_CRNM ( substr(1) (idot:), rhr, ier1 )
	ELSE
	    rhr = 0.0
	    ier1 = 0
	END IF
C
C*	Set the verifying time string YMDHN.
C
	nn = NINT ( rhr * 60. )
	WRITE (cnn,'(I2.2)', IOSTAT=ier2 ) nn
	ymdhn = field (4) (1:10) // cnn
	IF ( num .gt. 1 ) THEN
	    CALL ST_CRNM ( substr (2), rymdhw, ier3 )
	ELSE
	    rymdhw = 0
	    ier3 = 0
	END IF
	IF ( num .eq. 3 ) THEN
	    CALL ST_CRNM ( substr (3), rymdhi, ier4 )
	ELSE
	    rymdhi = 0
	    ier4 = 0
	END IF
	ier = ier1 + ier2 + ier3 + ier4
	IF ( ier .ne. 0 ) THEN
	    iret = -9
	    RETURN
	END IF
C*
	canl = field (5)
	crgn = field (6)
C
C*	Get the threshold value if present in field 7 and no
C*	| delimiter is present.
C
	cstth = field (7)
	igb = INDEX ( field (7), '|' )
	IF ( igb .ne. 0 ) THEN
	    cstat = field (7)
	    ier = 0
	    lthflg = 0
	    rthrsh = -1.1E31
	ELSE
	    igs = INDEX ( field (7), '/' )
	    IF ( igs .ne. 0 ) THEN
		cpar = field (7) (1:(igs-1))
		crng = field (7) (igs:)
	    ELSE
		cpar = field (7)
		crng = ' '
	    END IF
	    igt = INDEX ( cpar, '>' )
	    ilt = INDEX ( cpar, '<' )
	    IF ( igt .ne. 0 ) THEN
		IF ( crng .eq. ' ' ) THEN
		    cstat = cpar (1:(igt-1))
		ELSE
		    cstat = field (7)
		END IF
		substr (1) = cpar ((igt+1):)
		lthflg = -1
		CALL ST_CRNM ( substr (1), rthrsh, ier )
	    ELSE IF ( ilt .ne. 0 ) THEN
		IF ( crng .eq. ' ' ) THEN
		    cstat = cpar (1:(ilt-1))
		ELSE
	    	    cstat = field (7)
		END IF
		substr (1) = cpar ((ilt+1):)
		lthflg = +1
		CALL ST_CRNM ( substr (1), rthrsh, ier )
	    ELSE
		cstat = field (7)
		ier = 0
		lthflg = 0
		rthrsh = -1.1E31
	    END IF
	END IF
	IF ( ier .ne. 0 ) THEN
	    iret = -10
	    RETURN
	END IF
C
C*	Get accumulation/averaging period from parameter name.
C
	cprm = field (8)
C
C*	Get level information if present.
C
	IF ( ( field (9) (1:1) .eq. 'B' .or.
     +         field (9) (1:1) .eq. 'D' .or.
     +         field (9) (1:1) .eq. 'H' .or.
     +         field (9) (1:1) .eq. 'P' .or.
     +         field (9) (1:1) .eq. 'S' .or.
     +         field (9) (1:1) .eq. 'T' .or.
     +         field (9) (1:1) .eq. 'Z' ) .and.
     +	     ( field (9) (2:2) .ge. '0' .and.
     +	       field (9) (2:2) .le. '9' ) ) THEN
	    iminus = INDEX ( field (9), '-' )
	    IF ( iminus .eq. 0 ) THEN
		CALL ST_CRNM ( field (9) (2:), rlvl (1), ier )
		rlvl (2) = -1.1e31
		nlev = 1
	    ELSE
		CALL ST_CRNM ( field (9) (2:(iminus-1)), rlvl (1), ier )
		CALL ST_CRNM ( field (9) ((iminus+1):), rlvl (2), ier1 )
		nlev = 2
		ier = ier + ier1
	    END IF
	    IF ( ier .ne. 0 ) THEN
		iret = -12
		RETURN
	    END IF
	ELSE
	    nlev = 0
	    rlvl (1) = -1.1e31
	    rlvl (2) = -1.1e31
	END IF
	IF ( nlev .eq. 1 ) THEN
	    clvl = field (9) (1:1)
	ELSE
	    clvl = field (9)
	END IF
C
C*	Process the data field.
C
	IF ( cdata .eq. ' ' ) THEN
	    nval = 0
	    iret = +1
	    RETURN
	ELSE
	    CALL VSDB_RLN ( cdata, ' ', -1.1D31, nval, value, nv, ier )
	    IF ( ier .lt. 0 ) THEN
		iret = -13
		RETURN
	    END IF
	    IF ( ier .gt. 0 ) iret = 3
	    nval = nv
	END IF
C*
	RETURN
	END
