	SUBROUTINE VSDB_PAR ( rcrd, field, nfld, ivrsn, cdata, nval,
     +			      fh, ifw, iy, im, id, rhr, iymdhw, iymdhi,
     +			      rthrsh, lthflg, iahr, level, nlev, value,
     +			      iret )
C************************************************************************
C* VSDB_PAR								*
C*									*
C* This subroutine parses a record from a Verification Statistic Data	*
C* Base and returns all of the component fields and values as described *
C* below.								*
C*									*
C* If RCRD is equal to NULL ('NULL'), then FIELD, NFLD, IVRSN, and	*
C* CDATA are assumed to already have been set by VSDB_FLD and are used	*
C* as input strings from which the output parameters are extracted.	*
C*									*
C* Note that the maximum value NLEV can have is 2.  If NLEV = 0 then	*
C* level values are not relevant.  If NLEV = 2, a layer is defined.	*
C*									*
C*									*
C* VSDB_PAR  ( RCRD, FIELD, NFLD, IVRSN, CDATA, NVAL,			*
C*	       FH, IFW, IY, IM, ID, RHR, IYMDHW, IYMDHI,		*
C*	       RTHRSH, LTHFLG, IAHR, LEVEL, NLEV, VALUE, IRET )		*	
C*									*
C* Input parameters:							*
C*	RCRD		CHAR*		Record from a VSDB file		*
C*									*
C* Input or output parameters:						*
C*	FIELD (NFLD)	CHAR*		Descriptor fields		*
C*	NFLD		INTEGER		Number of descriptor fields	*
C*	IVRSN		INTEGER		VSDB version number		*
C*	CDATA		CHAR*		Data field			*
C*	NVAL		INTEGER		On input = max # of data values	*
C*					On output = # of values found	*
C*									*
C* Output parameters:							*
C*	FH		REAL		Forecast hour			*
C*	IFW		INTEGER		Forecast time window (h)	*
C*	IY		INTEGER		Verifying Year			*
C*	IM		INTEGER		Verifying Month			*
C*	ID		INTEGER		Verifying Day			*
C*	RHR		REAL		Verifying hour			*
C*	IYMDHW		INTEGER		Verifying time window (h)	*
C*	IYMDHI		INTEGER		Time increment (h)		*
C*	RTHRSH		REAL		Real value threshold		*
C*	LTHFLG		INTEGER		Threshold type flag		*
C*					 = -1 if lower bound		*
C*					 = 0 if no threshold value	*
C*					 = +1 if upper bound		*
C*	IAHR		INTEGER		Accum/avg period (h)		*
C*	LEVEL (2)	INTEGER		Levels				*
C*	NLEV		INTEGER		Number of levels		*
C*	VALUE (NVAL)	REAL*8		Values following the = in record*
C*	IRET		INTEGER		Return code			*
C*					+03 = more than NVAL values	*
C*					+01 = data field is blank	*
C*				 	  0 = normal return 		*
C*					-05 = invalid record		*
C*					-06 = invalid version number	*
C*					-07 = invalid number of fields  *
C*					-08 = invalid forecast hour	*
C*					-09 = invalid verifying time	*
C*					-10 = invalid threshold set	*
C*					-11 = invalid accum period	*
C*					-12 = invalid level id		*
C*					-13 = invalid data field	*
C**									*
C* Log:									*
C* K. Brill/NMC		 7/97						*
C* K. Brill/EMC		11/97	Set rhr=0.0 if no .d in verifying date	*
C* K. Brill/HPC		01/00   0 -> 0.0 in CALL VSDB_RLN for linux     *
C* K. Brill/HPC		 2/02	Allow slash after threshold amounts	*
C*				and return missing theshold if |	*
C* K. Brill/HPC		 3/04	Use VSDB_SLN instead of ST_CLST		*
C* K. Brill/IMSG         4/17   Accommodate REAL*8                      *
C************************************************************************
	CHARACTER*(*)	rcrd, field (*), cdata
	INTEGER		level (2)
	REAL*8		value (*)
C*
	CHARACTER*24	substr (3), sub2 (2)
	REAL*8		rv (4)
C*------------------------------------------------------------------------
	iret = 0
C
C*	Get identifier fields and the version number if RCRD is not NULL.
C
	IF ( rcrd .ne. 'NULL' ) THEN
	    CALL VSDB_FLD ( rcrd, nfld, field, ivrsn, cdata, iret )
	    IF ( iret .ne. 0 ) RETURN
	END IF
C
C*	Get the forecast hour.
C
	CALL VSDB_RLN ( field (3), '/', 0.0D00, 2, rv, num, ier )
	IF ( ier .lt. 0 ) THEN
	    iret = -8
	    RETURN
	END IF
	IF ( num .eq. 1 ) rv (2) = 0.0
	fh = rv (1)
	ifw = NINT ( rv (2) )
C
C*	Get the verifying time components.
C
	CALL VSDB_SLN ( field (4), '/', ' ', 3, substr, num, ier )
	IF ( num .le. 0 .or. ier .lt. 0 ) THEN
	    iret = -9
	    RETURN
	END IF
	idot = INDEX ( substr (1), '.' )
	IF ( idot .ne. 0 ) THEN
	    CALL ST_LSTR ( substr (1), ln1, ier )
	    CALL ST_CRNM ( substr (1) (idot:ln1), rhr, ier )
	ELSE
	    ier = 0
	    rhr = 0.0
	END IF
	CALL ST_NUMB ( field (4) (1:4), iy, ier1 )
	CALL ST_NUMB ( field (4) (5:6), im, ier2 )
	CALL ST_NUMB ( field (4) (7:8), id, ier3 )
	CALL ST_NUMB ( field (4) (9:10), ih, ier4 )
	rhr = FLOAT (ih) + rhr
	IF ( num .gt. 1 ) THEN
	    CALL ST_NUMB ( substr (2), iymdhw, ier5 )
	ELSE
	    iymdhw = 0
	    ier5 = 0
	END IF
	IF ( num .eq. 3 ) THEN
	    CALL ST_NUMB ( substr (3), iymdhi, ier6 )
	ELSE
	    iymdhi = 0
	    ier6 = 0
	END IF
	ier = ier + ier1 + ier2 + ier3 + ier4 + ier5 + ier6
	IF ( ier .ne. 0 ) THEN
	    iret = -9
	    RETURN
	END IF
C
C*	Get the threshold value if present in field 7.
C
	CALL VSDB_SLN ( field (7), '/', ' ', 2, sub2, num, ier )
	igb = INDEX ( field (7), '|' )
	igt = INDEX ( sub2 (1), '>' )
	ilt = INDEX ( sub2 (1), '<' )
	IF ( igt .ne. 0 .and. igb .eq. 0 ) THEN
	    CALL VSDB_SLN ( sub2 (1), '>', ' ', 2, substr, num, ier )	
	    IF ( ier .ge. 0 .and. num .eq. 2 ) THEN
		lthflg = -1
		CALL ST_CRNM ( substr (2), rthrsh, ier )
	    END IF
	ELSE IF ( ilt .ne. 0 .and. igb .eq. 0 ) THEN
	    CALL VSDB_SLN ( sub2 (1), '<', ' ', 2, substr, num, ier )	
	    IF ( ier .ge. 0 .and. num .eq. 2 ) THEN
		lthflg = +1
		CALL ST_CRNM ( substr (2), rthrsh, ier )
	    END IF
	ELSE
	    ier = 0
	    lthflg = 0
	    rthrsh = -1.1E31
	END IF
	IF ( ier .ne. 0 ) THEN
	    iret = -10
	    RETURN
	END IF
C
C*	Get accumulation/averaging period from parameter name.
C
	islash = INDEX ( field (8), '/' )
	IF ( islash .ne. 0 ) THEN
	    CALL VSDB_SLN ( field (8), '/', ' ', 2, substr, num, ier )
	    IF ( ier .ge. 0 .and. num .eq. 2 ) THEN
		CALL ST_NUMB ( substr (2), iahr, ier )
	    END IF
	    IF ( ier .ne. 0 ) THEN
		iret = -11
		RETURN
	    END IF
	ELSE
	    iahr = 0
	END IF
C
C*	Get level information if present.
C
	IF ( ( field (9) (1:1) .eq. 'B' .or.
     +         field (9) (1:1) .eq. 'D' .or.
     +         field (9) (1:1) .eq. 'H' .or.
     +         field (9) (1:1) .eq. 'P' .or.
     +         field (9) (1:1) .eq. 'S' .or.
     +         field (9) (1:1) .eq. 'T' .or.
     +         field (9) (1:1) .eq. 'Z' ) .and.
     +	     ( field (9) (2:2) .ge. '0' .and.
     +	       field (9) (2:2) .le. '9' ) ) THEN
	    CALL ST_ILST ( field (9) (2:), '-', -9999, 2, level, nlev,
     +			   ier )
	    IF ( ier .ne. 0 .or. nlev .eq. 0 ) THEN
		iret = -12
		RETURN
	    END IF
	ELSE
	    nlev = 0
	    level (1) = -9999
	    level (2) = -9999
	END IF
C
C*	Process the data field.
C
	IF ( cdata .eq. ' ' ) THEN
	    nval = 0
	    iret = +1
	    RETURN
	ELSE
	    CALL VSDB_RLN ( cdata, ' ', -1.1D31, nval, value, nv, ier )
	    IF ( ier .lt. 0 ) THEN
		iret = -13
		RETURN
	    END IF
	    IF ( ier .gt. 0 ) iret = 3
	    nval = nv
	END IF
C*
	RETURN
	END
